@@ -18,8 +18,8 @@
 
 package org.apache.flink.hadoopcompatibility;
 
-import org.apache.flink.api.java.utils.AbstractParameterToolTest;
-import org.apache.flink.api.java.utils.ParameterTool;
+import org.apache.flink.util.AbstractParameterToolTest;
+import org.apache.flink.util.ParameterTool;
 
 import org.junit.jupiter.api.Test;
 
