@@ -241,13 +241,6 @@ public class BasicTypeInfo<T> extends TypeInformation<T> implements AtomicType<T
         return this.serializer;
     }
 
-    @Override
-    @Deprecated
-    @PublicEvolving
-    public TypeSerializer<T> createSerializer(ExecutionConfig config) {
-        return createSerializer(config.getSerializerConfig());
-    }
-
     @Override
     @PublicEvolving
     public TypeComparator<T> createComparator(
