@@ -23,7 +23,7 @@ import org.apache.flink.api.common.typeutils.TypeSerializer;
 
 import java.nio.charset.StandardCharsets;
 
-import static org.junit.Assert.assertEquals;
+import static org.assertj.core.api.Assertions.assertThat;
 
 /** Tests for {@link SimpleVersionedSerializerTypeSerializerProxy}. */
 class SimpleVersionedSerializerTypeSerializerProxyTest extends SerializerTestBase<String> {
@@ -79,7 +79,7 @@ class SimpleVersionedSerializerTypeSerializerProxyTest extends SerializerTestBas
 
         @Override
         public String deserialize(int version, byte[] serialized) {
-            assertEquals(VERSION, version);
+            assertThat(version).isEqualTo(VERSION);
             return new String(serialized, StandardCharsets.UTF_8);
         }
 
