@@ -38,23 +38,21 @@ import org.apache.flink.table.runtime.typeutils.InternalTypeInfo;
 import org.apache.flink.table.types.logical.DecimalType;
 import org.apache.flink.table.types.logical.LogicalType;
 import org.apache.flink.table.types.logical.RowType;
-import org.apache.flink.util.IOUtils;
 
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.hive.ql.io.sarg.PredicateLeaf;
-import org.junit.ClassRule;
-import org.junit.Test;
-import org.junit.rules.TemporaryFolder;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.io.TempDir;
 
-import java.io.File;
-import java.io.FileOutputStream;
 import java.io.IOException;
+import java.io.InputStream;
 import java.math.BigDecimal;
+import java.nio.file.Files;
 import java.util.ArrayList;
 import java.util.Collections;
 import java.util.LinkedHashMap;
 import java.util.List;
-import java.util.UUID;
 import java.util.concurrent.atomic.AtomicInteger;
 import java.util.concurrent.atomic.AtomicLong;
 import java.util.function.Consumer;
@@ -63,7 +61,7 @@ import static org.apache.flink.table.utils.PartitionPathUtils.generatePartitionP
 import static org.assertj.core.api.Assertions.assertThat;
 
 /** Test for {@link OrcColumnarRowInputFormat}. */
-public class OrcColumnarRowInputFormatTest {
+class OrcColumnarRowInputFormatTest {
 
     /** Small batch size for test more boundary conditions. */
     protected static final int BATCH_SIZE = 9;
@@ -89,14 +87,19 @@ public class OrcColumnarRowInputFormatTest {
     private static final RowType DECIMAL_FILE_TYPE =
             RowType.of(new LogicalType[] {new DecimalType(10, 5)}, new String[] {"_col0"});
 
-    private final Path flatFile = copyFileFromResource("test-data-flat.orc");
+    private static Path flatFile;
+    private static Path decimalFile;
 
-    private final Path decimalFile = copyFileFromResource("test-data-decimal.orc");
-
-    @ClassRule public static final TemporaryFolder TEMPORARY_FOLDER = new TemporaryFolder();
+    @BeforeAll
+    static void setupFiles(@TempDir java.nio.file.Path tmpDir) {
+        flatFile = copyFileFromResource("test-data-flat.orc", tmpDir.resolve("test-data-flat.orc"));
+        decimalFile =
+                copyFileFromResource(
+                        "test-data-decimal.orc", tmpDir.resolve("test-data-decimal.orc"));
+    }
 
     @Test
-    public void testReadFileInSplits() throws IOException {
+    void testReadFileInSplits() throws IOException {
         OrcColumnarRowInputFormat<?, FileSourceSplit> format =
                 createFormat(FLAT_FILE_TYPE, new int[] {0, 1});
 
@@ -123,7 +126,7 @@ public class OrcColumnarRowInputFormatTest {
     }
 
     @Test
-    public void testReadFileWithSelectFields() throws IOException {
+    void testReadFileWithSelectFields() throws IOException {
         OrcColumnarRowInputFormat<?, FileSourceSplit> format =
                 createFormat(FLAT_FILE_TYPE, new int[] {2, 0, 1});
 
@@ -152,7 +155,7 @@ public class OrcColumnarRowInputFormatTest {
     }
 
     @Test
-    public void testReadDecimalTypeFile() throws IOException {
+    void testReadDecimalTypeFile() throws IOException {
         OrcColumnarRowInputFormat<?, FileSourceSplit> format =
                 createFormat(DECIMAL_FILE_TYPE, new int[] {0});
 
@@ -187,7 +190,7 @@ public class OrcColumnarRowInputFormatTest {
     }
 
     @Test
-    public void testReadFileWithPartitionFields() throws IOException {
+    void testReadFileWithPartitionFields(@TempDir java.nio.file.Path tmpDir) throws IOException {
         LinkedHashMap<String, String> partSpec = new LinkedHashMap<>();
         partSpec.put("f1", "1");
         partSpec.put("f3", "3");
@@ -195,7 +198,9 @@ public class OrcColumnarRowInputFormatTest {
         partSpec.put("f8", BigDecimal.valueOf(5.333).toString());
         partSpec.put("f13", "f13");
 
-        final Path flatFile = copyFileFromResource("test-data-flat.orc", partSpec);
+        final Path flatFile =
+                copyFileFromResource(
+                        "test-data-flat.orc", tmpDir.resolve(generatePartitionPath(partSpec)));
 
         RowType tableType =
                 RowType.of(
@@ -254,7 +259,7 @@ public class OrcColumnarRowInputFormatTest {
     }
 
     @Test
-    public void testReadFileAndRestore() throws IOException {
+    void testReadFileAndRestore() throws IOException {
         OrcColumnarRowInputFormat<?, FileSourceSplit> format =
                 createFormat(FLAT_FILE_TYPE, new int[] {0, 1});
 
@@ -267,7 +272,7 @@ public class OrcColumnarRowInputFormatTest {
     }
 
     @Test
-    public void testReadFileAndRestoreWithFilter() throws IOException {
+    void testReadFileAndRestoreWithFilter() throws IOException {
         List<Predicate> filter =
                 Collections.singletonList(
                         new Or(
@@ -396,35 +401,15 @@ public class OrcColumnarRowInputFormatTest {
         Utils.forEachRemaining(createReader(format, split), action);
     }
 
-    private Path copyFileFromResource(String fileName) {
-        try {
-            File file = TEMPORARY_FOLDER.newFile();
-            return copyFileFromResource(fileName, file);
-        } catch (IOException e) {
-            throw new RuntimeException(e);
-        }
-    }
-
-    private Path copyFileFromResource(String fileName, LinkedHashMap<String, String> partSpec) {
-        try {
-            File folder = TEMPORARY_FOLDER.newFolder();
-            folder = new File(folder, generatePartitionPath(partSpec));
-            return copyFileFromResource(fileName, new File(folder, UUID.randomUUID().toString()));
-        } catch (IOException e) {
-            throw new RuntimeException(e);
-        }
-    }
-
-    private Path copyFileFromResource(String fileName, File file) {
-        try {
-            file.getParentFile().mkdirs();
-            file.delete();
-            file.createNewFile();
-            IOUtils.copyBytes(
-                    getClass().getClassLoader().getResource(fileName).openStream(),
-                    new FileOutputStream(file),
-                    true);
-            return new Path(file.getPath());
+    static Path copyFileFromResource(String resourceName, java.nio.file.Path file) {
+        try (InputStream resource =
+                OrcColumnarRowInputFormatTest.class
+                        .getClassLoader()
+                        .getResource(resourceName)
+                        .openStream()) {
+            Files.createDirectories(file.getParent());
+            Files.copy(resource, file);
+            return new Path(file.toString());
         } catch (IOException e) {
             throw new RuntimeException(e);
         }
