@@ -28,8 +28,8 @@ from shutil import copytree, copy, rmtree
 from setuptools import setup, Extension
 from xml.etree import ElementTree as ET
 
-if sys.version_info < (3, 8):
-    print("Python versions prior to 3.8 are not supported for PyFlink.",
+if sys.version_info < (3, 9):
+    print("Python versions prior to 3.9 are not supported for PyFlink.",
           file=sys.stderr)
     sys.exit(-1)
 
@@ -197,8 +197,8 @@ README_FILE_TEMP_PATH = os.path.join("pyflink", "README.txt")
 PYFLINK_UDF_RUNNER_SH = "pyflink-udf-runner.sh"
 PYFLINK_UDF_RUNNER_BAT = "pyflink-udf-runner.bat"
 
-in_flink_source = os.path.isfile("../flink-java/src/main/java/org/apache/flink/api/java/"
-                                 "ExecutionEnvironment.java")
+in_flink_source = os.path.isfile("../flink-runtime/src/main/java/org/apache/flink/streaming"
+                                 "/api/environment/StreamExecutionEnvironment.java")
 try:
     if in_flink_source:
 
@@ -317,14 +317,14 @@ try:
         'pyflink.bin': ['*']}
 
     install_requires = ['py4j==0.10.9.7', 'python-dateutil>=2.8.0,<3',
-                        'apache-beam>=2.43.0,<2.49.0',
-                        'cloudpickle>=2.2.0', 'avro-python3>=1.8.1,!=1.9.2',
+                        'apache-beam>=2.54.0,<=2.61.0',
+                        'cloudpickle>=2.2.0', 'avro>=1.12.0',
                         'pytz>=2018.3', 'fastavro>=1.1.0,!=1.8.0', 'requests>=2.26.0',
                         'protobuf>=3.19.0',
                         'numpy>=1.22.4',
                         'pandas>=1.3.0',
                         'pyarrow>=5.0.0,<21.0.0',
-                        'pemja>=0.5.5,<0.5.6;platform_system != "Windows"',
+                        'pemja>=0.5.0,<0.5.4;platform_system != "Windows"',
                         'httplib2>=0.19.0',
                         'ruamel.yaml>=0.18.4',
                         apache_flink_libraries_dependency]
@@ -341,7 +341,7 @@ try:
         license='https://www.apache.org/licenses/LICENSE-2.0',
         author='Apache Software Foundation',
         author_email='dev@flink.apache.org',
-        python_requires='>=3.8',
+        python_requires='>=3.9',
         install_requires=install_requires,
         cmdclass={'build_ext': build_ext},
         description='Apache Flink Python API',
@@ -351,10 +351,10 @@ try:
         classifiers=[
             'Development Status :: 5 - Production/Stable',
             'License :: OSI Approved :: Apache Software License',
-            'Programming Language :: Python :: 3.8',
             'Programming Language :: Python :: 3.9',
             'Programming Language :: Python :: 3.10',
-            'Programming Language :: Python :: 3.11'],
+            'Programming Language :: Python :: 3.11',
+            'Programming Language :: Python :: 3.12'],
         ext_modules=extensions
     )
 finally:
