@@ -18,8 +18,8 @@
 
 package org.apache.flink.runtime.webmonitor.testutils;
 
-import org.apache.flink.api.java.ExecutionEnvironment;
-import org.apache.flink.api.java.io.DiscardingOutputFormat;
+import org.apache.flink.streaming.api.environment.StreamExecutionEnvironment;
+import org.apache.flink.streaming.api.functions.sink.v2.DiscardingSink;
 
 /** Simple test program that exposes passed arguments. */
 public class ParameterProgram {
@@ -29,8 +29,8 @@ public class ParameterProgram {
     public static void main(String[] args) throws Exception {
         actualArguments = args;
 
-        ExecutionEnvironment env = ExecutionEnvironment.getExecutionEnvironment();
-        env.fromElements("hello", "world").output(new DiscardingOutputFormat<>());
+        StreamExecutionEnvironment env = StreamExecutionEnvironment.getExecutionEnvironment();
+        env.fromData("hello", "world").sinkTo(new DiscardingSink<>());
         env.execute();
     }
 }
