@@ -20,6 +20,7 @@ package org.apache.flink.runtime.io.network.partition.hybrid.tiered.tier.memory;
 
 import org.apache.flink.configuration.Configuration;
 import org.apache.flink.runtime.io.disk.BatchShuffleReadBufferPool;
+import org.apache.flink.runtime.io.network.buffer.BufferCompressor;
 import org.apache.flink.runtime.io.network.partition.hybrid.tiered.common.TieredStoragePartitionId;
 import org.apache.flink.runtime.io.network.partition.hybrid.tiered.netty.TieredStorageNettyService;
 import org.apache.flink.runtime.io.network.partition.hybrid.tiered.storage.TieredStorageConsumerSpec;
@@ -39,9 +40,7 @@ import javax.annotation.Nullable;
 import java.util.List;
 import java.util.concurrent.ScheduledExecutorService;
 
-import static org.apache.flink.runtime.io.network.partition.hybrid.tiered.common.TieredStorageUtils.buildBufferCompressor;
 import static org.apache.flink.runtime.io.network.partition.hybrid.tiered.common.TieredStorageUtils.getMemoryTierName;
-import static org.apache.flink.util.Preconditions.checkNotNull;
 import static org.apache.flink.util.Preconditions.checkState;
 
 /** The implementation of {@link TierFactory} for memory tier. */
@@ -55,12 +54,9 @@ public class MemoryTierFactory implements TierFactory {
 
     private int bufferSizeBytes = -1;
 
-    @Nullable private Configuration conf;
-
     @Override
     public void setup(Configuration configuration) {
         this.bufferSizeBytes = ConfigurationParserUtils.getPageSize(configuration);
-        this.conf = checkNotNull(configuration);
     }
 
     @Override
@@ -98,7 +94,8 @@ public class MemoryTierFactory implements TierFactory {
             BatchShuffleReadBufferPool bufferPool,
             ScheduledExecutorService ioExecutor,
             List<TierShuffleDescriptor> shuffleDescriptors,
-            int maxRequestedBuffers) {
+            int maxRequestedBuffers,
+            @Nullable BufferCompressor bufferCompressor) {
         checkState(bufferSizeBytes > 0);
 
         return new MemoryTierProducerAgent(
@@ -111,7 +108,7 @@ public class MemoryTierFactory implements TierFactory {
                 memoryManager,
                 nettyService,
                 resourceRegistry,
-                buildBufferCompressor(bufferSizeBytes, checkNotNull(conf)));
+                bufferCompressor);
     }
 
     @Override
@@ -121,4 +118,9 @@ public class MemoryTierFactory implements TierFactory {
             TieredStorageNettyService nettyService) {
         return new MemoryTierConsumerAgent(tieredStorageConsumerSpecs, nettyService);
     }
+
+    @Override
+    public String identifier() {
+        return "memory";
+    }
 }
