@@ -21,7 +21,6 @@ package org.apache.flink.runtime.metrics.groups;
 import org.apache.flink.annotation.Internal;
 import org.apache.flink.api.common.JobID;
 import org.apache.flink.runtime.executiongraph.ExecutionAttemptID;
-import org.apache.flink.runtime.jobgraph.JobVertexID;
 import org.apache.flink.runtime.metrics.MetricRegistry;
 
 import javax.annotation.Nullable;
@@ -29,7 +28,9 @@ import javax.annotation.Nullable;
 import java.util.HashMap;
 import java.util.Map;
 
+import static java.lang.Thread.holdsLock;
 import static org.apache.flink.util.Preconditions.checkNotNull;
+import static org.apache.flink.util.Preconditions.checkState;
 
 /**
  * Special {@link org.apache.flink.metrics.MetricGroup} representing everything belonging to a
@@ -45,7 +46,7 @@ public class TaskManagerJobMetricGroup extends JobMetricGroup<TaskManagerMetricG
 
     // ------------------------------------------------------------------------
 
-    TaskManagerJobMetricGroup(
+    public TaskManagerJobMetricGroup(
             MetricRegistry registry,
             TaskManagerMetricGroup parent,
             JobID jobId,
@@ -69,12 +70,7 @@ public class TaskManagerJobMetricGroup extends JobMetricGroup<TaskManagerMetricG
     // ------------------------------------------------------------------------
 
     public TaskMetricGroup addTask(
-            final JobVertexID jobVertexId,
-            final ExecutionAttemptID executionAttemptID,
-            final String taskName,
-            final int subtaskIndex,
-            final int attemptNumber) {
-        checkNotNull(jobVertexId);
+            final ExecutionAttemptID executionAttemptID, final String taskName) {
         checkNotNull(executionAttemptID);
         checkNotNull(taskName);
 
@@ -85,14 +81,7 @@ public class TaskManagerJobMetricGroup extends JobMetricGroup<TaskManagerMetricG
                     return prior;
                 } else {
                     TaskMetricGroup task =
-                            new TaskMetricGroup(
-                                    registry,
-                                    this,
-                                    jobVertexId,
-                                    executionAttemptID,
-                                    taskName,
-                                    subtaskIndex,
-                                    attemptNumber);
+                            new TaskMetricGroup(registry, this, executionAttemptID, taskName);
                     tasks.put(executionAttemptID, task);
                     return task;
                 }
@@ -105,20 +94,15 @@ public class TaskManagerJobMetricGroup extends JobMetricGroup<TaskManagerMetricG
     public void removeTaskMetricGroup(ExecutionAttemptID executionId) {
         checkNotNull(executionId);
 
-        boolean removeFromParent = false;
+        // this can be a call from this.close which iterates over tasks
+        // changing tasks here would break iteration
         synchronized (this) {
-            if (!isClosed() && tasks.remove(executionId) != null && tasks.isEmpty()) {
-                // this call removed the last task. close this group.
-                removeFromParent = true;
-                close();
+            if (!isClosed()) {
+                tasks.remove(executionId);
+                // keep this group open even if tasks is empty - to re-use on new task submission
+                // the group will be closed by TM with the release of the last job slot on this TM
             }
         }
-
-        // IMPORTANT: removing from the parent must not happen while holding the this group's lock,
-        //      because it would violate the "first parent then subgroup" lock acquisition order
-        if (removeFromParent) {
-            parent.removeJobMetricsGroup(jobId, this);
-        }
     }
 
     // ------------------------------------------------------------------------
@@ -126,7 +110,8 @@ public class TaskManagerJobMetricGroup extends JobMetricGroup<TaskManagerMetricG
     // ------------------------------------------------------------------------
 
     @Override
-    protected Iterable<? extends ComponentMetricGroup> subComponents() {
+    protected Iterable<? extends ComponentMetricGroup<?>> subComponents() {
+        checkState(holdsLock(this));
         return tasks.values();
     }
 }
