@@ -30,7 +30,8 @@ import org.apache.flink.runtime.checkpoint.SnapshotType;
 import org.apache.flink.runtime.query.TaskKvStateRegistry;
 import org.apache.flink.runtime.state.internal.InternalKvState;
 import org.apache.flink.runtime.state.metrics.LatencyTrackingStateConfig;
-import org.apache.flink.runtime.state.metrics.LatencyTrackingStateFactory;
+import org.apache.flink.runtime.state.metrics.MetricsTrackingStateFactory;
+import org.apache.flink.runtime.state.metrics.SizeTrackingStateConfig;
 import org.apache.flink.runtime.state.ttl.TtlStateFactory;
 import org.apache.flink.runtime.state.ttl.TtlTimeProvider;
 import org.apache.flink.util.IOUtils;
@@ -93,6 +94,8 @@ public abstract class AbstractKeyedStateBackend<K>
 
     protected final LatencyTrackingStateConfig latencyTrackingStateConfig;
 
+    protected final SizeTrackingStateConfig sizeTrackingStateConfig;
+
     /** Decorates the input and output streams to write key-groups compressed. */
     protected final StreamCompressionDecorator keyGroupCompressionDecorator;
 
@@ -106,6 +109,7 @@ public abstract class AbstractKeyedStateBackend<K>
             ExecutionConfig executionConfig,
             TtlTimeProvider ttlTimeProvider,
             LatencyTrackingStateConfig latencyTrackingStateConfig,
+            SizeTrackingStateConfig sizeTrackingStateConfig,
             CloseableRegistry cancelStreamRegistry,
             InternalKeyContext<K> keyContext) {
         this(
@@ -115,6 +119,7 @@ public abstract class AbstractKeyedStateBackend<K>
                 executionConfig,
                 ttlTimeProvider,
                 latencyTrackingStateConfig,
+                sizeTrackingStateConfig,
                 cancelStreamRegistry,
                 determineStreamCompression(executionConfig),
                 keyContext);
@@ -127,6 +132,7 @@ public abstract class AbstractKeyedStateBackend<K>
             ExecutionConfig executionConfig,
             TtlTimeProvider ttlTimeProvider,
             LatencyTrackingStateConfig latencyTrackingStateConfig,
+            SizeTrackingStateConfig sizeTrackingStateConfig,
             CloseableRegistry cancelStreamRegistry,
             StreamCompressionDecorator keyGroupCompressionDecorator,
             InternalKeyContext<K> keyContext) {
@@ -137,6 +143,7 @@ public abstract class AbstractKeyedStateBackend<K>
                 executionConfig,
                 ttlTimeProvider,
                 latencyTrackingStateConfig,
+                sizeTrackingStateConfig,
                 cancelStreamRegistry,
                 keyGroupCompressionDecorator,
                 Preconditions.checkNotNull(keyContext),
@@ -157,6 +164,7 @@ public abstract class AbstractKeyedStateBackend<K>
                 abstractKeyedStateBackend.executionConfig,
                 abstractKeyedStateBackend.ttlTimeProvider,
                 abstractKeyedStateBackend.latencyTrackingStateConfig,
+                abstractKeyedStateBackend.sizeTrackingStateConfig,
                 abstractKeyedStateBackend.cancelStreamRegistry,
                 abstractKeyedStateBackend.keyGroupCompressionDecorator,
                 abstractKeyedStateBackend.keyContext,
@@ -176,6 +184,7 @@ public abstract class AbstractKeyedStateBackend<K>
             ExecutionConfig executionConfig,
             TtlTimeProvider ttlTimeProvider,
             LatencyTrackingStateConfig latencyTrackingStateConfig,
+            SizeTrackingStateConfig sizeTrackingStateConfig,
             CloseableRegistry cancelStreamRegistry,
             StreamCompressionDecorator keyGroupCompressionDecorator,
             InternalKeyContext<K> keyContext,
@@ -206,6 +215,7 @@ public abstract class AbstractKeyedStateBackend<K>
         this.keyGroupCompressionDecorator = keyGroupCompressionDecorator;
         this.ttlTimeProvider = Preconditions.checkNotNull(ttlTimeProvider);
         this.latencyTrackingStateConfig = Preconditions.checkNotNull(latencyTrackingStateConfig);
+        this.sizeTrackingStateConfig = Preconditions.checkNotNull(sizeTrackingStateConfig);
         this.keySelectionListeners = keySelectionListeners;
         this.lastState = lastState;
         this.lastName = lastName;
@@ -380,11 +390,13 @@ public abstract class AbstractKeyedStateBackend<K>
                 stateDescriptor.initializeSerializerUnlessSet(executionConfig);
             }
             kvState =
-                    LatencyTrackingStateFactory.createStateAndWrapWithLatencyTrackingIfEnabled(
+                    MetricsTrackingStateFactory.createStateAndWrapWithMetricsTrackingIfEnabled(
                             TtlStateFactory.createStateAndWrapWithTtlIfEnabled(
                                     namespaceSerializer, stateDescriptor, this, ttlTimeProvider),
+                            this,
                             stateDescriptor,
-                            latencyTrackingStateConfig);
+                            latencyTrackingStateConfig,
+                            sizeTrackingStateConfig);
             keyValueStatesByName.put(stateDescriptor.getName(), kvState);
             publishQueryableStateIfEnabled(stateDescriptor, kvState);
         }
@@ -451,6 +463,10 @@ public abstract class AbstractKeyedStateBackend<K>
         return latencyTrackingStateConfig;
     }
 
+    public SizeTrackingStateConfig getSizeTrackingStateConfig() {
+        return sizeTrackingStateConfig;
+    }
+
     @VisibleForTesting
     public StreamCompressionDecorator getKeyGroupCompressionDecorator() {
         return keyGroupCompressionDecorator;
