@@ -30,6 +30,7 @@ import java.util.List;
 import java.util.function.BiConsumer;
 import java.util.function.Consumer;
 import java.util.function.Function;
+import java.util.function.Supplier;
 
 /** Test implementation for {@link TieredStorageMemoryManager}. */
 public class TestingTieredStorageMemoryManager implements TieredStorageMemoryManager {
@@ -38,6 +39,8 @@ public class TestingTieredStorageMemoryManager implements TieredStorageMemoryMan
 
     private final Consumer<TaskIOMetricGroup> setMetricGroupConsumer;
 
+    private final Supplier<BufferPool> bufferPoolSupplier;
+
     private final Consumer<Runnable> listenBufferReclaimRequestConsumer;
 
     private final Function<Object, BufferBuilder> requestBufferBlockingFunction;
@@ -55,6 +58,7 @@ public class TestingTieredStorageMemoryManager implements TieredStorageMemoryMan
     private TestingTieredStorageMemoryManager(
             BiConsumer<BufferPool, List<TieredStorageMemorySpec>> setupConsumer,
             Consumer<TaskIOMetricGroup> setMetricGroupConsumer,
+            Supplier<BufferPool> bufferPoolSupplier,
             Consumer<Runnable> listenBufferReclaimRequestConsumer,
             Function<Object, BufferBuilder> requestBufferBlockingFunction,
             Function<Object, Integer> getMaxNonReclaimableBuffersFunction,
@@ -64,6 +68,7 @@ public class TestingTieredStorageMemoryManager implements TieredStorageMemoryMan
             Runnable releaseRunnable) {
         this.setupConsumer = setupConsumer;
         this.setMetricGroupConsumer = setMetricGroupConsumer;
+        this.bufferPoolSupplier = bufferPoolSupplier;
         this.listenBufferReclaimRequestConsumer = listenBufferReclaimRequestConsumer;
         this.requestBufferBlockingFunction = requestBufferBlockingFunction;
         this.getMaxNonReclaimableBuffersFunction = getMaxNonReclaimableBuffersFunction;
@@ -83,6 +88,11 @@ public class TestingTieredStorageMemoryManager implements TieredStorageMemoryMan
         setMetricGroupConsumer.accept(metricGroup);
     }
 
+    @Override
+    public BufferPool getBufferPool() {
+        return bufferPoolSupplier.get();
+    }
+
     @Override
     public void listenBufferReclaimRequest(Runnable onBufferReclaimRequest) {
         listenBufferReclaimRequestConsumer.accept(onBufferReclaimRequest);
@@ -126,6 +136,8 @@ public class TestingTieredStorageMemoryManager implements TieredStorageMemoryMan
 
         private Consumer<TaskIOMetricGroup> setMetricGroupConsumer = (ignore) -> {};
 
+        private Supplier<BufferPool> bufferPoolSupplier = () -> null;
+
         private Consumer<Runnable> listenBufferReclaimRequestConsumer = runnable -> {};
 
         private Function<Object, BufferBuilder> requestBufferBlockingFunction = owner -> null;
@@ -149,6 +161,12 @@ public class TestingTieredStorageMemoryManager implements TieredStorageMemoryMan
             return this;
         }
 
+        public TestingTieredStorageMemoryManager.Builder setBufferPoolSupplier(
+                Supplier<BufferPool> bufferPoolSupplier) {
+            this.bufferPoolSupplier = bufferPoolSupplier;
+            return this;
+        }
+
         public TestingTieredStorageMemoryManager.Builder setListenBufferReclaimRequestConsumer(
                 Consumer<Runnable> listenBufferReclaimRequestConsumer) {
             this.listenBufferReclaimRequestConsumer = listenBufferReclaimRequestConsumer;
@@ -195,6 +213,7 @@ public class TestingTieredStorageMemoryManager implements TieredStorageMemoryMan
             return new TestingTieredStorageMemoryManager(
                     setupConsumer,
                     setMetricGroupConsumer,
+                    bufferPoolSupplier,
                     listenBufferReclaimRequestConsumer,
                     requestBufferBlockingFunction,
                     getMaxNonReclaimableBuffersFunction,
