@@ -1323,12 +1323,12 @@ class DefaultLeaderElectionServiceTest {
             assertThatFuture(confirmLeadershipFuture).eventuallySucceeds();
 
             assertThat(contenderLeadership).isFalse();
-            assertThat(leaderInformationStorage.get().forComponentId(componentId).isPresent())
+            assertThat(leaderInformationStorage.get().forComponentId(componentId).isEmpty())
                     .as(
                             "The LeaderInformation is empty because the leadership confirmation succeeded the "
                                     + "leadership revocation which resulted in no leader information being written out to "
                                     + "the HA backend.")
-                    .isFalse();
+                    .isTrue();
 
             // not closing the LeaderElection instance would leave the DefaultLeaderElectionService
             // in an inconsistent state causing an error when closing the service
