@@ -42,6 +42,7 @@ import org.apache.flink.runtime.io.network.api.writer.RecordCollectingResultPart
 import org.apache.flink.runtime.io.network.api.writer.ResultPartitionWriter;
 import org.apache.flink.runtime.io.network.partition.consumer.IndexedInputGate;
 import org.apache.flink.runtime.io.network.partition.consumer.IteratorWrappingTestSingleInputGate;
+import org.apache.flink.runtime.jobgraph.JobType;
 import org.apache.flink.runtime.jobgraph.JobVertexID;
 import org.apache.flink.runtime.jobgraph.tasks.InputSplitProvider;
 import org.apache.flink.runtime.jobgraph.tasks.TaskOperatorEventGateway;
@@ -71,6 +72,7 @@ import java.util.Map;
 import java.util.Optional;
 import java.util.concurrent.ExecutorService;
 import java.util.concurrent.Future;
+import java.util.function.Consumer;
 
 import static org.apache.flink.runtime.executiongraph.ExecutionGraphTestUtils.createExecutionAttemptId;
 import static org.apache.flink.util.Preconditions.checkArgument;
@@ -85,6 +87,8 @@ public class MockEnvironment implements Environment, AutoCloseable {
 
     private final TaskInfo taskInfo;
 
+    private final JobType jobType;
+
     private final ExecutionConfig executionConfig;
 
     private final MemoryManager memManager;
@@ -131,6 +135,8 @@ public class MockEnvironment implements Environment, AutoCloseable {
 
     private Optional<? extends Throwable> actualExternalFailureCause = Optional.empty();
 
+    private Optional<Consumer<Throwable>> externalFailureCauseConsumer = Optional.empty();
+
     private final TaskMetricGroup taskMetricGroup;
 
     private final ExternalResourceInfoProvider externalResourceInfoProvider;
@@ -149,7 +155,9 @@ public class MockEnvironment implements Environment, AutoCloseable {
 
     protected MockEnvironment(
             JobID jobID,
+            String jobName,
             JobVertexID jobVertexID,
+            JobType jobType,
             String taskName,
             MockInputSplitProvider inputSplitProvider,
             int bufferSize,
@@ -168,9 +176,9 @@ public class MockEnvironment implements Environment, AutoCloseable {
             ExternalResourceInfoProvider externalResourceInfoProvider,
             ChannelStateWriteRequestExecutorFactory channelStateExecutorFactory) {
 
-        this.jobInfo = new JobInfoImpl(jobID, "MockJob");
+        this.jobInfo = new JobInfoImpl(jobID, jobName);
         this.jobVertexID = jobVertexID;
-
+        this.jobType = jobType;
         this.taskInfo = new TaskInfoImpl(taskName, maxParallelism, subtaskIndex, parallelism, 0);
         this.jobConfiguration = new Configuration();
         this.taskConfiguration = taskConfiguration;
@@ -269,6 +277,11 @@ public class MockEnvironment implements Environment, AutoCloseable {
         return this.jobInfo.getJobId();
     }
 
+    @Override
+    public JobType getJobType() {
+        return jobType;
+    }
+
     @Override
     public Configuration getJobConfiguration() {
         return this.jobConfiguration;
@@ -403,6 +416,11 @@ public class MockEnvironment implements Environment, AutoCloseable {
 
     @Override
     public void failExternally(Throwable cause) {
+        if (externalFailureCauseConsumer.isPresent()) {
+            externalFailureCauseConsumer.get().accept(cause);
+            return;
+        }
+
         if (!expectedExternalFailureCause.isPresent()) {
             throw new UnsupportedOperationException(
                     "MockEnvironment does not support external task failure.");
@@ -473,4 +491,8 @@ public class MockEnvironment implements Environment, AutoCloseable {
     public Optional<? extends Throwable> getActualExternalFailureCause() {
         return actualExternalFailureCause;
     }
+
+    public void setExternalFailureCauseConsumer(Consumer<Throwable> externalFailureCauseConsumer) {
+        this.externalFailureCauseConsumer = Optional.of(externalFailureCauseConsumer);
+    }
 }
