@@ -17,7 +17,6 @@
 
 package org.apache.flink.runtime.scheduler.adaptive;
 
-import org.apache.flink.api.common.time.Time;
 import org.apache.flink.configuration.Configuration;
 import org.apache.flink.configuration.DeploymentOptions;
 import org.apache.flink.configuration.JobManagerOptions;
@@ -26,7 +25,10 @@ import org.apache.flink.core.failure.FailureEnricher;
 import org.apache.flink.runtime.blob.BlobWriter;
 import org.apache.flink.runtime.blob.VoidBlobWriter;
 import org.apache.flink.runtime.checkpoint.CheckpointRecoveryFactory;
+import org.apache.flink.runtime.checkpoint.CheckpointStatsListener;
+import org.apache.flink.runtime.checkpoint.CheckpointStatsTracker;
 import org.apache.flink.runtime.checkpoint.CheckpointsCleaner;
+import org.apache.flink.runtime.checkpoint.DefaultCheckpointStatsTracker;
 import org.apache.flink.runtime.checkpoint.StandaloneCheckpointRecoveryFactory;
 import org.apache.flink.runtime.concurrent.ComponentMainThreadExecutor;
 import org.apache.flink.runtime.executiongraph.JobStatusListener;
@@ -52,14 +54,16 @@ import org.apache.flink.util.FatalExitExceptionHandler;
 
 import javax.annotation.Nullable;
 
+import java.time.Duration;
 import java.util.Collection;
 import java.util.Collections;
 import java.util.concurrent.ScheduledExecutorService;
+import java.util.function.BiFunction;
 import java.util.function.Function;
 
 /** Builder for {@link AdaptiveScheduler}. */
 public class AdaptiveSchedulerBuilder {
-    private static final Time DEFAULT_TIMEOUT = Time.seconds(300);
+    private static final Duration DEFAULT_TIMEOUT = Duration.ofSeconds(300);
 
     private final JobGraph jobGraph;
 
@@ -74,7 +78,7 @@ public class AdaptiveSchedulerBuilder {
     private CheckpointRecoveryFactory checkpointRecoveryFactory =
             new StandaloneCheckpointRecoveryFactory();
     private DeclarativeSlotPool declarativeSlotPool;
-    private Time rpcTimeout = DEFAULT_TIMEOUT;
+    private Duration rpcTimeout = DEFAULT_TIMEOUT;
     private BlobWriter blobWriter = VoidBlobWriter.getInstance();
     private JobManagerJobMetricGroup jobManagerJobMetricGroup =
             UnregisteredMetricGroups.createUnregisteredJobManagerJobMetricGroup();
@@ -92,6 +96,18 @@ public class AdaptiveSchedulerBuilder {
 
     @Nullable private SlotAllocator slotAllocator;
 
+    /**
+     * {@code null} indicates that the default factory will be used based on the set configuration.
+     */
+    @Nullable
+    private AdaptiveScheduler.StateTransitionManagerFactory stateTransitionManagerFactory = null;
+
+    private BiFunction<JobManagerJobMetricGroup, CheckpointStatsListener, CheckpointStatsTracker>
+            checkpointStatsTrackerFactory =
+                    (metricGroup, checkpointStatsListener) ->
+                            new DefaultCheckpointStatsTracker(
+                                    10, metricGroup, checkpointStatsListener);
+
     public AdaptiveSchedulerBuilder(
             final JobGraph jobGraph,
             ComponentMainThreadExecutor mainThreadExecutor,
@@ -105,7 +121,9 @@ public class AdaptiveSchedulerBuilder {
                         new DefaultAllocatedSlotPool(),
                         ignored -> {},
                         DEFAULT_TIMEOUT,
-                        rpcTimeout);
+                        rpcTimeout,
+                        Duration.ZERO,
+                        mainThreadExecutor);
         this.executorService = executorService;
     }
 
@@ -144,7 +162,7 @@ public class AdaptiveSchedulerBuilder {
         return this;
     }
 
-    public AdaptiveSchedulerBuilder setRpcTimeout(final Time rpcTimeout) {
+    public AdaptiveSchedulerBuilder setRpcTimeout(final Duration rpcTimeout) {
         this.rpcTimeout = rpcTimeout;
         return this;
     }
@@ -209,6 +227,24 @@ public class AdaptiveSchedulerBuilder {
         return this;
     }
 
+    public AdaptiveSchedulerBuilder setStateTransitionManagerFactory(
+            @Nullable
+                    AdaptiveScheduler.StateTransitionManagerFactory stateTransitionManagerFactory) {
+        this.stateTransitionManagerFactory = stateTransitionManagerFactory;
+        return this;
+    }
+
+    public AdaptiveSchedulerBuilder setCheckpointStatsTrackerFactory(
+            @Nullable
+                    BiFunction<
+                                    JobManagerJobMetricGroup,
+                                    CheckpointStatsListener,
+                                    CheckpointStatsTracker>
+                            checkpointStatsTrackerFactory) {
+        this.checkpointStatsTrackerFactory = checkpointStatsTrackerFactory;
+        return this;
+    }
+
     public AdaptiveScheduler build() throws Exception {
         final ExecutionGraphFactory executionGraphFactory =
                 new DefaultExecutionGraphFactory(
@@ -223,8 +259,14 @@ public class AdaptiveSchedulerBuilder {
                         shuffleMaster,
                         partitionTracker);
 
+        final AdaptiveScheduler.Settings settings =
+                AdaptiveScheduler.Settings.of(jobMasterConfiguration);
         return new AdaptiveScheduler(
-                AdaptiveScheduler.Settings.of(jobMasterConfiguration),
+                settings,
+                stateTransitionManagerFactory == null
+                        ? DefaultStateTransitionManager::new
+                        : stateTransitionManagerFactory,
+                checkpointStatsTrackerFactory,
                 jobGraph,
                 jobResourceRequirements,
                 jobMasterConfiguration,
