@@ -18,9 +18,7 @@
 
 package org.apache.flink.runtime.shuffle;
 
-import org.apache.flink.api.common.ExecutionConfig;
 import org.apache.flink.api.common.JobID;
-import org.apache.flink.api.common.time.Time;
 import org.apache.flink.configuration.Configuration;
 import org.apache.flink.runtime.io.network.NettyShuffleServiceFactory;
 import org.apache.flink.runtime.io.network.partition.ResultPartitionID;
@@ -32,10 +30,12 @@ import org.apache.flink.runtime.jobgraph.JobVertex;
 import org.apache.flink.runtime.minicluster.MiniCluster;
 import org.apache.flink.runtime.minicluster.MiniClusterConfiguration;
 import org.apache.flink.runtime.testtasks.NoOpInvokable;
+import org.apache.flink.streaming.util.RestartStrategyUtils;
 
 import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.Test;
 
+import java.time.Duration;
 import java.util.Collections;
 import java.util.concurrent.BlockingQueue;
 import java.util.concurrent.CompletableFuture;
@@ -43,7 +43,8 @@ import java.util.concurrent.LinkedBlockingQueue;
 import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.concurrent.atomic.AtomicReference;
 
-import static org.apache.flink.api.common.restartstrategy.RestartStrategies.fixedDelayRestart;
+import static org.apache.flink.configuration.ConfigurationUtils.getBooleanConfigOption;
+import static org.apache.flink.runtime.util.JobVertexConnectionUtils.connectNewDataSetAsInput;
 import static org.assertj.core.api.Assertions.assertThat;
 
 /** Tests for {@link ShuffleMaster}. */
@@ -97,7 +98,8 @@ class ShuffleMasterTest {
         configuration.set(
                 ShuffleServiceOptions.SHUFFLE_SERVICE_FACTORY_CLASS,
                 TestShuffleServiceFactory.class.getName());
-        configuration.setBoolean(STOP_TRACKING_PARTITION_KEY, stopTrackingPartition);
+        configuration.set(
+                getBooleanConfigOption(STOP_TRACKING_PARTITION_KEY), stopTrackingPartition);
         return new MiniClusterConfiguration.Builder()
                 .withRandomPorts()
                 .setNumTaskManagers(1)
@@ -115,13 +117,11 @@ class ShuffleMasterTest {
         sink.setParallelism(2);
         sink.setInvokableClass(NoOpInvokable.class);
 
-        sink.connectNewDataSetAsInput(
-                source, DistributionPattern.ALL_TO_ALL, ResultPartitionType.BLOCKING);
+        connectNewDataSetAsInput(
+                sink, source, DistributionPattern.ALL_TO_ALL, ResultPartitionType.BLOCKING);
 
         JobGraph jobGraph = JobGraphTestUtils.batchJobGraph(source, sink);
-        ExecutionConfig config = new ExecutionConfig();
-        config.setRestartStrategy(fixedDelayRestart(2, Time.seconds(2)));
-        jobGraph.setExecutionConfig(config);
+        RestartStrategyUtils.configureFixedDelayRestartStrategy(jobGraph, 2, Duration.ofSeconds(2));
         return jobGraph;
     }
 
@@ -153,7 +153,8 @@ class ShuffleMasterTest {
 
         public TestShuffleMaster(Configuration conf) {
             super(new ShuffleMasterContextImpl(conf, throwable -> {}));
-            this.stopTrackingPartition = conf.getBoolean(STOP_TRACKING_PARTITION_KEY, false);
+            this.stopTrackingPartition =
+                    conf.get(getBooleanConfigOption(STOP_TRACKING_PARTITION_KEY), false);
             currentInstance.set(this);
         }
 
