@@ -20,11 +20,10 @@ package org.apache.flink.state.forst;
 import org.apache.flink.annotation.VisibleForTesting;
 import org.apache.flink.api.common.ExecutionConfig;
 import org.apache.flink.api.common.state.v2.AggregatingStateDescriptor;
-import org.apache.flink.api.common.state.v2.ListStateDescriptor;
+import org.apache.flink.api.common.state.v2.MapStateDescriptor;
 import org.apache.flink.api.common.state.v2.ReducingStateDescriptor;
 import org.apache.flink.api.common.state.v2.State;
 import org.apache.flink.api.common.state.v2.StateDescriptor;
-import org.apache.flink.api.common.state.v2.ValueStateDescriptor;
 import org.apache.flink.api.common.typeutils.TypeSerializer;
 import org.apache.flink.api.common.typeutils.TypeSerializerSchemaCompatibility;
 import org.apache.flink.api.java.tuple.Tuple2;
@@ -48,11 +47,11 @@ import org.apache.flink.runtime.state.PriorityQueueSetFactory;
 import org.apache.flink.runtime.state.SerializedCompositeKeyBuilder;
 import org.apache.flink.runtime.state.SnapshotResult;
 import org.apache.flink.runtime.state.SnapshotStrategyRunner;
-import org.apache.flink.runtime.state.StateSnapshotTransformer;
 import org.apache.flink.runtime.state.heap.HeapPriorityQueueElement;
 import org.apache.flink.runtime.state.heap.HeapPriorityQueueSetFactory;
 import org.apache.flink.runtime.state.heap.HeapPriorityQueueSnapshotRestoreWrapper;
 import org.apache.flink.runtime.state.ttl.TtlTimeProvider;
+import org.apache.flink.runtime.state.v2.RegisteredKeyAndUserKeyValueStateBackendMetaInfo;
 import org.apache.flink.runtime.state.v2.RegisteredKeyValueStateBackendMetaInfo;
 import org.apache.flink.runtime.state.v2.internal.InternalKeyedState;
 import org.apache.flink.runtime.state.v2.ttl.TtlStateFactory;
@@ -299,7 +298,7 @@ public class ForStKeyedStateBackend<K> implements AsyncKeyedStateBackend<K> {
                         new ForStValueState<>(
                                 stateRequestHandler,
                                 columnFamilyHandle,
-                                (ValueStateDescriptor<SV>) stateDesc,
+                                registerResult.f1.getStateSerializer(),
                                 serializedKeyBuilder,
                                 defaultNamespace,
                                 namespaceSerializer::duplicate,
@@ -311,7 +310,7 @@ public class ForStKeyedStateBackend<K> implements AsyncKeyedStateBackend<K> {
                         new ForStListState<>(
                                 stateRequestHandler,
                                 columnFamilyHandle,
-                                (ListStateDescriptor<SV>) stateDesc,
+                                registerResult.f1.getStateSerializer(),
                                 serializedKeyBuilder,
                                 defaultNamespace,
                                 namespaceSerializer::duplicate,
@@ -319,23 +318,28 @@ public class ForStKeyedStateBackend<K> implements AsyncKeyedStateBackend<K> {
                                 valueDeserializerView);
             case MAP:
                 Supplier<DataInputDeserializer> keyDeserializerView = DataInputDeserializer::new;
-                return ForStMapState.create(
-                        stateDesc,
-                        stateRequestHandler,
-                        columnFamilyHandle,
-                        serializedKeyBuilder,
-                        defaultNamespace,
-                        namespaceSerializer::duplicate,
-                        valueSerializerView,
-                        keyDeserializerView,
-                        valueDeserializerView,
-                        keyGroupPrefixBytes);
+                RegisteredKeyAndUserKeyValueStateBackendMetaInfo mapStateMetaInfo =
+                        (RegisteredKeyAndUserKeyValueStateBackendMetaInfo) registerResult.f1;
+                return (S)
+                        ForStMapState.create(
+                                mapStateMetaInfo.getUserKeySerializer(),
+                                mapStateMetaInfo.getStateSerializer(),
+                                stateRequestHandler,
+                                columnFamilyHandle,
+                                serializedKeyBuilder,
+                                defaultNamespace,
+                                namespaceSerializer::duplicate,
+                                valueSerializerView,
+                                keyDeserializerView,
+                                valueDeserializerView,
+                                keyGroupPrefixBytes);
             case REDUCING:
                 return (S)
                         new ForStReducingState<>(
                                 stateRequestHandler,
                                 columnFamilyHandle,
-                                (ReducingStateDescriptor<SV>) stateDesc,
+                                ((ReducingStateDescriptor<SV>) stateDesc).getReduceFunction(),
+                                registerResult.f1.getStateSerializer(),
                                 serializedKeyBuilder,
                                 defaultNamespace,
                                 namespaceSerializer::duplicate,
@@ -344,7 +348,9 @@ public class ForStKeyedStateBackend<K> implements AsyncKeyedStateBackend<K> {
             case AGGREGATING:
                 return (S)
                         new ForStAggregatingState<>(
-                                (AggregatingStateDescriptor<?, SV, ?>) stateDesc,
+                                ((AggregatingStateDescriptor<?, SV, ?>) stateDesc)
+                                        .getAggregateFunction(),
+                                registerResult.f1.getStateSerializer(),
                                 stateRequestHandler,
                                 columnFamilyHandle,
                                 serializedKeyBuilder,
@@ -369,6 +375,11 @@ public class ForStKeyedStateBackend<K> implements AsyncKeyedStateBackend<K> {
 
         TypeSerializer<SV> stateSerializer = stateDesc.getSerializer();
 
+        TypeSerializer<?> userKeySerializer =
+                stateDesc instanceof MapStateDescriptor
+                        ? ((MapStateDescriptor<?, SV>) stateDesc).getUserKeySerializer()
+                        : null;
+
         ForStOperationUtils.ForStKvStateInfo newStateInfo;
         RegisteredKeyValueStateBackendMetaInfo<N, SV> newMetaInfo;
         if (oldStateInfo != null) {
@@ -381,6 +392,7 @@ public class ForStKeyedStateBackend<K> implements AsyncKeyedStateBackend<K> {
                             Tuple2.of(oldStateInfo.columnFamilyHandle, castedMetaInfo),
                             stateDesc,
                             stateSerializer,
+                            userKeySerializer,
                             namespaceSerializer);
 
             newStateInfo =
@@ -388,13 +400,22 @@ public class ForStKeyedStateBackend<K> implements AsyncKeyedStateBackend<K> {
                             oldStateInfo.columnFamilyHandle, newMetaInfo);
             kvStateInformation.put(stateDesc.getStateId(), newStateInfo);
         } else {
-            newMetaInfo =
-                    new RegisteredKeyValueStateBackendMetaInfo<>(
-                            stateDesc.getStateId(),
-                            stateDesc.getType(),
-                            namespaceSerializer,
-                            stateSerializer,
-                            StateSnapshotTransformer.StateSnapshotTransformFactory.noTransform());
+            if (stateDesc.getType().equals(StateDescriptor.Type.MAP)) {
+                newMetaInfo =
+                        new RegisteredKeyAndUserKeyValueStateBackendMetaInfo<>(
+                                stateDesc.getStateId(),
+                                stateDesc.getType(),
+                                namespaceSerializer,
+                                stateSerializer,
+                                userKeySerializer);
+            } else {
+                newMetaInfo =
+                        new RegisteredKeyValueStateBackendMetaInfo<>(
+                                stateDesc.getStateId(),
+                                stateDesc.getType(),
+                                namespaceSerializer,
+                                stateSerializer);
+            }
 
             newStateInfo =
                     ForStOperationUtils.createStateInfo(
@@ -414,15 +435,32 @@ public class ForStKeyedStateBackend<K> implements AsyncKeyedStateBackend<K> {
         return Tuple2.of(newStateInfo.columnFamilyHandle, newMetaInfo);
     }
 
-    private <N, SV> RegisteredKeyValueStateBackendMetaInfo<N, SV> updateRestoredStateMetaInfo(
+    private <N, UK, SV> RegisteredKeyValueStateBackendMetaInfo<N, SV> updateRestoredStateMetaInfo(
             Tuple2<ColumnFamilyHandle, RegisteredKeyValueStateBackendMetaInfo<N, SV>> oldStateInfo,
             StateDescriptor<SV> stateDesc,
             TypeSerializer<SV> stateSerializer,
+            TypeSerializer<UK> userKeySerializer,
             TypeSerializer<N> namespaceSerializer)
             throws Exception {
 
         RegisteredKeyValueStateBackendMetaInfo<N, SV> restoredKvStateMetaInfo = oldStateInfo.f1;
 
+        // fetch current namespace serializer now because if it is incompatible, we can't access
+        // it anymore to improve the error message
+        TypeSerializer<N> previousNamespaceSerializer =
+                restoredKvStateMetaInfo.getNamespaceSerializer();
+
+        TypeSerializerSchemaCompatibility<N> s =
+                restoredKvStateMetaInfo.updateNamespaceSerializer(namespaceSerializer);
+        if (s.isCompatibleAfterMigration() || s.isIncompatible()) {
+            throw new StateMigrationException(
+                    "The new namespace serializer ("
+                            + namespaceSerializer
+                            + ") must be compatible with the old namespace serializer ("
+                            + previousNamespaceSerializer
+                            + ").");
+        }
+
         restoredKvStateMetaInfo.checkStateMetaInfo(stateDesc);
 
         // fetch current serializer now because if it is incompatible, we can't access it anymore to
@@ -447,6 +485,17 @@ public class ForStKeyedStateBackend<K> implements AsyncKeyedStateBackend<K> {
                             + ").");
         }
 
+        if (userKeySerializer != null) {
+            TypeSerializerSchemaCompatibility<UK> userKeySerializerCompatibility =
+                    ((RegisteredKeyAndUserKeyValueStateBackendMetaInfo<N, UK, SV>)
+                                    restoredKvStateMetaInfo)
+                            .updateUserKeySerializer(userKeySerializer);
+            if (!userKeySerializerCompatibility.isCompatibleAsIs()) {
+                throw new StateMigrationException(
+                        "The new serializer for a MapState requires state migration in order for the job to proceed. State migration not support yet.");
+            }
+        }
+
         return restoredKvStateMetaInfo;
     }
 
@@ -547,14 +596,18 @@ public class ForStKeyedStateBackend<K> implements AsyncKeyedStateBackend<K> {
                 IOUtils.closeQuietly(db);
 
                 LOG.info(
-                        "Closed ForSt State Backend. Cleaning up ForSt: {}.",
-                        optionsContainer.getPathContainer());
+                        "Closed ForSt State Backend. Cleaning up ForSt local working directory {}, remote working directory {}.",
+                        optionsContainer.getLocalBasePath(),
+                        optionsContainer.getRemoteBasePath());
 
                 try {
                     optionsContainer.clearDirectories();
                 } catch (Exception ex) {
                     LOG.warn(
-                            "Could not delete ForSt: {}.", optionsContainer.getPathContainer(), ex);
+                            "Could not delete ForSt local working directory {}, remote working directory {}.",
+                            optionsContainer.getLocalBasePath(),
+                            optionsContainer.getRemoteBasePath(),
+                            ex);
                 }
 
                 IOUtils.closeQuietly(optionsContainer);
@@ -571,12 +624,12 @@ public class ForStKeyedStateBackend<K> implements AsyncKeyedStateBackend<K> {
 
     @VisibleForTesting
     Path getLocalBasePath() {
-        return optionsContainer.getPathContainer().getLocalBasePath();
+        return optionsContainer.getLocalBasePath();
     }
 
     @VisibleForTesting
     Path getRemoteBasePath() {
-        return optionsContainer.getPathContainer().getRemoteBasePath();
+        return optionsContainer.getRemoteBasePath();
     }
 
     @Override
