@@ -302,7 +302,11 @@ public class ForStKeyedStateBackendBuilder<K>
                 //       deletion in file mapping manager.
                 optionsContainer.forceClearRemoteDirectories();
             } catch (Exception ex) {
-                logger.warn("Failed to delete ForSt: {}.", optionsContainer.getPathContainer(), ex);
+                logger.warn(
+                        "Failed to delete ForSt local base path {}, remote base path {}.",
+                        optionsContainer.getLocalBasePath(),
+                        optionsContainer.getRemoteBasePath(),
+                        ex);
             }
             IOUtils.closeQuietly(optionsContainer);
             IOUtils.closeQuietly(snapshotStrategy);
@@ -318,8 +322,9 @@ public class ForStKeyedStateBackendBuilder<K>
         InternalKeyContext<K> keyContext =
                 new InternalKeyContextImpl<>(keyGroupRange, numberOfKeyGroups);
         logger.info(
-                "Finished building ForSt keyed state-backend at {}",
-                optionsContainer.getPathContainer());
+                "Finished building ForSt keyed state-backend at local base path: {}, remote base path: {}.",
+                optionsContainer.getLocalBasePath(),
+                optionsContainer.getRemoteBasePath());
         return new ForStKeyedStateBackend<>(
                 backendUID,
                 executionConfig,
@@ -355,8 +360,8 @@ public class ForStKeyedStateBackendBuilder<K>
         // working dir. We will implement this in ForStDB later, but before that, we achieved this
         // by setting the dbPath to "/" when the dfs directory existed.
         Path instanceForStPath =
-                optionsContainer.getPathContainer().getRemoteForStPath() == null
-                        ? optionsContainer.getPathContainer().getLocalForStPath()
+                optionsContainer.getRemoteForStPath() == null
+                        ? optionsContainer.getLocalForStPath()
                         : new Path("/db");
 
         if (CollectionUtil.isEmptyOrAllElementsNull(restoreStateHandles)) {
@@ -397,7 +402,9 @@ public class ForStKeyedStateBackendBuilder<K>
                     overlapFractionThreshold,
                     useIngestDbRestoreMode,
                     rescalingUseDeleteFilesInRange,
-                    recoveryClaimMode);
+                    recoveryClaimMode,
+                    org.apache.flink.runtime.state.v2.RegisteredKeyValueStateBackendMetaInfo
+                            ::fromMetaInfoSnapshot);
         } else if (priorityQueueConfig.getPriorityQueueStateType()
                 == ForStStateBackend.PriorityQueueStateType.HEAP) {
             // Note: This branch can be touched after ForSt Support canonical savepoint,
