@@ -73,6 +73,8 @@ import static org.apache.flink.state.forst.ForStOptions.CACHE_SIZE_BASE_LIMIT;
 public final class ForStResourceContainer implements AutoCloseable {
     private static final Logger LOG = LoggerFactory.getLogger(ForStResourceContainer.class);
 
+    public static final String DB_DIR_STRING = "db";
+
     private static final String FORST_RELOCATE_LOG_SUFFIX = "_LOG";
 
     // the filename length limit is 255 on most operating systems
@@ -80,9 +82,13 @@ public final class ForStResourceContainer implements AutoCloseable {
     // and the db data dir's absolute path will be used as the log file name's prefix.
     private static final int INSTANCE_PATH_LENGTH_LIMIT = 255 - FORST_RELOCATE_LOG_SUFFIX.length();
 
-    private final ForStPathContainer pathContainer;
+    @Nullable private final Path remoteBasePath;
 
-    private boolean remotePathNewlyCreated;
+    @Nullable private final Path remoteForStPath;
+
+    @Nullable private final Path localBasePath;
+
+    @Nullable private final Path localForStPath;
 
     @Nullable private Path cacheBasePath;
 
@@ -122,7 +128,8 @@ public final class ForStResourceContainer implements AutoCloseable {
                 new Configuration(),
                 null,
                 null,
-                ForStPathContainer.empty(),
+                null,
+                null,
                 RecoveryClaimMode.DEFAULT,
                 null,
                 null,
@@ -135,7 +142,8 @@ public final class ForStResourceContainer implements AutoCloseable {
                 new Configuration(),
                 optionsFactory,
                 null,
-                ForStPathContainer.empty(),
+                null,
+                null,
                 RecoveryClaimMode.DEFAULT,
                 null,
                 null,
@@ -150,7 +158,8 @@ public final class ForStResourceContainer implements AutoCloseable {
                 new Configuration(),
                 optionsFactory,
                 sharedResources,
-                ForStPathContainer.empty(),
+                null,
+                null,
                 RecoveryClaimMode.DEFAULT,
                 null,
                 null,
@@ -161,7 +170,8 @@ public final class ForStResourceContainer implements AutoCloseable {
             ReadableConfig configuration,
             @Nullable ForStOptionsFactory optionsFactory,
             @Nullable OpaqueMemoryResource<ForStSharedResources> sharedResources,
-            ForStPathContainer pathContainer,
+            @Nullable Path localBasePath,
+            @Nullable Path remoteBasePath,
             RecoveryClaimMode claimMode,
             @Nullable CheckpointStorageAccess checkpointStorageAccess,
             MetricGroup metricGroup,
@@ -171,7 +181,11 @@ public final class ForStResourceContainer implements AutoCloseable {
         this.optionsFactory = optionsFactory;
         this.sharedResources = sharedResources;
 
-        this.pathContainer = pathContainer;
+        this.localBasePath = localBasePath;
+        this.localForStPath = localBasePath != null ? new Path(localBasePath, DB_DIR_STRING) : null;
+        this.remoteBasePath = remoteBasePath;
+        this.remoteForStPath =
+                remoteBasePath != null ? new Path(remoteBasePath, DB_DIR_STRING) : null;
 
         this.enableStatistics = enableStatistics;
         this.handlesToClose = new ArrayList<>();
@@ -212,10 +226,10 @@ public final class ForStResourceContainer implements AutoCloseable {
         // TODO: Fallback to checkpoint directory when checkpoint feature is ready if not
         // configured,
         //  fallback to local directory currently temporarily.
-        if (pathContainer.getRemoteForStPath() != null) {
+        if (remoteForStPath != null) {
             FlinkEnv flinkEnv =
                     new FlinkEnv(
-                            pathContainer.getRemoteBasePath().toString(),
+                            remoteBasePath.toString(),
                             new StringifiedForStFileSystem(forStFileSystem));
             opt.setEnv(flinkEnv);
             handlesToClose.add(flinkEnv);
@@ -296,16 +310,40 @@ public final class ForStResourceContainer implements AutoCloseable {
         return opt;
     }
 
-    public ForStPathContainer getPathContainer() {
-        return pathContainer;
+    @Nullable
+    public Path getLocalBasePath() {
+        return localBasePath;
+    }
+
+    @Nullable
+    public Path getLocalForStPath() {
+        return localForStPath;
+    }
+
+    @Nullable
+    public Path getRemoteBasePath() {
+        return remoteBasePath;
+    }
+
+    @Nullable
+    public Path getRemoteForStPath() {
+        return remoteForStPath;
     }
 
     public Path getBasePath() {
-        return pathContainer.getBasePath();
+        if (remoteBasePath != null) {
+            return remoteBasePath;
+        } else {
+            return localBasePath;
+        }
     }
 
     public Path getDbPath() {
-        return pathContainer.getDbPath();
+        if (remoteForStPath != null) {
+            return remoteForStPath;
+        } else {
+            return localForStPath;
+        }
     }
 
     public boolean isCoordinatorInline() {
@@ -330,31 +368,28 @@ public final class ForStResourceContainer implements AutoCloseable {
      * @throws Exception if any unexpected behaviors.
      */
     public void prepareDirectories() throws Exception {
-        if (pathContainer.getRemoteBasePath() != null
-                && pathContainer.getRemoteForStPath() != null) {
-            remotePathNewlyCreated =
-                    prepareDirectories(
-                            pathContainer.getRemoteBasePath(), pathContainer.getRemoteForStPath());
+        if (remoteBasePath != null && remoteForStPath != null) {
+            prepareDirectories(remoteBasePath, remoteForStPath);
         }
-        if (pathContainer.getLocalBasePath() != null && pathContainer.getLocalForStPath() != null) {
-            prepareDirectories(pathContainer.getLocalBasePath(), pathContainer.getLocalForStPath());
+        if (localBasePath != null && localForStPath != null) {
+            prepareDirectories(
+                    new Path(localBasePath.getPath()), new Path(localForStPath.getPath()));
         }
-        if (pathContainer.getRemoteForStPath() != null
-                && pathContainer.getLocalForStPath() != null) {
-            if (cacheBasePath == null && pathContainer.getLocalBasePath() != null) {
-                cacheBasePath = new Path(pathContainer.getLocalBasePath().getPath(), "cache");
+        if (remoteForStPath != null && localForStPath != null) {
+            if (cacheBasePath == null && localBasePath != null) {
+                cacheBasePath = new Path(localBasePath.getPath(), "cache");
                 LOG.info(
                         "Cache base path is not configured, set to local base path: {}",
                         cacheBasePath);
             }
             forStFileSystem =
                     ForStFlinkFileSystem.get(
-                            pathContainer.getRemoteForStPath().toUri(),
-                            pathContainer.getLocalForStPath(),
+                            remoteForStPath.toUri(),
+                            localForStPath,
                             ForStFlinkFileSystem.getFileBasedCache(
                                     configuration,
                                     cacheBasePath,
-                                    pathContainer.getRemoteForStPath(),
+                                    remoteForStPath,
                                     cacheCapacity,
                                     cacheReservedSize,
                                     metricGroup));
@@ -367,26 +402,23 @@ public final class ForStResourceContainer implements AutoCloseable {
         return forStFileSystem;
     }
 
-    private static boolean prepareDirectories(Path basePath, Path dbPath) throws IOException {
-        boolean allNewlyCreated = true;
+    private static void prepareDirectories(Path basePath, Path dbPath) throws IOException {
         FileSystem fileSystem = basePath.getFileSystem();
         if (fileSystem.exists(basePath)) {
             if (!fileSystem.getFileStatus(basePath).isDir()) {
                 throw new IOException("Not a directory: " + basePath);
             }
-            allNewlyCreated = false;
         } else if (!fileSystem.mkdirs(basePath)) {
             throw new IOException(
                     String.format("Could not create ForSt directory at %s.", basePath));
         }
         if (fileSystem.exists(dbPath)) {
-            LOG.info("Reusing previous ForSt db directory at {}.", dbPath);
-            allNewlyCreated = false;
-        } else if (!fileSystem.mkdirs(dbPath)) {
+            fileSystem.delete(dbPath, true);
+        }
+        if (!fileSystem.mkdirs(dbPath)) {
             throw new IOException(
                     String.format("Could not create ForSt db directory at %s.", dbPath));
         }
-        return allNewlyCreated;
     }
 
     /**
@@ -395,19 +427,17 @@ public final class ForStResourceContainer implements AutoCloseable {
      * @throws Exception if any unexpected behaviors.
      */
     public void clearDirectories() throws Exception {
-        Path remoteBasePath = pathContainer.getRemoteBasePath();
         if (remoteBasePath != null) {
             forStFileSystem.delete(remoteBasePath, true);
         }
-        Path localBasePath = pathContainer.getLocalBasePath();
         if (localBasePath != null) {
             clearDirectories(localBasePath);
         }
     }
 
     public void forceClearRemoteDirectories() throws Exception {
-        if (pathContainer.getRemoteBasePath() != null && remotePathNewlyCreated) {
-            clearDirectories(pathContainer.getRemoteBasePath());
+        if (remoteBasePath != null) {
+            clearDirectories(remoteBasePath);
         }
     }
 
@@ -494,10 +524,9 @@ public final class ForStResourceContainer implements AutoCloseable {
         String logDir = internalGetOption(ForStConfigurableOptions.LOG_DIR);
         if (logDir == null || logDir.isEmpty()) {
             // only relocate db log dir in local mode
-            if (pathContainer.getRemoteForStPath() == null
-                    && pathContainer.getLocalForStPath() != null
-                    && pathContainer.getLocalForStPath().getPath().length()
-                            <= INSTANCE_PATH_LENGTH_LIMIT) {
+            if (remoteForStPath == null
+                    && localForStPath != null
+                    && localForStPath.getPath().length() <= INSTANCE_PATH_LENGTH_LIMIT) {
                 relocateDefaultDbLogDir(currentOptions);
             }
         } else {
@@ -540,6 +569,10 @@ public final class ForStResourceContainer implements AutoCloseable {
         currentOptions.setMinWriteBufferNumberToMerge(
                 internalGetOption(ForStConfigurableOptions.MIN_WRITE_BUFFER_NUMBER_TO_MERGE));
 
+        currentOptions.setPeriodicCompactionSeconds(
+                internalGetOption(ForStConfigurableOptions.COMPACT_FILTER_PERIODIC_COMPACTION_TIME)
+                        .getSeconds());
+
         TableFormatConfig tableFormatConfig = currentOptions.tableFormatConfig();
 
         BlockBasedTableConfig blockBasedTableConfig;
@@ -609,10 +642,9 @@ public final class ForStResourceContainer implements AutoCloseable {
         // log dir, which results in "/" being used as the log directory. This often has permission
         // issues, so the db log dir is temporarily set explicitly here.
         // TODO: remove this method after ForSt deal log dir well
-        if (pathContainer.getLocalForStPath() != null) {
-            this.relocatedDbLogBaseDir =
-                    java.nio.file.Path.of(pathContainer.getLocalForStPath().toUri().toString());
-            dbOptions.setDbLogDir(pathContainer.getLocalForStPath().getPath());
+        if (localForStPath != null) {
+            this.relocatedDbLogBaseDir = java.nio.file.Path.of(localForStPath.toUri().toString());
+            dbOptions.setDbLogDir(localForStPath.getPath());
         }
     }
 
@@ -629,11 +661,10 @@ public final class ForStResourceContainer implements AutoCloseable {
 
     /** Clean all relocated ForSt logs. */
     private void cleanRelocatedDbLogs() {
-        if (pathContainer.getLocalForStPath() != null && relocatedDbLogBaseDir != null) {
+        if (localForStPath != null && relocatedDbLogBaseDir != null) {
             LOG.info("Cleaning up relocated ForSt logs: {}.", relocatedDbLogBaseDir);
 
-            String relocatedDbLogPrefix =
-                    resolveRelocatedDbLogPrefix(pathContainer.getLocalForStPath().getPath());
+            String relocatedDbLogPrefix = resolveRelocatedDbLogPrefix(localForStPath.getPath());
             try {
                 Arrays.stream(FileUtils.listDirectory(relocatedDbLogBaseDir))
                         .filter(
