@@ -22,6 +22,7 @@ import org.apache.flink.annotation.Experimental;
 import org.apache.flink.annotation.VisibleForTesting;
 import org.apache.flink.api.common.ExecutionConfig;
 import org.apache.flink.api.common.JobID;
+import org.apache.flink.api.java.tuple.Tuple2;
 import org.apache.flink.configuration.CheckpointingOptions;
 import org.apache.flink.configuration.ConfigOption;
 import org.apache.flink.configuration.Configuration;
@@ -45,6 +46,7 @@ import org.apache.flink.runtime.state.OperatorStateBackend;
 import org.apache.flink.runtime.state.StreamCompressionDecorator;
 import org.apache.flink.runtime.state.filesystem.FsCheckpointStorageAccess;
 import org.apache.flink.runtime.state.metrics.LatencyTrackingStateConfig;
+import org.apache.flink.runtime.state.metrics.SizeTrackingStateConfig;
 import org.apache.flink.state.forst.ForStMemoryControllerUtils.ForStMemoryFactory;
 import org.apache.flink.state.forst.sync.ForStPriorityQueueConfig;
 import org.apache.flink.state.forst.sync.ForStSyncKeyedStateBackendBuilder;
@@ -288,6 +290,7 @@ public class ForStStateBackend extends AbstractManagedMemoryStateBackend
 
         // configure latency tracking
         latencyTrackingConfigBuilder = original.latencyTrackingConfigBuilder.configure(config);
+        sizeTrackingConfigBuilder = original.sizeTrackingConfigBuilder.configure(config);
 
         this.forStMemoryFactory = original.forStMemoryFactory;
 
@@ -415,8 +418,7 @@ public class ForStStateBackend extends AbstractManagedMemoryStateBackend
 
         lazyInitializeForJob(env, fileCompatibleIdentifier);
 
-        ForStPathContainer pathContainer =
-                createForStPathContainer(fileCompatibleIdentifier, env, false);
+        Tuple2<Path, Path> localAndRemoteBasePath = getForStBasePath(fileCompatibleIdentifier, env);
 
         final OpaqueMemoryResource<ForStSharedResources> sharedResources =
                 ForStOperationUtils.allocateSharedCachesIfConfigured(
@@ -431,7 +433,8 @@ public class ForStStateBackend extends AbstractManagedMemoryStateBackend
         final ForStResourceContainer resourceContainer =
                 createOptionsAndResourceContainer(
                         sharedResources,
-                        pathContainer,
+                        localAndRemoteBasePath.f0,
+                        localAndRemoteBasePath.f1,
                         env.getCheckpointStorageAccess(),
                         parameters.getMetricGroup(),
                         nativeMetricOptions.isStatisticsEnabled());
@@ -487,8 +490,7 @@ public class ForStStateBackend extends AbstractManagedMemoryStateBackend
 
         lazyInitializeForJob(env, fileCompatibleIdentifier);
 
-        ForStPathContainer pathContainer =
-                createForStPathContainer(fileCompatibleIdentifier, env, forceSyncLocal);
+        Tuple2<Path, Path> localAndRemoteBasePath = getForStBasePath(fileCompatibleIdentifier, env);
 
         LocalRecoveryConfig localRecoveryConfig =
                 env.getTaskStateManager().createLocalRecoveryConfig();
@@ -506,7 +508,8 @@ public class ForStStateBackend extends AbstractManagedMemoryStateBackend
         final ForStResourceContainer resourceContainer =
                 createOptionsAndResourceContainer(
                         sharedResources,
-                        pathContainer,
+                        localAndRemoteBasePath.f0,
+                        forceSyncLocal ? null : localAndRemoteBasePath.f1,
                         env.getCheckpointStorageAccess(),
                         parameters.getMetricGroup(),
                         nativeMetricOptions.isStatisticsEnabled());
@@ -517,6 +520,8 @@ public class ForStStateBackend extends AbstractManagedMemoryStateBackend
 
         LatencyTrackingStateConfig latencyTrackingStateConfig =
                 latencyTrackingConfigBuilder.setMetricGroup(parameters.getMetricGroup()).build();
+        SizeTrackingStateConfig sizeTrackingStateConfig =
+                sizeTrackingConfigBuilder.setMetricGroup(parameters.getMetricGroup()).build();
         ForStSyncKeyedStateBackendBuilder<K> builder =
                 new ForStSyncKeyedStateBackendBuilder<>(
                                 parameters.getOperatorIdentifier(),
@@ -532,6 +537,7 @@ public class ForStStateBackend extends AbstractManagedMemoryStateBackend
                                 priorityQueueConfig,
                                 parameters.getTtlTimeProvider(),
                                 latencyTrackingStateConfig,
+                                sizeTrackingStateConfig,
                                 parameters.getMetricGroup(),
                                 parameters.getCustomInitializationMetrics(),
                                 parameters.getStateHandles(),
@@ -789,32 +795,25 @@ public class ForStStateBackend extends AbstractManagedMemoryStateBackend
         return configuration;
     }
 
-    ForStPathContainer createForStPathContainer(
-            String operatorIdentifier, Environment env, boolean forceLocal) {
+    Tuple2<Path, Path> getForStBasePath(String operatorIdentifier, Environment env) {
         String opChildPath =
                 String.format(
                         "op_%s_attempt_%s",
                         operatorIdentifier, env.getTaskInfo().getAttemptNumber());
 
-        File localJobFile = new File(getNextStoragePath(), jobId.toHexString());
-        Path localJobPath = new Path(localJobFile.getPath());
-        Path localBasePath = new Path(new File(localJobFile, opChildPath).getAbsolutePath());
-
-        if (forceLocal) {
-            return ForStPathContainer.ofLocal(localJobPath, localBasePath);
-        }
-
-        Path remoteJobPath = null;
+        Path localBasePath =
+                new Path(
+                        new File(new File(getNextStoragePath(), jobId.toHexString()), opChildPath)
+                                .getAbsolutePath());
         Path remoteBasePath = null;
         if (remoteForStDirectory != null) {
-            remoteJobPath = new Path(remoteForStDirectory, jobId.toHexString());
-            remoteBasePath = new Path(remoteJobPath, opChildPath);
+            remoteBasePath =
+                    new Path(new Path(remoteForStDirectory, jobId.toHexString()), opChildPath);
         } else if (remoteShareWithCheckpoint) {
             if (env.getCheckpointStorageAccess() instanceof FsCheckpointStorageAccess) {
-                FsCheckpointStorageAccess fsCheckpointStorageAccess =
-                        (FsCheckpointStorageAccess) env.getCheckpointStorageAccess();
-                remoteJobPath = fsCheckpointStorageAccess.getCheckpointsDirectory();
-                Path sharedStateDirectory = fsCheckpointStorageAccess.getSharedStateDirectory();
+                Path sharedStateDirectory =
+                        ((FsCheckpointStorageAccess) env.getCheckpointStorageAccess())
+                                .getSharedStateDirectory();
                 remoteBasePath = new Path(sharedStateDirectory, opChildPath);
                 LOG.info("Set remote ForSt directory to checkpoint directory {}", remoteBasePath);
             } else {
@@ -822,20 +821,19 @@ public class ForStStateBackend extends AbstractManagedMemoryStateBackend
                         "Remote ForSt directory can't be set, because checkpoint directory isn't on file system.");
             }
         }
-
-        return ForStPathContainer.of(localJobPath, localBasePath, remoteJobPath, remoteBasePath);
+        return Tuple2.of(localBasePath, remoteBasePath);
     }
 
     @VisibleForTesting
     ForStResourceContainer createOptionsAndResourceContainer(@Nullable Path localBasePath) {
-        return createOptionsAndResourceContainer(
-                null, ForStPathContainer.ofLocal(null, localBasePath), null, null, false);
+        return createOptionsAndResourceContainer(null, localBasePath, null, null, null, false);
     }
 
     @VisibleForTesting
     private ForStResourceContainer createOptionsAndResourceContainer(
             @Nullable OpaqueMemoryResource<ForStSharedResources> sharedResources,
-            ForStPathContainer pathContainer,
+            @Nullable Path localBasePath,
+            @Nullable Path remoteBasePath,
             @Nullable CheckpointStorageAccess checkpointStorageAccess,
             @Nullable MetricGroup metricGroup,
             boolean enableStatistics) {
@@ -844,7 +842,8 @@ public class ForStStateBackend extends AbstractManagedMemoryStateBackend
                 configurableOptions != null ? configurableOptions : new Configuration(),
                 forStOptionsFactory,
                 sharedResources,
-                pathContainer,
+                localBasePath,
+                remoteBasePath,
                 recoveryClaimMode,
                 checkpointStorageAccess,
                 metricGroup,
