@@ -56,6 +56,7 @@ import org.apache.flink.runtime.state.heap.HeapPriorityQueueElement;
 import org.apache.flink.runtime.state.heap.HeapPriorityQueueSetFactory;
 import org.apache.flink.runtime.state.heap.HeapPriorityQueueSnapshotRestoreWrapper;
 import org.apache.flink.runtime.state.metrics.LatencyTrackingStateConfig;
+import org.apache.flink.runtime.state.metrics.SizeTrackingStateConfig;
 import org.apache.flink.runtime.state.ttl.TtlTimeProvider;
 import org.apache.flink.state.forst.ForStDBTtlCompactFiltersManager;
 import org.apache.flink.state.forst.ForStDBWriteBatchWrapper;
@@ -73,7 +74,6 @@ import org.forstdb.ColumnFamilyHandle;
 import org.forstdb.ColumnFamilyOptions;
 import org.forstdb.ReadOptions;
 import org.forstdb.RocksDB;
-import org.forstdb.RocksDBException;
 import org.forstdb.Snapshot;
 import org.forstdb.WriteOptions;
 import org.slf4j.Logger;
@@ -265,6 +265,7 @@ public class ForStSyncKeyedStateBackend<K> extends AbstractKeyedStateBackend<K>
             ExecutionConfig executionConfig,
             TtlTimeProvider ttlTimeProvider,
             LatencyTrackingStateConfig latencyTrackingStateConfig,
+            SizeTrackingStateConfig sizeTrackingStateConfig,
             RocksDB db,
             LinkedHashMap<String, ForStOperationUtils.ForStKvStateInfo> kvStateInformation,
             Map<String, HeapPriorityQueueSnapshotRestoreWrapper<?>> registeredPQStates,
@@ -290,6 +291,7 @@ public class ForStSyncKeyedStateBackend<K> extends AbstractKeyedStateBackend<K>
                 executionConfig,
                 ttlTimeProvider,
                 latencyTrackingStateConfig,
+                sizeTrackingStateConfig,
                 cancelStreamRegistry,
                 keyGroupCompressionDecorator,
                 keyContext);
@@ -377,6 +379,12 @@ public class ForStSyncKeyedStateBackend<K> extends AbstractKeyedStateBackend<K>
         return targetStream.onClose(iteratorWrapper::close);
     }
 
+    @Override
+    public <N> Stream<K> getKeys(List<String> states, N namespace) {
+        // TODO
+        throw new UnsupportedOperationException();
+    }
+
     @Override
     public <N> Stream<Tuple2<K, N>> getKeysAndNamespaces(String state) {
         ForStOperationUtils.ForStKvStateInfo columnInfo = kvStateInformation.get(state);
@@ -480,13 +488,18 @@ public class ForStSyncKeyedStateBackend<K> extends AbstractKeyedStateBackend<K>
             columnFamilyOptions.forEach(IOUtils::closeQuietly);
 
             LOG.info(
-                    "Closed ForSt State Backend. Cleaning up ForSt: {}.",
-                    optionsContainer.getPathContainer());
+                    "Closed ForSt State Backend. Cleaning up ForSt local working directory {}, remote working directory {}.",
+                    optionsContainer.getLocalBasePath(),
+                    optionsContainer.getRemoteBasePath());
 
             try {
                 optionsContainer.clearDirectories();
             } catch (Exception ex) {
-                LOG.warn("Could not delete ForSt: {}.", optionsContainer.getPathContainer(), ex);
+                LOG.warn(
+                        "Could not delete ForSt local working directory {}, remote working directory {}.",
+                        optionsContainer.getLocalBasePath(),
+                        optionsContainer.getRemoteBasePath(),
+                        ex);
             }
 
             IOUtils.closeQuietly(optionsContainer);
@@ -581,7 +594,8 @@ public class ForStSyncKeyedStateBackend<K> extends AbstractKeyedStateBackend<K>
     @Nonnull
     @Override
     public SavepointResources<K> savepoint() throws Exception {
-        throw new UnsupportedOperationException("This method is not supported.");
+        throw new UnsupportedOperationException(
+                "Canonical savepoints are not supported by ForSt State Backend.");
     }
 
     @Override
@@ -930,13 +944,6 @@ public class ForStSyncKeyedStateBackend<K> extends AbstractKeyedStateBackend<K>
         return true;
     }
 
-    @VisibleForTesting
-    public void compactState(StateDescriptor<?, ?> stateDesc) throws RocksDBException {
-        ForStOperationUtils.ForStKvStateInfo kvStateInfo =
-                kvStateInformation.get(stateDesc.getName());
-        db.compactRange(kvStateInfo.columnFamilyHandle);
-    }
-
     @Nonnegative
     long getWriteBatchSize() {
         return writeBatchSize;
