@@ -164,14 +164,13 @@ public class ForStExtension implements BeforeEachCallback, AfterEachCallback {
 
         resourceGuard = new ResourceGuard();
         File localWorkingDir = TempDirUtils.newFolder(rocksFolder.toPath(), "local-working-dir");
-        Path localJobPath = new Path(localWorkingDir.getAbsolutePath());
-        Path localBasePath = new Path(localJobPath, "base");
         this.resourceContainer =
                 new ForStResourceContainer(
                         new Configuration(),
                         optionsFactory,
                         null,
-                        ForStPathContainer.ofLocal(localJobPath, localBasePath),
+                        new Path(localWorkingDir.getAbsolutePath()),
+                        null,
                         null,
                         null,
                         null,
@@ -191,10 +190,9 @@ public class ForStExtension implements BeforeEachCallback, AfterEachCallback {
         // working dir. We will implement this in ForStDB later, but before that, we achieved this
         // by setting the dbPath to "/" when the dfs directory existed.
         // TODO: use localForStPath as dbPath after ForSt Support mixing local-dir and remote-dir
-        ForStPathContainer pathContainer = resourceContainer.getPathContainer();
         Path instanceForStPath =
-                pathContainer.getRemoteForStPath() == null
-                        ? pathContainer.getLocalForStPath()
+                resourceContainer.getRemoteForStPath() == null
+                        ? resourceContainer.getLocalForStPath()
                         : new Path("/");
 
         this.columnFamilyHandles = new ArrayList<>(1);
