@@ -26,6 +26,8 @@ import org.apache.flink.queryablestate.client.state.serialization.KvStateSeriali
 import org.apache.flink.runtime.state.KeyGroupRangeAssignment;
 import org.apache.flink.runtime.state.SerializedCompositeKeyBuilder;
 import org.apache.flink.runtime.state.internal.InternalKvState;
+import org.apache.flink.runtime.state.ttl.TtlAwareSerializer;
+import org.apache.flink.runtime.state.ttl.TtlTimeProvider;
 import org.apache.flink.util.FlinkRuntimeException;
 import org.apache.flink.util.Preconditions;
 import org.apache.flink.util.StateMigrationException;
@@ -36,6 +38,8 @@ import org.rocksdb.WriteOptions;
 
 import java.io.IOException;
 
+import static org.apache.flink.util.Preconditions.checkArgument;
+
 /**
  * Base class for {@link State} implementations that store state in a RocksDB database.
  *
@@ -172,10 +176,7 @@ public abstract class AbstractRocksDBState<K, N, V> implements InternalKvState<K
             throws IOException {
         dataOutputView.clear();
         dataOutputView.writeBoolean(value == null);
-        if (value != null) {
-            serializer.serialize(value, dataOutputView);
-        }
-        return dataOutputView.getCopyOfBuffer();
+        return serializeValueInternal(value, serializer);
     }
 
     <T> byte[] serializeValue(T value, TypeSerializer<T> serializer) throws IOException {
@@ -187,12 +188,21 @@ public abstract class AbstractRocksDBState<K, N, V> implements InternalKvState<K
             DataInputDeserializer serializedOldValueInput,
             DataOutputSerializer serializedMigratedValueOutput,
             TypeSerializer<V> priorSerializer,
-            TypeSerializer<V> newSerializer)
+            TypeSerializer<V> newSerializer,
+            TtlTimeProvider ttlTimeProvider)
             throws StateMigrationException {
+        checkArgument(priorSerializer instanceof TtlAwareSerializer);
+        checkArgument(newSerializer instanceof TtlAwareSerializer);
+        TtlAwareSerializer<V, ?> ttlAwarePriorSerializer =
+                (TtlAwareSerializer<V, ?>) priorSerializer;
+        TtlAwareSerializer<V, ?> ttlAwareNewSerializer = (TtlAwareSerializer<V, ?>) newSerializer;
 
         try {
-            V value = priorSerializer.deserialize(serializedOldValueInput);
-            newSerializer.serialize(value, serializedMigratedValueOutput);
+            ttlAwareNewSerializer.migrateValueFromPriorSerializer(
+                    ttlAwarePriorSerializer,
+                    () -> ttlAwarePriorSerializer.deserialize(serializedOldValueInput),
+                    serializedMigratedValueOutput,
+                    ttlTimeProvider);
         } catch (Exception e) {
             throw new StateMigrationException("Error while trying to migrate RocksDB state.", e);
         }
@@ -236,6 +246,11 @@ public abstract class AbstractRocksDBState<K, N, V> implements InternalKvState<K
         return this;
     }
 
+    protected AbstractRocksDBState<K, N, V> setColumnFamily(ColumnFamilyHandle columnFamily) {
+        this.columnFamily = columnFamily;
+        return this;
+    }
+
     @Override
     public StateIncrementalVisitor<K, N, V> getStateIncrementalVisitor(
             int recommendedMaxNumberOfReturnedRecords) {
