@@ -56,7 +56,10 @@ import org.apache.flink.runtime.state.heap.HeapPriorityQueueElement;
 import org.apache.flink.runtime.state.heap.HeapPriorityQueueSetFactory;
 import org.apache.flink.runtime.state.heap.HeapPriorityQueueSnapshotRestoreWrapper;
 import org.apache.flink.runtime.state.metrics.LatencyTrackingStateConfig;
+import org.apache.flink.runtime.state.metrics.SizeTrackingStateConfig;
+import org.apache.flink.runtime.state.ttl.TtlAwareSerializer;
 import org.apache.flink.runtime.state.ttl.TtlTimeProvider;
+import org.apache.flink.state.rocksdb.iterator.RocksMultiStateKeysIterator;
 import org.apache.flink.state.rocksdb.iterator.RocksStateKeysAndNamespaceIterator;
 import org.apache.flink.state.rocksdb.iterator.RocksStateKeysIterator;
 import org.apache.flink.state.rocksdb.snapshot.RocksDBFullSnapshotResources;
@@ -88,6 +91,8 @@ import java.io.Closeable;
 import java.io.File;
 import java.io.IOException;
 import java.util.ArrayList;
+import java.util.Arrays;
+import java.util.Collections;
 import java.util.HashMap;
 import java.util.LinkedHashMap;
 import java.util.List;
@@ -278,6 +283,7 @@ public class RocksDBKeyedStateBackend<K> extends AbstractKeyedStateBackend<K> {
             ExecutionConfig executionConfig,
             TtlTimeProvider ttlTimeProvider,
             LatencyTrackingStateConfig latencyTrackingStateConfig,
+            SizeTrackingStateConfig sizeTrackingStateConfig,
             RocksDB db,
             LinkedHashMap<String, RocksDbKvStateInfo> kvStateInformation,
             Map<String, HeapPriorityQueueSnapshotRestoreWrapper<?>> registeredPQStates,
@@ -304,6 +310,7 @@ public class RocksDBKeyedStateBackend<K> extends AbstractKeyedStateBackend<K> {
                 executionConfig,
                 ttlTimeProvider,
                 latencyTrackingStateConfig,
+                sizeTrackingStateConfig,
                 cancelStreamRegistry,
                 keyGroupCompressionDecorator,
                 keyContext);
@@ -398,6 +405,73 @@ public class RocksDBKeyedStateBackend<K> extends AbstractKeyedStateBackend<K> {
         return targetStream.onClose(iteratorWrapper::close);
     }
 
+    @SuppressWarnings("unchecked")
+    @Override
+    public <N> Stream<K> getKeys(List<String> states, N namespace) {
+        final List<Boolean> ambiguousKeyPossibles = new ArrayList<>();
+        final List<RocksIteratorWrapper> iterators = new ArrayList<>();
+        byte[] namespaceBytes = null;
+
+        for (String state : states) {
+            RocksDbKvStateInfo columnInfo = kvStateInformation.get(state);
+            if (columnInfo == null
+                    || !(columnInfo.metaInfo instanceof RegisteredKeyValueStateBackendMetaInfo)) {
+                continue;
+            }
+
+            RegisteredKeyValueStateBackendMetaInfo<N, ?> registeredKeyValueStateBackendMetaInfo =
+                    (RegisteredKeyValueStateBackendMetaInfo<N, ?>) columnInfo.metaInfo;
+
+            final TypeSerializer<N> namespaceSerializer =
+                    registeredKeyValueStateBackendMetaInfo.getNamespaceSerializer();
+            final DataOutputSerializer namespaceOutputView = new DataOutputSerializer(8);
+            boolean ambiguousKeyPossible =
+                    CompositeKeySerializationUtils.isAmbiguousKeyPossible(
+                            getKeySerializer(), namespaceSerializer);
+            ambiguousKeyPossibles.add(ambiguousKeyPossible);
+            try {
+                CompositeKeySerializationUtils.writeNameSpace(
+                        namespace, namespaceSerializer, namespaceOutputView, ambiguousKeyPossible);
+                final byte[] stateNamespaceBytes = namespaceOutputView.getCopyOfBuffer();
+                if (namespaceBytes == null) {
+                    namespaceBytes = stateNamespaceBytes;
+                } else {
+                    if (!Arrays.equals(namespaceBytes, stateNamespaceBytes)) {
+                        throw new FlinkRuntimeException(
+                                "Key namespaces are different for states ["
+                                        + String.join(",", states)
+                                        + "]");
+                    }
+                }
+            } catch (IOException ex) {
+                throw new FlinkRuntimeException(
+                        "Failed to get keys from RocksDB state backend.", ex);
+            }
+
+            RocksIteratorWrapper iterator =
+                    RocksDBOperationUtils.getRocksIterator(
+                            db, columnInfo.columnFamilyHandle, readOptions);
+            iterator.seekToFirst();
+            iterators.add(iterator);
+        }
+
+        Preconditions.checkNotNull(namespaceBytes, "Namespace must exist");
+        final RocksMultiStateKeysIterator<K> iteratorWrapper =
+                new RocksMultiStateKeysIterator<>(
+                        iterators,
+                        states,
+                        getKeySerializer(),
+                        keyGroupPrefixBytes,
+                        ambiguousKeyPossibles,
+                        namespaceBytes);
+
+        Stream<K> targetStream =
+                StreamSupport.stream(
+                        Spliterators.spliteratorUnknownSize(iteratorWrapper, Spliterator.ORDERED),
+                        false);
+        return targetStream.onClose(iteratorWrapper::close);
+    }
+
     @Override
     public <N> Stream<Tuple2<K, N>> getKeysAndNamespaces(String state) {
         RocksDbKvStateInfo columnInfo = kvStateInformation.get(state);
@@ -454,11 +528,6 @@ public class RocksDBKeyedStateBackend<K> extends AbstractKeyedStateBackend<K> {
         sharedRocksKeyBuilder.setKeyAndKeyGroup(getCurrentKey(), getCurrentKeyGroupIndex());
     }
 
-    @VisibleForTesting
-    LinkedHashMap<String, RocksDbKvStateInfo> getKvStateInformation() {
-        return kvStateInformation;
-    }
-
     /** Should only be called by one thread, and only after all accesses to the DB happened. */
     @Override
     public void dispose() {
@@ -692,20 +761,20 @@ public class RocksDBKeyedStateBackend<K> extends AbstractKeyedStateBackend<K> {
             RegisteredKeyValueStateBackendMetaInfo<N, SV> castedMetaInfo =
                     (RegisteredKeyValueStateBackendMetaInfo<N, SV>) oldStateInfo.metaInfo;
 
-            newMetaInfo =
-                    updateRestoredStateMetaInfo(
-                            Tuple2.of(oldStateInfo.columnFamilyHandle, castedMetaInfo),
-                            stateDesc,
-                            namespaceSerializer,
-                            stateSerializer);
-
+            Tuple2<ColumnFamilyHandle, RegisteredKeyValueStateBackendMetaInfo<N, SV>>
+                    newRocksDBState =
+                            updateRestoredStateMetaInfo(
+                                    Tuple2.of(oldStateInfo.columnFamilyHandle, castedMetaInfo),
+                                    stateDesc,
+                                    namespaceSerializer,
+                                    stateSerializer);
+            newMetaInfo = newRocksDBState.f1;
             newMetaInfo =
                     allowFutureMetadataUpdates
                             ? newMetaInfo.withSerializerUpgradesAllowed()
                             : newMetaInfo;
 
-            newRocksStateInfo =
-                    new RocksDbKvStateInfo(oldStateInfo.columnFamilyHandle, newMetaInfo);
+            newRocksStateInfo = new RocksDbKvStateInfo(newRocksDBState.f0, newMetaInfo);
             kvStateInformation.put(stateDesc.getName(), newRocksStateInfo);
             sstMergeManager.register(newRocksStateInfo);
         } else {
@@ -749,13 +818,16 @@ public class RocksDBKeyedStateBackend<K> extends AbstractKeyedStateBackend<K> {
     }
 
     private <N, S extends State, SV>
-            RegisteredKeyValueStateBackendMetaInfo<N, SV> updateRestoredStateMetaInfo(
-                    Tuple2<ColumnFamilyHandle, RegisteredKeyValueStateBackendMetaInfo<N, SV>>
-                            oldStateInfo,
-                    StateDescriptor<S, SV> stateDesc,
-                    TypeSerializer<N> namespaceSerializer,
-                    TypeSerializer<SV> stateSerializer)
-                    throws Exception {
+            Tuple2<ColumnFamilyHandle, RegisteredKeyValueStateBackendMetaInfo<N, SV>>
+                    updateRestoredStateMetaInfo(
+                            Tuple2<
+                                            ColumnFamilyHandle,
+                                            RegisteredKeyValueStateBackendMetaInfo<N, SV>>
+                                    oldStateInfo,
+                            StateDescriptor<S, SV> stateDesc,
+                            TypeSerializer<N> namespaceSerializer,
+                            TypeSerializer<SV> stateSerializer)
+                            throws Exception {
 
         RegisteredKeyValueStateBackendMetaInfo<N, SV> restoredKvStateMetaInfo = oldStateInfo.f1;
 
@@ -794,7 +866,7 @@ public class RocksDBKeyedStateBackend<K> extends AbstractKeyedStateBackend<K> {
                             + ").");
         }
 
-        return restoredKvStateMetaInfo;
+        return oldStateInfo;
     }
 
     /**
@@ -860,14 +932,43 @@ public class RocksDBKeyedStateBackend<K> extends AbstractKeyedStateBackend<K> {
 
             DataInputDeserializer serializedValueInput = new DataInputDeserializer();
             DataOutputSerializer migratedSerializedValueOutput = new DataOutputSerializer(512);
+
+            // Check if this is ttl state migration
+            TtlAwareSerializer<SV, ?> previousTtlAwareSerializer =
+                    (TtlAwareSerializer<SV, ?>)
+                            TtlAwareSerializer.wrapTtlAwareSerializer(
+                                    stateMetaInfo.f1.getPreviousStateSerializer());
+            TtlAwareSerializer<SV, ?> currentTtlAwareSerializer =
+                    (TtlAwareSerializer<SV, ?>)
+                            TtlAwareSerializer.wrapTtlAwareSerializer(
+                                    stateMetaInfo.f1.getStateSerializer());
+
+            if (TtlAwareSerializer.needTtlStateMigration(
+                    previousTtlAwareSerializer, currentTtlAwareSerializer)) {
+                // By performing ttl state migration, we need to recreate column family to
+                // enable/disable ttl compaction filter factory.
+                db.dropColumnFamily(stateMetaInfo.f0);
+                stateMetaInfo.f0 =
+                        RocksDBOperationUtils.createColumnFamily(
+                                RocksDBOperationUtils.createColumnFamilyDescriptor(
+                                        stateMetaInfo.f1,
+                                        columnFamilyOptionsFactory,
+                                        ttlCompactFiltersManager,
+                                        optionsContainer.getWriteBufferManagerCapacity()),
+                                db,
+                                Collections.emptyList(),
+                                ICloseableRegistry.NO_OP);
+            }
+
             while (iterator.isValid()) {
                 serializedValueInput.setBuffer(iterator.value());
 
                 rocksDBState.migrateSerializedValue(
                         serializedValueInput,
                         migratedSerializedValueOutput,
-                        stateMetaInfo.f1.getPreviousStateSerializer(),
-                        stateMetaInfo.f1.getStateSerializer());
+                        previousTtlAwareSerializer,
+                        currentTtlAwareSerializer,
+                        this.ttlTimeProvider);
 
                 batchWriter.put(
                         stateMetaInfo.f0,
