@@ -27,7 +27,7 @@ import org.apache.flink.api.common.typeutils.base.ListSerializer;
 import org.apache.flink.core.memory.DataInputDeserializer;
 import org.apache.flink.runtime.state.RegisteredKeyValueStateBackendMetaInfo;
 import org.apache.flink.runtime.state.RegisteredStateMetaInfoBase;
-import org.apache.flink.runtime.state.ttl.TtlStateFactory;
+import org.apache.flink.runtime.state.ttl.TtlAwareSerializer;
 import org.apache.flink.runtime.state.ttl.TtlTimeProvider;
 import org.apache.flink.runtime.state.ttl.TtlUtils;
 import org.apache.flink.runtime.state.ttl.TtlValue;
@@ -48,7 +48,6 @@ import javax.annotation.Nonnull;
 import java.io.IOException;
 import java.time.Duration;
 import java.util.LinkedHashMap;
-import java.util.function.Supplier;
 
 /** RocksDB compaction filter utils for state with TTL. */
 public class RocksDbTtlCompactFiltersManager {
@@ -93,8 +92,7 @@ public class RocksDbTtlCompactFiltersManager {
         if (metaInfoBase instanceof RegisteredKeyValueStateBackendMetaInfo) {
             RegisteredKeyValueStateBackendMetaInfo kvMetaInfoBase =
                     (RegisteredKeyValueStateBackendMetaInfo) metaInfoBase;
-            if (TtlStateFactory.TtlSerializer.isTtlStateSerializer(
-                    kvMetaInfoBase.getStateSerializer())) {
+            if (TtlAwareSerializer.isSerializerTtlEnabled(kvMetaInfoBase.getStateSerializer())) {
                 createAndSetCompactFilterFactory(metaInfoBase.getName(), options);
             }
         }
@@ -188,27 +186,15 @@ public class RocksDbTtlCompactFiltersManager {
 
     private static class ListElementFilterFactory<T>
             implements FlinkCompactionFilter.ListElementFilterFactory {
-        // {@See #createListElementFilter}.
-        private final ThreadLocalSerializerProvider<T> threadLocalSerializer;
+        private final TypeSerializer<T> serializer;
 
         private ListElementFilterFactory(TypeSerializer<T> serializer) {
-            ClassLoader contextClassLoader = null;
-            try {
-                contextClassLoader = Thread.currentThread().getContextClassLoader();
-            } catch (Throwable e) {
-                LOG.info("Cannot get context classloader for list state's compaction filter.", e);
-            }
-            threadLocalSerializer =
-                    new ThreadLocalSerializerProvider<>(serializer, contextClassLoader);
+            this.serializer = serializer;
         }
 
         @Override
         public FlinkCompactionFilter.ListElementFilter createListElementFilter() {
-            // This method will be invoked by native code multiple times when creating compaction
-            // filter. And the created filter will be shared by multiple background threads.
-            // Make sure the serializer is thread-local and has classloader set for each thread
-            // correctly and individually.
-            return new ListElementFilter<>(threadLocalSerializer);
+            return new ListElementFilter<>(serializer);
         }
     }
 
@@ -226,11 +212,11 @@ public class RocksDbTtlCompactFiltersManager {
     }
 
     private static class ListElementFilter<T> implements FlinkCompactionFilter.ListElementFilter {
-        private final ThreadLocalSerializerProvider<T> threadLocalSerializer;
-        private final DataInputDeserializer input;
+        private final TypeSerializer<T> serializer;
+        private DataInputDeserializer input;
 
-        private ListElementFilter(ThreadLocalSerializerProvider<T> serializer) {
-            this.threadLocalSerializer = serializer;
+        private ListElementFilter(TypeSerializer<T> serializer) {
+            this.serializer = serializer;
             this.input = new DataInputDeserializer();
         }
 
@@ -238,10 +224,9 @@ public class RocksDbTtlCompactFiltersManager {
         public int nextUnexpiredOffset(byte[] bytes, long ttl, long currentTimestamp) {
             input.setBuffer(bytes);
             int lastElementOffset = 0;
-            TypeSerializer<T> serializer = threadLocalSerializer.get();
             while (input.available() > 0) {
                 try {
-                    long timestamp = nextElementLastAccessTimestamp(serializer);
+                    long timestamp = nextElementLastAccessTimestamp();
                     if (!TtlUtils.expired(timestamp, ttl, currentTimestamp)) {
                         break;
                     }
@@ -254,8 +239,7 @@ public class RocksDbTtlCompactFiltersManager {
             return lastElementOffset;
         }
 
-        private long nextElementLastAccessTimestamp(TypeSerializer<T> serializer)
-                throws IOException {
+        private long nextElementLastAccessTimestamp() throws IOException {
             TtlValue<?> ttlValue = (TtlValue<?>) serializer.deserialize(input);
             if (input.available() > 0) {
                 input.skipBytesToRead(1);
@@ -264,37 +248,6 @@ public class RocksDbTtlCompactFiltersManager {
         }
     }
 
-    private static class ThreadLocalSerializerProvider<T> implements Supplier<TypeSerializer<T>> {
-        // Multiple background threads may share the same filter instance, so we need to make sure
-        // the serializer is thread-local, and every thread has its own instance with classloader.
-        private final ThreadLocal<TypeSerializer<T>> threadLocalSerializer;
-
-        public ThreadLocalSerializerProvider(
-                TypeSerializer<T> serializer, ClassLoader classLoader) {
-            this.threadLocalSerializer =
-                    ThreadLocal.withInitial(
-                            () -> {
-                                setClassloaderIfNeeded(classLoader);
-                                return serializer.duplicate();
-                            });
-        }
-
-        private void setClassloaderIfNeeded(ClassLoader classLoader) {
-            // The classloader that should be set to the current thread when deserializing.
-            // The reason why we should set classloader is that the serializer may be Kryo
-            // serializer which needs user classloader to load user classes.
-            // See FLINK-16686 for more details.
-            if (classLoader != null) {
-                Thread.currentThread().setContextClassLoader(classLoader);
-            }
-        }
-
-        @Override
-        public TypeSerializer<T> get() {
-            return threadLocalSerializer.get();
-        }
-    }
-
     public void disposeAndClearRegisteredCompactionFactories() {
         for (FlinkCompactionFilterFactory factory : compactionFilterFactories.values()) {
             IOUtils.closeQuietly(factory);
