@@ -24,7 +24,6 @@ import org.apache.flink.api.common.functions.ReduceFunction;
 import org.apache.flink.api.common.state.ReducingState;
 import org.apache.flink.api.common.state.ReducingStateDescriptor;
 import org.apache.flink.api.common.typeutils.base.LongSerializer;
-import org.apache.flink.streaming.api.windowing.time.Time;
 import org.apache.flink.streaming.api.windowing.windows.Window;
 
 import java.time.Duration;
@@ -123,18 +122,6 @@ public class ContinuousProcessingTimeTrigger<W extends Window> extends Trigger<O
         return "ContinuousProcessingTimeTrigger(" + interval + ")";
     }
 
-    /**
-     * Creates a trigger that continuously fires based on the given interval.
-     *
-     * @param interval The time interval at which to fire.
-     * @param <W> The type of {@link Window Windows} on which this trigger can operate.
-     * @deprecated Use {@link #of(Duration)}
-     */
-    @Deprecated
-    public static <W extends Window> ContinuousProcessingTimeTrigger<W> of(Time interval) {
-        return of(interval.toDuration());
-    }
-
     /**
      * Creates a trigger that continuously fires based on the given interval.
      *
