@@ -40,7 +40,6 @@ import org.apache.flink.streaming.api.watermark.Watermark;
 import org.apache.flink.streaming.api.windowing.assigners.EventTimeSessionWindows;
 import org.apache.flink.streaming.api.windowing.assigners.TumblingEventTimeWindows;
 import org.apache.flink.streaming.api.windowing.assigners.TumblingProcessingTimeWindows;
-import org.apache.flink.streaming.api.windowing.time.Time;
 import org.apache.flink.streaming.api.windowing.triggers.CountTrigger;
 import org.apache.flink.streaming.api.windowing.triggers.EventTimeTrigger;
 import org.apache.flink.streaming.api.windowing.triggers.ProcessingTimeTrigger;
@@ -62,10 +61,10 @@ import org.apache.flink.util.Collector;
 import org.junit.jupiter.api.TestTemplate;
 import org.junit.jupiter.api.extension.ExtendWith;
 
+import java.time.Duration;
 import java.util.Collection;
 import java.util.Comparator;
 import java.util.concurrent.ConcurrentLinkedQueue;
-import java.util.concurrent.TimeUnit;
 
 import static org.assertj.core.api.Assertions.assertThat;
 
@@ -77,10 +76,10 @@ import static org.assertj.core.api.Assertions.assertThat;
  * processing-time windows operator of previous Flink versions.
  */
 @ExtendWith(ParameterizedTestExtension.class)
-class WindowOperatorMigrationTest implements MigrationTest {
+public class WindowOperatorMigrationTest implements MigrationTest {
 
     @Parameters(name = "Migration Savepoint: {0}")
-    private static Collection<FlinkVersion> parameters() {
+    public static Collection<FlinkVersion> parameters() {
         return FlinkVersion.rangeOf(
                 FlinkVersion.v1_8, MigrationTest.getMostRecentlyPublishedVersion());
     }
@@ -104,15 +103,15 @@ class WindowOperatorMigrationTest implements MigrationTest {
                         "window-contents",
                         STRING_INT_TUPLE.createSerializer(new SerializerConfigImpl()));
 
-        WindowOperator<
+        WindowOperatorFactory<
                         String,
                         Tuple2<String, Integer>,
                         Iterable<Tuple2<String, Integer>>,
                         Tuple3<String, Long, Long>,
                         TimeWindow>
                 operator =
-                        new WindowOperator<>(
-                                EventTimeSessionWindows.withGap(Time.seconds(sessionSize)),
+                        new WindowOperatorFactory<>(
+                                EventTimeSessionWindows.withGap(Duration.ofSeconds(sessionSize)),
                                 new TimeWindow.Serializer(),
                                 new TupleKeySelector<String>(),
                                 BasicTypeInfo.STRING_TYPE_INFO.createSerializer(
@@ -162,15 +161,15 @@ class WindowOperatorMigrationTest implements MigrationTest {
                         "window-contents",
                         STRING_INT_TUPLE.createSerializer(new SerializerConfigImpl()));
 
-        WindowOperator<
+        WindowOperatorFactory<
                         String,
                         Tuple2<String, Integer>,
                         Iterable<Tuple2<String, Integer>>,
                         Tuple3<String, Long, Long>,
                         TimeWindow>
                 operator =
-                        new WindowOperator<>(
-                                EventTimeSessionWindows.withGap(Time.seconds(sessionSize)),
+                        new WindowOperatorFactory<>(
+                                EventTimeSessionWindows.withGap(Duration.ofSeconds(sessionSize)),
                                 new TimeWindow.Serializer(),
                                 new TupleKeySelector<String>(),
                                 BasicTypeInfo.STRING_TYPE_INFO.createSerializer(
@@ -236,15 +235,15 @@ class WindowOperatorMigrationTest implements MigrationTest {
                         "window-contents",
                         STRING_INT_TUPLE.createSerializer(new SerializerConfigImpl()));
 
-        WindowOperator<
+        WindowOperatorFactory<
                         String,
                         Tuple2<String, Integer>,
                         Iterable<Tuple2<String, Integer>>,
                         Tuple3<String, Long, Long>,
                         TimeWindow>
                 operator =
-                        new WindowOperator<>(
-                                EventTimeSessionWindows.withGap(Time.seconds(sessionSize)),
+                        new WindowOperatorFactory<>(
+                                EventTimeSessionWindows.withGap(Duration.ofSeconds(sessionSize)),
                                 new TimeWindow.Serializer(),
                                 new TupleKeySelector<String>(),
                                 BasicTypeInfo.STRING_TYPE_INFO.createSerializer(
@@ -288,15 +287,15 @@ class WindowOperatorMigrationTest implements MigrationTest {
                         "window-contents",
                         STRING_INT_TUPLE.createSerializer(new SerializerConfigImpl()));
 
-        WindowOperator<
+        WindowOperatorFactory<
                         String,
                         Tuple2<String, Integer>,
                         Iterable<Tuple2<String, Integer>>,
                         Tuple3<String, Long, Long>,
                         TimeWindow>
                 operator =
-                        new WindowOperator<>(
-                                EventTimeSessionWindows.withGap(Time.seconds(sessionSize)),
+                        new WindowOperatorFactory<>(
+                                EventTimeSessionWindows.withGap(Duration.ofSeconds(sessionSize)),
                                 new TimeWindow.Serializer(),
                                 new TupleKeySelector<String>(),
                                 BasicTypeInfo.STRING_TYPE_INFO.createSerializer(
@@ -373,15 +372,15 @@ class WindowOperatorMigrationTest implements MigrationTest {
                         new SumReducer<>(),
                         STRING_INT_TUPLE.createSerializer(new SerializerConfigImpl()));
 
-        WindowOperator<
+        WindowOperatorFactory<
                         String,
                         Tuple2<String, Integer>,
                         Tuple2<String, Integer>,
                         Tuple2<String, Integer>,
                         TimeWindow>
                 operator =
-                        new WindowOperator<>(
-                                TumblingEventTimeWindows.of(Time.of(windowSize, TimeUnit.SECONDS)),
+                        new WindowOperatorFactory<>(
+                                TumblingEventTimeWindows.of(Duration.ofSeconds(windowSize)),
                                 new TimeWindow.Serializer(),
                                 new TupleKeySelector<>(),
                                 BasicTypeInfo.STRING_TYPE_INFO.createSerializer(
@@ -453,15 +452,15 @@ class WindowOperatorMigrationTest implements MigrationTest {
                         new SumReducer<>(),
                         STRING_INT_TUPLE.createSerializer(new SerializerConfigImpl()));
 
-        WindowOperator<
+        WindowOperatorFactory<
                         String,
                         Tuple2<String, Integer>,
                         Tuple2<String, Integer>,
                         Tuple2<String, Integer>,
                         TimeWindow>
                 operator =
-                        new WindowOperator<>(
-                                TumblingEventTimeWindows.of(Time.of(windowSize, TimeUnit.SECONDS)),
+                        new WindowOperatorFactory<>(
+                                TumblingEventTimeWindows.of(Duration.ofSeconds(windowSize)),
                                 new TimeWindow.Serializer(),
                                 new TupleKeySelector<>(),
                                 BasicTypeInfo.STRING_TYPE_INFO.createSerializer(
@@ -524,15 +523,15 @@ class WindowOperatorMigrationTest implements MigrationTest {
                         "window-contents",
                         STRING_INT_TUPLE.createSerializer(new SerializerConfigImpl()));
 
-        WindowOperator<
+        WindowOperatorFactory<
                         String,
                         Tuple2<String, Integer>,
                         Iterable<Tuple2<String, Integer>>,
                         Tuple2<String, Integer>,
                         TimeWindow>
                 operator =
-                        new WindowOperator<>(
-                                TumblingEventTimeWindows.of(Time.of(windowSize, TimeUnit.SECONDS)),
+                        new WindowOperatorFactory<>(
+                                TumblingEventTimeWindows.of(Duration.ofSeconds(windowSize)),
                                 new TimeWindow.Serializer(),
                                 new TupleKeySelector<>(),
                                 BasicTypeInfo.STRING_TYPE_INFO.createSerializer(
@@ -602,15 +601,15 @@ class WindowOperatorMigrationTest implements MigrationTest {
                         "window-contents",
                         STRING_INT_TUPLE.createSerializer(new SerializerConfigImpl()));
 
-        WindowOperator<
+        WindowOperatorFactory<
                         String,
                         Tuple2<String, Integer>,
                         Iterable<Tuple2<String, Integer>>,
                         Tuple2<String, Integer>,
                         TimeWindow>
                 operator =
-                        new WindowOperator<>(
-                                TumblingEventTimeWindows.of(Time.of(windowSize, TimeUnit.SECONDS)),
+                        new WindowOperatorFactory<>(
+                                TumblingEventTimeWindows.of(Duration.ofSeconds(windowSize)),
                                 new TimeWindow.Serializer(),
                                 new TupleKeySelector<>(),
                                 BasicTypeInfo.STRING_TYPE_INFO.createSerializer(
@@ -673,16 +672,15 @@ class WindowOperatorMigrationTest implements MigrationTest {
                         new SumReducer<>(),
                         STRING_INT_TUPLE.createSerializer(new SerializerConfigImpl()));
 
-        WindowOperator<
+        WindowOperatorFactory<
                         String,
                         Tuple2<String, Integer>,
                         Tuple2<String, Integer>,
                         Tuple2<String, Integer>,
                         TimeWindow>
                 operator =
-                        new WindowOperator<>(
-                                TumblingProcessingTimeWindows.of(
-                                        Time.of(windowSize, TimeUnit.SECONDS)),
+                        new WindowOperatorFactory<>(
+                                TumblingProcessingTimeWindows.of(Duration.ofSeconds(windowSize)),
                                 new TimeWindow.Serializer(),
                                 new TupleKeySelector<>(),
                                 BasicTypeInfo.STRING_TYPE_INFO.createSerializer(
@@ -743,16 +741,15 @@ class WindowOperatorMigrationTest implements MigrationTest {
                         new SumReducer<>(),
                         STRING_INT_TUPLE.createSerializer(new SerializerConfigImpl()));
 
-        WindowOperator<
+        WindowOperatorFactory<
                         String,
                         Tuple2<String, Integer>,
                         Tuple2<String, Integer>,
                         Tuple2<String, Integer>,
                         TimeWindow>
                 operator =
-                        new WindowOperator<>(
-                                TumblingProcessingTimeWindows.of(
-                                        Time.of(windowSize, TimeUnit.SECONDS)),
+                        new WindowOperatorFactory<>(
+                                TumblingProcessingTimeWindows.of(Duration.ofSeconds(windowSize)),
                                 new TimeWindow.Serializer(),
                                 new TupleKeySelector<>(),
                                 BasicTypeInfo.STRING_TYPE_INFO.createSerializer(
@@ -810,16 +807,15 @@ class WindowOperatorMigrationTest implements MigrationTest {
                         "window-contents",
                         STRING_INT_TUPLE.createSerializer(new SerializerConfigImpl()));
 
-        WindowOperator<
+        WindowOperatorFactory<
                         String,
                         Tuple2<String, Integer>,
                         Iterable<Tuple2<String, Integer>>,
                         Tuple2<String, Integer>,
                         TimeWindow>
                 operator =
-                        new WindowOperator<>(
-                                TumblingProcessingTimeWindows.of(
-                                        Time.of(windowSize, TimeUnit.SECONDS)),
+                        new WindowOperatorFactory<>(
+                                TumblingProcessingTimeWindows.of(Duration.ofSeconds(windowSize)),
                                 new TimeWindow.Serializer(),
                                 new TupleKeySelector<>(),
                                 BasicTypeInfo.STRING_TYPE_INFO.createSerializer(
@@ -878,16 +874,15 @@ class WindowOperatorMigrationTest implements MigrationTest {
                         "window-contents",
                         STRING_INT_TUPLE.createSerializer(new SerializerConfigImpl()));
 
-        WindowOperator<
+        WindowOperatorFactory<
                         String,
                         Tuple2<String, Integer>,
                         Iterable<Tuple2<String, Integer>>,
                         Tuple2<String, Integer>,
                         TimeWindow>
                 operator =
-                        new WindowOperator<>(
-                                TumblingProcessingTimeWindows.of(
-                                        Time.of(windowSize, TimeUnit.SECONDS)),
+                        new WindowOperatorFactory<>(
+                                TumblingProcessingTimeWindows.of(Duration.ofSeconds(windowSize)),
                                 new TimeWindow.Serializer(),
                                 new TupleKeySelector<>(),
                                 BasicTypeInfo.STRING_TYPE_INFO.createSerializer(
@@ -952,15 +947,15 @@ class WindowOperatorMigrationTest implements MigrationTest {
                 TypeInformation.of(NonPojoType.class).createSerializer(new SerializerConfigImpl());
         assertThat(keySerializer).isInstanceOf(KryoSerializer.class);
 
-        WindowOperator<
+        WindowOperatorFactory<
                         NonPojoType,
                         Tuple2<NonPojoType, Integer>,
                         Tuple2<NonPojoType, Integer>,
                         Tuple2<NonPojoType, Integer>,
                         TimeWindow>
                 operator =
-                        new WindowOperator<>(
-                                TumblingEventTimeWindows.of(Time.of(windowSize, TimeUnit.SECONDS)),
+                        new WindowOperatorFactory<>(
+                                TumblingEventTimeWindows.of(Duration.ofSeconds(windowSize)),
                                 new TimeWindow.Serializer(),
                                 new TupleKeySelector<>(),
                                 keySerializer,
@@ -1047,15 +1042,15 @@ class WindowOperatorMigrationTest implements MigrationTest {
                 TypeInformation.of(NonPojoType.class).createSerializer(new SerializerConfigImpl());
         assertThat(keySerializer).isInstanceOf(KryoSerializer.class);
 
-        WindowOperator<
+        WindowOperatorFactory<
                         NonPojoType,
                         Tuple2<NonPojoType, Integer>,
                         Tuple2<NonPojoType, Integer>,
                         Tuple2<NonPojoType, Integer>,
                         TimeWindow>
                 operator =
-                        new WindowOperator<>(
-                                TumblingEventTimeWindows.of(Time.of(windowSize, TimeUnit.SECONDS)),
+                        new WindowOperatorFactory<>(
+                                TumblingEventTimeWindows.of(Duration.ofSeconds(windowSize)),
                                 new TimeWindow.Serializer(),
                                 new TupleKeySelector<>(),
                                 keySerializer,
