@@ -36,7 +36,7 @@ public final class LocalOverWindow {
 
     private Expression orderBy;
 
-    private Expression preceding;
+    private @Nullable Expression preceding;
 
     private @Nullable Expression following;
 
@@ -44,7 +44,7 @@ public final class LocalOverWindow {
             Expression alias,
             List<Expression> partitionBy,
             Expression orderBy,
-            Expression preceding,
+            @Nullable Expression preceding,
             @Nullable Expression following) {
         this.alias = alias;
         this.partitionBy = partitionBy;
@@ -65,8 +65,8 @@ public final class LocalOverWindow {
         return orderBy;
     }
 
-    public Expression getPreceding() {
-        return preceding;
+    public Optional<Expression> getPreceding() {
+        return Optional.ofNullable(preceding);
     }
 
     public Optional<Expression> getFollowing() {
