@@ -24,6 +24,7 @@ import org.apache.flink.table.catalog.Column.ComputedColumn;
 import org.apache.flink.table.catalog.Column.MetadataColumn;
 import org.apache.flink.table.catalog.Column.PhysicalColumn;
 import org.apache.flink.table.catalog.Constraint;
+import org.apache.flink.table.catalog.Index;
 import org.apache.flink.table.catalog.ResolvedSchema;
 import org.apache.flink.table.catalog.SchemaResolver;
 import org.apache.flink.table.catalog.UniqueConstraint;
@@ -54,8 +55,8 @@ import java.util.stream.IntStream;
  * Schema of a table or view.
  *
  * <p>A schema represents the schema part of a {@code CREATE TABLE (schema) WITH (options)} DDL
- * statement in SQL. It defines columns of different kind, constraints, time attributes, and
- * watermark strategies. It is possible to reference objects (such as functions or types) across
+ * statement in SQL. It defines columns of different kinds, constraints, indexes, time attributes,
+ * and watermark strategies. It is possible to reference objects (such as functions or types) across
  * different catalogs.
  *
  * <p>This class is used in the API and catalogs to define an unresolved schema that will be
@@ -77,13 +78,26 @@ public final class Schema {
 
     private final @Nullable UnresolvedPrimaryKey primaryKey;
 
-    private Schema(
+    private final List<UnresolvedIndex> indexes;
+
+    /** Please use {@link #Schema(List, List, UnresolvedPrimaryKey, List)} instead. */
+    @Deprecated
+    public Schema(
             List<UnresolvedColumn> columns,
             List<UnresolvedWatermarkSpec> watermarkSpecs,
             @Nullable UnresolvedPrimaryKey primaryKey) {
+        this(columns, watermarkSpecs, primaryKey, Collections.emptyList());
+    }
+
+    public Schema(
+            List<UnresolvedColumn> columns,
+            List<UnresolvedWatermarkSpec> watermarkSpecs,
+            @Nullable UnresolvedPrimaryKey primaryKey,
+            List<UnresolvedIndex> indexes) {
         this.columns = Collections.unmodifiableList(columns);
         this.watermarkSpecs = Collections.unmodifiableList(watermarkSpecs);
         this.primaryKey = primaryKey;
+        this.indexes = Collections.unmodifiableList(indexes);
     }
 
     /** Builder for configuring and creating instances of {@link Schema}. */
@@ -116,6 +130,10 @@ public final class Schema {
         return Optional.ofNullable(primaryKey);
     }
 
+    public List<UnresolvedIndex> getIndexes() {
+        return indexes;
+    }
+
     /** Resolves the given {@link Schema} to a validated {@link ResolvedSchema}. */
     public ResolvedSchema resolve(SchemaResolver resolver) {
         return resolver.resolve(this);
@@ -129,6 +147,9 @@ public final class Schema {
         if (primaryKey != null) {
             components.add(primaryKey);
         }
+        if (!indexes.isEmpty()) {
+            components.addAll(indexes);
+        }
         return components.stream()
                 .map(Objects::toString)
                 .map(s -> "  " + s)
@@ -146,12 +167,13 @@ public final class Schema {
         Schema schema = (Schema) o;
         return columns.equals(schema.columns)
                 && watermarkSpecs.equals(schema.watermarkSpecs)
-                && Objects.equals(primaryKey, schema.primaryKey);
+                && Objects.equals(primaryKey, schema.primaryKey)
+                && indexes.equals(schema.indexes);
     }
 
     @Override
     public int hashCode() {
-        return Objects.hash(columns, watermarkSpecs, primaryKey);
+        return Objects.hash(columns, watermarkSpecs, primaryKey, indexes);
     }
 
     // --------------------------------------------------------------------------------------------
@@ -166,9 +188,12 @@ public final class Schema {
 
         private @Nullable UnresolvedPrimaryKey primaryKey;
 
+        private final List<UnresolvedIndex> indexes;
+
         private Builder() {
             columns = new ArrayList<>();
             watermarkSpecs = new ArrayList<>();
+            indexes = new ArrayList<>();
         }
 
         /** Adopts all members from the given unresolved schema. */
@@ -180,6 +205,7 @@ public final class Schema {
                         unresolvedSchema.primaryKey.getConstraintName(),
                         unresolvedSchema.primaryKey.getColumnNames());
             }
+            indexes.addAll(unresolvedSchema.indexes);
             return this;
         }
 
@@ -188,6 +214,7 @@ public final class Schema {
             addResolvedColumns(resolvedSchema.getColumns());
             addResolvedWatermarkSpec(resolvedSchema.getWatermarkSpecs());
             resolvedSchema.getPrimaryKey().ifPresent(this::addResolvedConstraint);
+            addResolvedIndexes(resolvedSchema.getIndexes());
             return this;
         }
 
@@ -526,7 +553,7 @@ public final class Schema {
         }
 
         /**
-         * Declares a primary key constraint for a set of given columns. Primary key uniquely
+         * Declares a primary key constraint for a list of given columns. Primary key uniquely
          * identify a row in a table. Neither of columns in a primary can be nullable. The primary
          * key is informational only. It will not be enforced. It can be used for optimizations. It
          * is the data owner's responsibility to ensure uniqueness of the data.
@@ -541,7 +568,7 @@ public final class Schema {
         }
 
         /**
-         * Declares a primary key constraint for a set of given columns. Primary key uniquely
+         * Declares a primary key constraint for a list of given columns. Primary key uniquely
          * identify a row in a table. Neither of columns in a primary can be nullable. The primary
          * key is informational only. It will not be enforced. It can be used for optimizations. It
          * is the data owner's responsibility to ensure uniqueness of the data.
@@ -558,7 +585,7 @@ public final class Schema {
         }
 
         /**
-         * Declares a primary key constraint for a set of given columns. Primary key uniquely
+         * Declares a primary key constraint for a list of given columns. Primary key uniquely
          * identify a row in a table. Neither of columns in a primary can be nullable. The primary
          * key is informational only. It will not be enforced. It can be used for optimizations. It
          * is the data owner's responsibility to ensure uniqueness of the data.
@@ -572,7 +599,7 @@ public final class Schema {
         }
 
         /**
-         * Declares a primary key constraint for a set of given columns. Primary key uniquely
+         * Declares a primary key constraint for a list of given columns. Primary key uniquely
          * identify a row in a table. Neither of columns in a primary can be nullable. The primary
          * key is informational only. It will not be enforced. It can be used for optimizations. It
          * is the data owner's responsibility to ensure uniqueness of the data.
@@ -595,9 +622,59 @@ public final class Schema {
             return this;
         }
 
+        /**
+         * Declares a named index for a list of given column names. Indexes are designed to enable
+         * very efficient search. The indexes are informational only and can be used for
+         * optimizations. It is the data owner's responsibility to guarantee the index queries allow
+         * the complete row to be retrieved efficiently.
+         *
+         * <p>The index will be assigned a generated name in the format {@code INDEX_col1_col2}.
+         *
+         * @param columnNames indexes that form a table index
+         */
+        public Builder index(String... columnNames) {
+            Preconditions.checkNotNull(indexes, "Index column names must not be null.");
+            return index(Arrays.asList(columnNames));
+        }
+
+        /**
+         * Declares a named index for a list of given column names. Indexes are designed to enable
+         * very efficient search. The indexes are informational only and can be used for
+         * optimizations. It is the data owner's responsibility to guarantee the index queries allow
+         * the complete row to be retrieved efficiently.
+         *
+         * <p>The index will be assigned a generated name in the format {@code INDEX_col1_col2}.
+         *
+         * @param columnNames indexes that form a table index
+         */
+        public Builder index(List<String> columnNames) {
+            Preconditions.checkNotNull(indexes, "Index column names must not be null.");
+            final String generatedIndexName =
+                    columnNames.stream().collect(Collectors.joining("_", "INDEX_", ""));
+            return indexNamed(generatedIndexName, columnNames);
+        }
+
+        /**
+         * Declares a named index for a list of given column names. Indexes are designed to enable
+         * very efficient search. The indexes are informational only and can be used for
+         * optimizations. It is the data owner's responsibility to guarantee the index queries allow
+         * the complete row to be retrieved efficiently.
+         *
+         * @param indexName the name of the index
+         * @param columnNames columns that form a table index
+         */
+        public Builder indexNamed(String indexName, List<String> columnNames) {
+            Preconditions.checkNotNull(indexName, "Index name must not be null.");
+            Preconditions.checkNotNull(columnNames, "Index column names must not be null.");
+            Preconditions.checkArgument(
+                    !columnNames.isEmpty(), "Index must be defined for at least a single column.");
+            this.indexes.add(new UnresolvedIndex(indexName, columnNames));
+            return this;
+        }
+
         /** Returns an instance of an unresolved {@link Schema}. */
         public Schema build() {
-            return new Schema(columns, watermarkSpecs, primaryKey);
+            return new Schema(columns, watermarkSpecs, primaryKey, indexes);
         }
 
         // ----------------------------------------------------------------------------------------
@@ -638,6 +715,11 @@ public final class Schema {
                 throw new IllegalArgumentException("Unsupported constraint type.");
             }
         }
+
+        private void addResolvedIndexes(List<Index> resolvedIndexes) {
+            resolvedIndexes.forEach(
+                    index -> indexes.add(new UnresolvedIndex(index.getName(), index.getColumns())));
+        }
     }
 
     // --------------------------------------------------------------------------------------------
@@ -1043,4 +1125,52 @@ public final class Schema {
             return Objects.hash(super.hashCode(), columnNames);
         }
     }
+
+    /** Declaration of an index that will be resolved to {@link Index} during schema resolution. */
+    @PublicEvolving
+    public static final class UnresolvedIndex {
+        private final String indexName;
+        private final List<String> columnNames;
+
+        public UnresolvedIndex(String indexName, List<String> columnNames) {
+            this.indexName = indexName;
+            this.columnNames = columnNames;
+        }
+
+        public String getIndexName() {
+            return indexName;
+        }
+
+        public List<String> getColumnNames() {
+            return columnNames;
+        }
+
+        @Override
+        public String toString() {
+            return String.format(
+                    "INDEX %s (%s)",
+                    EncodingUtils.escapeIdentifier(getIndexName()),
+                    getColumnNames().stream()
+                            .map(EncodingUtils::escapeIdentifier)
+                            .collect(Collectors.joining(", ")));
+        }
+
+        @Override
+        public boolean equals(Object o) {
+            if (this == o) {
+                return true;
+            }
+            if (o == null || getClass() != o.getClass()) {
+                return false;
+            }
+            UnresolvedIndex that = (UnresolvedIndex) o;
+            return Objects.equals(indexName, that.indexName)
+                    && Objects.equals(columnNames, that.columnNames);
+        }
+
+        @Override
+        public int hashCode() {
+            return Objects.hash(indexName, columnNames);
+        }
+    }
 }
