@@ -28,6 +28,8 @@ import org.apache.flink.table.types.logical.LogicalType;
 import org.apache.flink.table.types.logical.LogicalTypeFamily;
 import org.apache.flink.table.types.logical.LogicalTypeRoot;
 import org.apache.flink.table.types.utils.ValueDataTypeConverter;
+import org.apache.flink.table.utils.EncodingUtils;
+import org.apache.flink.types.ColumnList;
 import org.apache.flink.util.Preconditions;
 import org.apache.flink.util.StringUtils;
 
@@ -225,7 +227,7 @@ public final class ValueLiteralExpression implements ResolvedExpression {
     }
 
     @Override
-    public String asSerializableString() {
+    public String asSerializableString(SqlFactory sqlFactory) {
         if (value == null && !dataType.getLogicalType().is(LogicalTypeRoot.NULL)) {
             return String.format(
                     "CAST(NULL AS %s)",
@@ -299,6 +301,17 @@ public final class ValueLiteralExpression implements ResolvedExpression {
                         duration.toMinutes() % 60,
                         duration.getSeconds() % 60,
                         duration.getNano() / 1_000_000);
+            case DESCRIPTOR:
+                final ColumnList columnList = getValueAs(ColumnList.class).get();
+                if (!columnList.getDataTypes().isEmpty()) {
+                    throw new TableException("Data types in DESCRIPTOR are not supported yet.");
+                }
+                return String.format(
+                        "DESCRIPTOR(%s)",
+                        columnList.getNames().stream()
+                                .map(EncodingUtils::escapeBackticks)
+                                .map(c -> String.format("`%s`", c))
+                                .collect(Collectors.joining()));
             case ARRAY:
             case MULTISET:
             case MAP:
@@ -307,11 +320,11 @@ public final class ValueLiteralExpression implements ResolvedExpression {
                         "Constructed type literals are not SQL serializable. Please use respective"
                                 + " constructor functions");
             case TIMESTAMP_WITH_TIME_ZONE:
+            case DISTINCT_TYPE:
             case STRUCTURED_TYPE:
             case RAW:
-            case DISTINCT_TYPE:
-            case UNRESOLVED:
             case SYMBOL:
+            case UNRESOLVED:
             default:
                 throw new TableException(
                         "Literals with "
