@@ -26,7 +26,10 @@ import org.apache.flink.table.api.config.TableConfigOptions.ColumnExpansionStrat
 import org.apache.flink.table.catalog.Column;
 import org.apache.flink.table.catalog.ResolvedSchema;
 import org.apache.flink.table.data.TimestampData;
+import org.apache.flink.table.planner.catalog.CatalogSchemaModel;
 import org.apache.flink.table.planner.catalog.CatalogSchemaTable;
+import org.apache.flink.table.planner.functions.sql.ml.SqlMLTableFunction;
+import org.apache.flink.table.planner.plan.FlinkCalciteCatalogReader;
 import org.apache.flink.table.planner.plan.utils.FlinkRexUtil;
 import org.apache.flink.table.planner.utils.ShortcutUtils;
 import org.apache.flink.table.types.logical.DecimalType;
@@ -43,12 +46,14 @@ import org.apache.calcite.sql.JoinType;
 import org.apache.calcite.sql.SqlAsOperator;
 import org.apache.calcite.sql.SqlBasicCall;
 import org.apache.calcite.sql.SqlCall;
+import org.apache.calcite.sql.SqlExplicitModelCall;
 import org.apache.calcite.sql.SqlFunction;
 import org.apache.calcite.sql.SqlFunctionCategory;
 import org.apache.calcite.sql.SqlIdentifier;
 import org.apache.calcite.sql.SqlJoin;
 import org.apache.calcite.sql.SqlKind;
 import org.apache.calcite.sql.SqlLiteral;
+import org.apache.calcite.sql.SqlModelCall;
 import org.apache.calcite.sql.SqlNode;
 import org.apache.calcite.sql.SqlNodeList;
 import org.apache.calcite.sql.SqlOperator;
@@ -126,6 +131,10 @@ public final class FlinkCalciteSqlValidator extends SqlValidatorImpl {
                         .get(TableConfigOptions.TABLE_COLUMN_EXPANSION_STRATEGY);
     }
 
+    public RelOptCluster getRelOptCluster() {
+        return relOptCluster;
+    }
+
     public void setExpectedOutputType(SqlNode sqlNode, RelDataType expectedOutputType) {
         this.sqlNodeForExpectedOutputType = sqlNode;
         this.expectedOutputType = expectedOutputType;
@@ -184,10 +193,8 @@ public final class FlinkCalciteSqlValidator extends SqlValidatorImpl {
     @Override
     public void validateColumnListParams(
             SqlFunction function, List<RelDataType> argTypes, List<SqlNode> operands) {
-        // we don't support column lists and translate them into the unknown type in the type
-        // factory,
-        // this makes it possible to ignore them in the validator and fall back to regular row types
-        // see also SqlFunction#deriveType
+        // There is no validation necessary for column list parameters.
+        // This method will be dropped once we update Calcite to 1.36 (see CALCITE-5644).
     }
 
     @Override
@@ -373,7 +380,21 @@ public final class FlinkCalciteSqlValidator extends SqlValidatorImpl {
         final SqlBasicCall call = (SqlBasicCall) node;
         final SqlOperator operator = call.getOperator();
 
-        if (operator instanceof SqlWindowTableFunction) {
+        if (node instanceof SqlExplicitModelCall) {
+            // Convert it so that model can be accessed in planner. SqlExplicitModelCall
+            // from parser can't access model.
+            SqlExplicitModelCall modelCall = (SqlExplicitModelCall) node;
+            SqlIdentifier modelIdentifier = modelCall.getModelIdentifier();
+            FlinkCalciteCatalogReader catalogReader =
+                    (FlinkCalciteCatalogReader) getCatalogReader();
+            CatalogSchemaModel model = catalogReader.getModel(modelIdentifier.names);
+            if (model != null) {
+                return new SqlModelCall(modelCall, model);
+            }
+        }
+
+        // TODO (FLINK-37819): add test for SqlMLTableFunction
+        if (operator instanceof SqlWindowTableFunction || operator instanceof SqlMLTableFunction) {
             if (tableArgs.stream().allMatch(Objects::isNull)) {
                 return rewritten;
             }
