@@ -23,9 +23,9 @@ import org.apache.flink.sql.parser.ddl.SqlTableColumn;
 import org.apache.flink.sql.parser.ddl.SqlTableColumn.SqlComputedColumn;
 import org.apache.flink.sql.parser.ddl.SqlTableColumn.SqlMetadataColumn;
 import org.apache.flink.sql.parser.ddl.SqlTableColumn.SqlRegularColumn;
-import org.apache.flink.sql.parser.ddl.SqlTableLike;
 import org.apache.flink.sql.parser.ddl.SqlTableLike.FeatureOption;
 import org.apache.flink.sql.parser.ddl.SqlTableLike.MergingStrategy;
+import org.apache.flink.sql.parser.ddl.SqlTableLike.SqlTableLikeOption;
 import org.apache.flink.sql.parser.ddl.SqlWatermark;
 import org.apache.flink.sql.parser.ddl.constraint.SqlTableConstraint;
 import org.apache.flink.table.api.Schema;
@@ -33,37 +33,26 @@ import org.apache.flink.table.api.Schema.UnresolvedColumn;
 import org.apache.flink.table.api.Schema.UnresolvedComputedColumn;
 import org.apache.flink.table.api.Schema.UnresolvedMetadataColumn;
 import org.apache.flink.table.api.Schema.UnresolvedPhysicalColumn;
-import org.apache.flink.table.api.Schema.UnresolvedPrimaryKey;
 import org.apache.flink.table.api.Schema.UnresolvedWatermarkSpec;
 import org.apache.flink.table.api.ValidationException;
 import org.apache.flink.table.catalog.DataTypeFactory;
 import org.apache.flink.table.catalog.TableDistribution;
-import org.apache.flink.table.expressions.SqlCallExpression;
 import org.apache.flink.table.planner.calcite.FlinkTypeFactory;
 import org.apache.flink.table.types.logical.LogicalType;
-import org.apache.flink.table.types.utils.TypeConversions;
 
 import org.apache.calcite.rel.type.RelDataType;
-import org.apache.calcite.rel.type.RelDataTypeField;
-import org.apache.calcite.sql.SqlDataTypeSpec;
 import org.apache.calcite.sql.SqlIdentifier;
-import org.apache.calcite.sql.SqlLiteral;
 import org.apache.calcite.sql.SqlNode;
 import org.apache.calcite.sql.validate.SqlValidator;
 
 import javax.annotation.Nullable;
 
-import java.util.ArrayList;
 import java.util.HashMap;
 import java.util.LinkedHashMap;
 import java.util.List;
 import java.util.Map;
 import java.util.Optional;
 import java.util.function.Function;
-import java.util.stream.Collectors;
-
-import static org.apache.flink.table.planner.calcite.FlinkTypeFactory.toLogicalType;
-import static org.apache.flink.table.types.utils.TypeConversions.fromLogicalToDataType;
 
 /** A utility class with logic for handling the {@code CREATE TABLE ... LIKE} clause. */
 class MergeTableLikeUtil {
@@ -101,11 +90,11 @@ class MergeTableLikeUtil {
      * specific {@link FeatureOption}.
      */
     public Map<FeatureOption, MergingStrategy> computeMergingStrategies(
-            List<SqlTableLike.SqlTableLikeOption> mergingOptions) {
+            List<SqlTableLikeOption> mergingOptions) {
 
         Map<FeatureOption, MergingStrategy> result = new HashMap<>(defaultMergingStrategies);
 
-        Optional<SqlTableLike.SqlTableLikeOption> maybeAllOption =
+        Optional<SqlTableLikeOption> maybeAllOption =
                 mergingOptions.stream()
                         .filter(option -> option.getFeatureOption() == FeatureOption.ALL)
                         .findFirst();
@@ -120,7 +109,7 @@ class MergeTableLikeUtil {
                     }
                 });
 
-        for (SqlTableLike.SqlTableLikeOption mergingOption : mergingOptions) {
+        for (SqlTableLikeOption mergingOption : mergingOptions) {
             result.put(mergingOption.getFeatureOption(), mergingOption.getMergingStrategy());
         }
 
@@ -194,7 +183,7 @@ class MergeTableLikeUtil {
      * Merges the partitions part of {@code CREATE TABLE} statement.
      *
      * <p>Partitioning is a single property of a Table, thus there can be at most a single instance
-     * of partitioning. Therefore it is not possible to use {@link MergingStrategy#INCLUDING} with
+     * of partitioning. Therefore, it is not possible to use {@link MergingStrategy#INCLUDING} with
      * partitioning defined in both source and derived table.
      */
     public List<String> mergePartitions(
@@ -242,21 +231,13 @@ class MergeTableLikeUtil {
         return options;
     }
 
-    private static class SchemaBuilder {
-
-        Map<String, UnresolvedColumn> columns = new LinkedHashMap<>();
-        Map<String, UnresolvedWatermarkSpec> watermarkSpecs = new HashMap<>();
-        UnresolvedPrimaryKey primaryKey = null;
-
+    private static class SchemaBuilder extends SchemaBuilderUtil {
         // Intermediate state
         Map<String, RelDataType> physicalFieldNamesToTypes = new LinkedHashMap<>();
         Map<String, RelDataType> metadataFieldNamesToTypes = new LinkedHashMap<>();
         Map<String, RelDataType> computedFieldNamesToTypes = new LinkedHashMap<>();
 
-        Function<SqlNode, String> escapeExpressions;
         FlinkTypeFactory typeFactory;
-        SqlValidator sqlValidator;
-        DataTypeFactory dataTypeFactory;
 
         SchemaBuilder(
                 Map<FeatureOption, MergingStrategy> mergingStrategies,
@@ -265,10 +246,9 @@ class MergeTableLikeUtil {
                 DataTypeFactory dataTypeFactory,
                 SqlValidator sqlValidator,
                 Function<SqlNode, String> escapeExpressions) {
+            super(sqlValidator, escapeExpressions, dataTypeFactory);
             this.typeFactory = typeFactory;
-            this.dataTypeFactory = dataTypeFactory;
-            this.sqlValidator = sqlValidator;
-            this.escapeExpressions = escapeExpressions;
+
             populateColumnsFromSourceTable(mergingStrategies, sourceSchema);
             populateWatermarksFromSourceTable(mergingStrategies, sourceSchema);
             populatePrimaryKeyFromSourceTable(mergingStrategies, sourceSchema);
@@ -279,10 +259,7 @@ class MergeTableLikeUtil {
             for (UnresolvedColumn sourceColumn : sourceSchema.getColumns()) {
                 if (sourceColumn instanceof UnresolvedPhysicalColumn) {
                     LogicalType columnType =
-                            dataTypeFactory
-                                    .createDataType(
-                                            ((UnresolvedPhysicalColumn) sourceColumn).getDataType())
-                                    .getLogicalType();
+                            getLogicalType((UnresolvedPhysicalColumn) sourceColumn);
                     physicalFieldNamesToTypes.put(
                             sourceColumn.getName(),
                             typeFactory.createFieldTypeFromLogicalType(columnType));
@@ -325,113 +302,35 @@ class MergeTableLikeUtil {
                         "The base table already has a primary key. You might "
                                 + "want to specify EXCLUDING CONSTRAINTS.");
             } else if (derivedPrimaryKey != null) {
-                List<String> primaryKeyColumns = new ArrayList<>();
-                for (SqlNode primaryKeyNode : derivedPrimaryKey.getColumns()) {
-                    String primaryKey = ((SqlIdentifier) primaryKeyNode).getSimple();
-                    if (!columns.containsKey(primaryKey)) {
-                        throw new ValidationException(
-                                String.format(
-                                        "Primary key column '%s' is not defined in the schema at %s",
-                                        primaryKey, primaryKeyNode.getParserPosition()));
-                    }
-                    if (!(columns.get(primaryKey) instanceof UnresolvedPhysicalColumn)) {
-                        throw new ValidationException(
-                                String.format(
-                                        "Could not create a PRIMARY KEY with column '%s' at %s.\n"
-                                                + "A PRIMARY KEY constraint must be declared on physical columns.",
-                                        primaryKey, primaryKeyNode.getParserPosition()));
-                    }
-                    primaryKeyColumns.add(primaryKey);
-                }
-                primaryKey =
-                        new UnresolvedPrimaryKey(
-                                derivedPrimaryKey
-                                        .getConstraintName()
-                                        .orElseGet(
-                                                () ->
-                                                        primaryKeyColumns.stream()
-                                                                .collect(
-                                                                        Collectors.joining(
-                                                                                "_", "PK_", ""))),
-                                primaryKeyColumns);
+                setPrimaryKey(derivedPrimaryKey);
             }
         }
 
         private void appendDerivedWatermarks(
                 Map<FeatureOption, MergingStrategy> mergingStrategies,
                 List<SqlWatermark> derivedWatermarkSpecs) {
-            for (SqlWatermark derivedWatermarkSpec : derivedWatermarkSpecs) {
-                SqlIdentifier eventTimeColumnName = derivedWatermarkSpec.getEventTimeColumnName();
+            if (mergingStrategies.get(FeatureOption.WATERMARKS) != MergingStrategy.OVERWRITING) {
+                for (SqlWatermark derivedWatermarkSpec : derivedWatermarkSpecs) {
+                    SqlIdentifier eventTimeColumnName =
+                            derivedWatermarkSpec.getEventTimeColumnName();
+                    String rowtimeAttribute = eventTimeColumnName.toString();
 
-                HashMap<String, RelDataType> nameToTypeMap = new LinkedHashMap<>();
-                nameToTypeMap.putAll(physicalFieldNamesToTypes);
-                nameToTypeMap.putAll(metadataFieldNamesToTypes);
-                nameToTypeMap.putAll(computedFieldNamesToTypes);
-
-                verifyRowtimeAttribute(mergingStrategies, eventTimeColumnName, nameToTypeMap);
-                String rowtimeAttribute = eventTimeColumnName.toString();
-
-                SqlNode expression = derivedWatermarkSpec.getWatermarkStrategy();
-
-                // this will validate and expand function identifiers.
-                SqlNode validated =
-                        sqlValidator.validateParameterizedExpression(expression, nameToTypeMap);
-
-                watermarkSpecs.put(
-                        rowtimeAttribute,
-                        new UnresolvedWatermarkSpec(
-                                rowtimeAttribute,
-                                new SqlCallExpression(escapeExpressions.apply(validated))));
-            }
-        }
-
-        private void verifyRowtimeAttribute(
-                Map<FeatureOption, MergingStrategy> mergingStrategies,
-                SqlIdentifier eventTimeColumnName,
-                Map<String, RelDataType> allFieldsTypes) {
-            String fullRowtimeExpression = eventTimeColumnName.toString();
-            boolean specAlreadyExists = watermarkSpecs.containsKey(fullRowtimeExpression);
-
-            if (specAlreadyExists
-                    && mergingStrategies.get(FeatureOption.WATERMARKS)
-                            != MergingStrategy.OVERWRITING) {
-                throw new ValidationException(
-                        String.format(
-                                "There already exists a watermark spec for column '%s' in the base table. You "
-                                        + "might want to specify EXCLUDING WATERMARKS or OVERWRITING WATERMARKS.",
-                                fullRowtimeExpression));
-            }
-
-            List<String> components = eventTimeColumnName.names;
-            if (!allFieldsTypes.containsKey(components.get(0))) {
-                throw new ValidationException(
-                        String.format(
-                                "The rowtime attribute field '%s' is not defined in the table schema, at %s\n"
-                                        + "Available fields: [%s]",
-                                fullRowtimeExpression,
-                                eventTimeColumnName.getParserPosition(),
-                                allFieldsTypes.keySet().stream()
-                                        .collect(Collectors.joining("', '", "'", "'"))));
-            }
-
-            if (components.size() > 1) {
-                RelDataType componentType = allFieldsTypes.get(components.get(0));
-                for (int i = 1; i < components.size(); i++) {
-                    RelDataTypeField field = componentType.getField(components.get(i), true, false);
-                    if (field == null) {
+                    if (watermarkSpecs.containsKey(rowtimeAttribute)) {
                         throw new ValidationException(
                                 String.format(
-                                        "The rowtime attribute field '%s' is not defined in the table schema, at %s\n"
-                                                + "Nested field '%s' was not found in a composite type: %s.",
-                                        fullRowtimeExpression,
-                                        eventTimeColumnName.getComponent(i).getParserPosition(),
-                                        components.get(i),
-                                        FlinkTypeFactory.toLogicalType(
-                                                allFieldsTypes.get(components.get(0)))));
+                                        "There already exists a watermark spec for column '%s' in the base table. You "
+                                                + "might want to specify EXCLUDING WATERMARKS or OVERWRITING WATERMARKS.",
+                                        rowtimeAttribute));
                     }
-                    componentType = field.getType();
                 }
             }
+
+            HashMap<String, RelDataType> nameToTypeMap = new LinkedHashMap<>();
+            nameToTypeMap.putAll(physicalFieldNamesToTypes);
+            nameToTypeMap.putAll(metadataFieldNamesToTypes);
+            nameToTypeMap.putAll(computedFieldNamesToTypes);
+
+            addWatermarks(derivedWatermarkSpecs, nameToTypeMap, true);
         }
 
         private void appendDerivedColumns(
@@ -442,20 +341,10 @@ class MergeTableLikeUtil {
 
             for (SqlNode derivedColumn : derivedColumns) {
                 final String name = ((SqlTableColumn) derivedColumn).getName().getSimple();
-                final String comment =
-                        ((SqlTableColumn) derivedColumn)
-                                .getComment()
-                                .map(c -> ((SqlLiteral) c).getValueAs(String.class))
-                                .orElse(null);
+
                 final UnresolvedColumn column;
                 if (derivedColumn instanceof SqlRegularColumn) {
-                    final LogicalType logicalType =
-                            FlinkTypeFactory.toLogicalType(physicalFieldNamesToTypes.get(name));
-                    column =
-                            new UnresolvedPhysicalColumn(
-                                    name,
-                                    TypeConversions.fromLogicalToDataType(logicalType),
-                                    comment);
+                    column = toUnresolvedPhysicalColumn((SqlRegularColumn) derivedColumn);
                 } else if (derivedColumn instanceof SqlComputedColumn) {
                     final SqlComputedColumn computedColumn = (SqlComputedColumn) derivedColumn;
                     if (physicalFieldNamesToTypes.containsKey(name)) {
@@ -494,10 +383,8 @@ class MergeTableLikeUtil {
                     final RelDataType validatedType =
                             sqlValidator.getValidatedNodeType(validatedExpr);
                     column =
-                            new UnresolvedComputedColumn(
-                                    name,
-                                    new SqlCallExpression(escapeExpressions.apply(validatedExpr)),
-                                    comment);
+                            toUnresolvedComputedColumn(
+                                    (SqlComputedColumn) derivedColumn, validatedExpr);
                     computedFieldNamesToTypes.put(name, validatedType);
                 } else if (derivedColumn instanceof SqlMetadataColumn) {
                     final SqlMetadataColumn metadataColumn = (SqlMetadataColumn) derivedColumn;
@@ -527,16 +414,8 @@ class MergeTableLikeUtil {
                         }
                     }
 
-                    SqlDataTypeSpec type = metadataColumn.getType();
-                    boolean nullable = type.getNullable() == null || type.getNullable();
-                    RelDataType relType = type.deriveType(sqlValidator, nullable);
-                    column =
-                            new UnresolvedMetadataColumn(
-                                    name,
-                                    fromLogicalToDataType(toLogicalType(relType)),
-                                    metadataColumn.getMetadataAlias().orElse(null),
-                                    metadataColumn.isVirtual(),
-                                    comment);
+                    RelDataType relType = toRelDataType(metadataColumn.getType());
+                    column = toUnresolvedMetadataColumn((SqlMetadataColumn) derivedColumn);
                     metadataFieldNamesToTypes.put(name, relType);
                 } else {
                     throw new ValidationException("Unsupported column type: " + derivedColumn);
@@ -556,9 +435,7 @@ class MergeTableLikeUtil {
                                         "A column named '%s' already exists in the base table.",
                                         name));
                     }
-                    SqlDataTypeSpec type = regularColumn.getType();
-                    boolean nullable = type.getNullable() == null || type.getNullable();
-                    RelDataType relType = type.deriveType(sqlValidator, nullable);
+                    RelDataType relType = toRelDataType(regularColumn.getType());
                     // add field name and field type to physical field list
                     RelDataType oldType = physicalFieldNamesToTypes.put(name, relType);
                     if (oldType != null) {
@@ -570,21 +447,5 @@ class MergeTableLikeUtil {
                 }
             }
         }
-
-        public Schema build() {
-            Schema.Builder resultBuilder = Schema.newBuilder();
-            resultBuilder.fromColumns(new ArrayList<>(columns.values()));
-
-            for (UnresolvedWatermarkSpec watermarkSpec : watermarkSpecs.values()) {
-                resultBuilder.watermark(
-                        watermarkSpec.getColumnName(), watermarkSpec.getWatermarkExpression());
-            }
-            if (primaryKey != null) {
-                resultBuilder.primaryKeyNamed(
-                        primaryKey.getConstraintName(),
-                        primaryKey.getColumnNames().toArray(new String[0]));
-            }
-            return resultBuilder.build();
-        }
     }
 }
