@@ -22,10 +22,10 @@ import org.apache.flink.table.functions.BuiltInFunctionDefinitions;
 import org.apache.flink.table.planner.calcite.FlinkTypeFactory;
 import org.apache.flink.table.planner.functions.bridging.BridgingSqlFunction;
 import org.apache.flink.table.planner.utils.ShortcutUtils;
-import org.apache.flink.table.runtime.functions.table.UnnestRowsFunction;
+import org.apache.flink.table.runtime.functions.table.UnnestRowsFunctionBase;
 import org.apache.flink.table.types.logical.LogicalType;
 
-import org.apache.flink.shaded.guava32.com.google.common.collect.ImmutableList;
+import org.apache.flink.shaded.guava33.com.google.common.collect.ImmutableList;
 
 import org.apache.calcite.plan.RelOptCluster;
 import org.apache.calcite.plan.RelOptRuleCall;
@@ -68,26 +68,18 @@ public class LogicalUnnestRule extends RelRule<LogicalUnnestRule.LogicalUnnestRu
             LogicalFilter logicalFilter = (LogicalFilter) right;
             RelNode relNode = getRel(logicalFilter.getInput());
             if (relNode instanceof Uncollect) {
-                return !((Uncollect) relNode).withOrdinality;
+                return true;
             } else if (relNode instanceof LogicalProject) {
                 LogicalProject logicalProject = (LogicalProject) relNode;
                 relNode = getRel(logicalProject.getInput());
-                if (relNode instanceof Uncollect) {
-                    return !((Uncollect) relNode).withOrdinality;
-                }
-                return false;
+                return relNode instanceof Uncollect;
             }
         } else if (right instanceof LogicalProject) {
             LogicalProject logicalProject = (LogicalProject) right;
             RelNode relNode = getRel(logicalProject.getInput());
-            if (relNode instanceof Uncollect) {
-                Uncollect uncollect = (Uncollect) relNode;
-                return !uncollect.withOrdinality;
-            }
-            return false;
-        } else if (right instanceof Uncollect) {
-            Uncollect uncollect = (Uncollect) right;
-            return !uncollect.withOrdinality;
+            return relNode instanceof Uncollect;
+        } else {
+            return right instanceof Uncollect;
         }
         return false;
     }
@@ -131,16 +123,22 @@ public class LogicalUnnestRule extends RelRule<LogicalUnnestRule.LogicalUnnestRu
                             ((Map.Entry) uncollect.getInput().getRowType().getFieldList().get(0))
                                     .getValue();
             LogicalType logicalType = FlinkTypeFactory.toLogicalType(relDataType);
+
             BridgingSqlFunction sqlFunction =
                     BridgingSqlFunction.of(
-                            cluster, BuiltInFunctionDefinitions.INTERNAL_UNNEST_ROWS);
+                            cluster,
+                            uncollect.withOrdinality
+                                    ? BuiltInFunctionDefinitions
+                                            .INTERNAL_UNNEST_ROWS_WITH_ORDINALITY
+                                    : BuiltInFunctionDefinitions.INTERNAL_UNNEST_ROWS);
             RexNode rexCall =
                     cluster.getRexBuilder()
                             .makeCall(
                                     typeFactory.createFieldTypeFromLogicalType(
                                             toRowType(
-                                                    UnnestRowsFunction.getUnnestedType(
-                                                            logicalType))),
+                                                    UnnestRowsFunctionBase.getUnnestedType(
+                                                            logicalType,
+                                                            uncollect.withOrdinality))),
                                     sqlFunction,
                                     ((LogicalProject) getRel(uncollect.getInput())).getProjects());
             return new LogicalTableFunctionScan(
