@@ -17,22 +17,16 @@
  */
 package org.apache.flink.table.planner.plan.rules.physical.batch
 
-import org.apache.flink.annotation.Experimental
-import org.apache.flink.configuration.ConfigOption
-import org.apache.flink.configuration.ConfigOptions.key
 import org.apache.flink.table.planner.plan.`trait`.FlinkRelDistribution
 import org.apache.flink.table.planner.plan.nodes.FlinkConventions
 import org.apache.flink.table.planner.plan.nodes.logical.FlinkLogicalSort
 import org.apache.flink.table.planner.plan.nodes.physical.batch.BatchPhysicalSort
-import org.apache.flink.table.planner.utils.ShortcutUtils
 
 import org.apache.calcite.plan.{RelOptRule, RelOptRuleCall}
 import org.apache.calcite.rel.RelNode
 import org.apache.calcite.rel.convert.ConverterRule
 import org.apache.calcite.rel.convert.ConverterRule.Config
 
-import java.lang.{Boolean => JBoolean}
-
 /**
  * Rule that matches [[FlinkLogicalSort]] which sort fields is non-empty and both `fetch` and
  * `offset` are null, and converts it to [[BatchPhysicalSort]].
@@ -48,13 +42,7 @@ class BatchPhysicalSortRule(config: Config) extends ConverterRule(config) {
   override def convert(rel: RelNode): RelNode = {
     val sort: FlinkLogicalSort = rel.asInstanceOf[FlinkLogicalSort]
     val input = sort.getInput
-    val tableConfig = ShortcutUtils.unwrapTableConfig(sort)
-    val enableRangeSort = tableConfig.get(BatchPhysicalSortRule.TABLE_EXEC_RANGE_SORT_ENABLED)
-    val distribution = if (enableRangeSort) {
-      FlinkRelDistribution.range(sort.getCollation.getFieldCollations)
-    } else {
-      FlinkRelDistribution.SINGLETON
-    }
+    val distribution = FlinkRelDistribution.SINGLETON
     val requiredTraitSet = input.getTraitSet
       .replace(distribution)
       .replace(FlinkConventions.BATCH_PHYSICAL)
@@ -74,15 +62,4 @@ object BatchPhysicalSortRule {
       FlinkConventions.LOGICAL,
       FlinkConventions.BATCH_PHYSICAL,
       "BatchPhysicalSortRule"))
-
-  /** This configuration will be removed in Flink 2.0. */
-  @Deprecated
-  @Experimental
-  val TABLE_EXEC_RANGE_SORT_ENABLED: ConfigOption[JBoolean] =
-    key("table.exec.range-sort.enabled")
-      .booleanType()
-      .defaultValue(JBoolean.valueOf(false))
-      .withDescription("Sets whether to enable range sort, use range sort to sort all data in" +
-        " several partitions. When it is false, sorting in only one partition")
-
 }
