@@ -21,6 +21,8 @@ package org.apache.flink.table.api;
 import org.apache.flink.api.dag.Transformation;
 import org.apache.flink.streaming.api.graph.StreamGraph;
 import org.apache.flink.table.api.internal.TableEnvironmentImpl;
+import org.apache.flink.table.expressions.SqlFactory;
+import org.apache.flink.table.functions.FunctionDefinition;
 import org.apache.flink.table.operations.CollectModifyOperation;
 import org.apache.flink.table.operations.QueryOperation;
 import org.apache.flink.table.test.program.SqlTestStep;
@@ -65,7 +67,10 @@ public class QueryOperationSqlSerializationTest implements TableTestProgramRunne
                 QueryOperationTestPrograms.OVER_WINDOW_ROWS,
                 QueryOperationTestPrograms.OVER_WINDOW_ROWS_UNBOUNDED_NO_PARTITION,
                 QueryOperationTestPrograms.OVER_WINDOW_LAG,
-                QueryOperationTestPrograms.ACCESSING_NESTED_COLUMN);
+                QueryOperationTestPrograms.ACCESSING_NESTED_COLUMN,
+                QueryOperationTestPrograms.ROW_SEMANTIC_TABLE_PTF,
+                QueryOperationTestPrograms.SET_SEMANTIC_TABLE_PTF,
+                QueryOperationTestPrograms.INLINE_FUNCTION_SERIALIZATION);
     }
 
     @ParameterizedTest
@@ -87,7 +92,8 @@ public class QueryOperationSqlSerializationTest implements TableTestProgramRunne
                                 .findFirst()
                                 .get();
         final Table table = tableApiStep.toTable(env);
-        assertThat(table.getQueryOperation().asSerializableString()).isEqualTo(sqlStep.sql);
+        assertThat(table.getQueryOperation().asSerializableString(new InlineFunctionSqlFactory()))
+                .isEqualTo(sqlStep.sql);
     }
 
     @ParameterizedTest
@@ -124,29 +130,44 @@ public class QueryOperationSqlSerializationTest implements TableTestProgramRunne
     }
 
     private static TableEnvironment setupEnv(TableTestProgram program) {
-        final TableEnvironment env = TableEnvironment.create(EnvironmentSettings.inStreamingMode());
+        final TableEnvironment env =
+                TableEnvironment.create(
+                        EnvironmentSettings.newInstance()
+                                .inStreamingMode()
+                                .withSqlFactory(new InlineFunctionSqlFactory())
+                                .build());
         final Map<String, String> connectorOptions = new HashMap<>();
         connectorOptions.put("connector", "values");
         program.getSetupSourceTestSteps().forEach(s -> s.apply(env, connectorOptions));
         program.getSetupSinkTestSteps().forEach(s -> s.apply(env, connectorOptions));
         program.getSetupFunctionTestSteps().forEach(f -> f.apply(env));
+        program.getSetupSqlTestSteps().forEach(s -> s.apply(env));
         return env;
     }
 
     @Override
     public EnumSet<TestKind> supportedSetupSteps() {
         return EnumSet.of(
+                TestKind.SQL,
                 TestKind.FUNCTION,
                 TestKind.SOURCE_WITH_DATA,
-                TestKind.SOURCE_WITHOUT_DATA,
-                TestKind.SOURCE_WITH_RESTORE_DATA, // restore data is ignored
-                TestKind.SINK_WITH_DATA,
-                TestKind.SINK_WITH_RESTORE_DATA // restore data is ignored
-                );
+                TestKind.SINK_WITH_DATA);
     }
 
     @Override
     public EnumSet<TestKind> supportedRunSteps() {
         return EnumSet.of(TestKind.TABLE_API, TestKind.SQL);
     }
+
+    private static class InlineFunctionSqlFactory implements SqlFactory {
+
+        private final Map<FunctionDefinition, String> functionNameMap = new HashMap<>();
+
+        @Override
+        public String serializeInlineFunction(FunctionDefinition functionDefinition) {
+            return functionNameMap.computeIfAbsent(
+                    functionDefinition,
+                    fd -> String.format("inlineFunction$%02d", functionNameMap.size()));
+        }
+    }
 }
