@@ -21,8 +21,8 @@ import org.apache.flink.api.common.typeinfo.{BasicTypeInfo, TypeInformation}
 import org.apache.flink.api.java.typeutils.RowTypeInfo
 import org.apache.flink.cep.pattern.Pattern
 import org.apache.flink.configuration.Configuration
-import org.apache.flink.streaming.api.datastream.{DataStream => JDataStream}
-import org.apache.flink.streaming.api.scala.{DataStream, StreamExecutionEnvironment}
+import org.apache.flink.streaming.api.datastream.DataStream
+import org.apache.flink.streaming.api.environment.StreamExecutionEnvironment
 import org.apache.flink.table.api._
 import org.apache.flink.table.api.bridge.scala.StreamTableEnvironment
 import org.apache.flink.table.api.internal.TableEnvironmentImpl
@@ -56,17 +56,15 @@ abstract class PatternTranslatorTestBase {
       typeInfo: TypeInformation[Row]): (RelBuilder, PlannerBase, StreamExecutionEnvironment) = {
     // create DataStreamTable
     val dataStreamMock = mock(classOf[DataStream[Row]])
-    val jDataStreamMock = mock(classOf[JDataStream[Row]])
-    when(dataStreamMock.javaStream).thenReturn(jDataStreamMock)
-    when(jDataStreamMock.getType).thenReturn(typeInfo)
-    when(jDataStreamMock.getId).thenReturn(0)
+    when(dataStreamMock.getType).thenReturn(typeInfo)
+    when(dataStreamMock.getId).thenReturn(0)
 
     val env = StreamExecutionEnvironment.getExecutionEnvironment
     val tEnv = StreamTableEnvironment.create(env, TableTestUtil.STREAM_SETTING)
     TableTestUtil.createTemporaryView(
       tEnv,
       tableName,
-      dataStreamMock.javaStream,
+      dataStreamMock,
       Some(Array[Expression]('f0, 'proctime.proctime)))
 
     // prepare RelBuilder
