@@ -18,8 +18,9 @@
 package org.apache.flink.table.planner.plan.cost
 
 import org.apache.calcite.plan.RelOptCostImpl
-import org.junit.Assert._
-import org.junit.Test
+import org.assertj.core.api.Assertions.assertThatThrownBy
+import org.junit.jupiter.api.Assertions._
+import org.junit.jupiter.api.Test
 
 class FlinkCostTest {
 
@@ -88,9 +89,10 @@ class FlinkCostTest {
     assertTrue(cost4.isLe(cost1))
   }
 
-  @Test(expected = classOf[ClassCastException])
+  @Test
   def testIsLe_WithDiffCost(): Unit = {
-    FlinkCost.Tiny.isLe(RelOptCostImpl.FACTORY.makeTinyCost())
+    assertThatThrownBy(() => FlinkCost.Tiny.isLe(RelOptCostImpl.FACTORY.makeTinyCost()))
+      .isInstanceOf(classOf[ClassCastException])
   }
 
   @Test
@@ -111,9 +113,10 @@ class FlinkCostTest {
     assertTrue(cost4.isLt(cost1))
   }
 
-  @Test(expected = classOf[ClassCastException])
+  @Test
   def testIsLt_WithDiffCost(): Unit = {
-    FlinkCost.Tiny.isLt(RelOptCostImpl.FACTORY.makeTinyCost())
+    assertThatThrownBy(() => FlinkCost.Tiny.isLt(RelOptCostImpl.FACTORY.makeTinyCost()))
+      .isInstanceOf(classOf[ClassCastException])
   }
 
   @Test
@@ -133,9 +136,10 @@ class FlinkCostTest {
     assertTrue(expectedCost2.equals(cost1.plus(cost3)))
   }
 
-  @Test(expected = classOf[ClassCastException])
+  @Test
   def testPlus_WithDiffCost(): Unit = {
-    FlinkCost.Tiny.plus(RelOptCostImpl.FACTORY.makeTinyCost())
+    assertThatThrownBy(() => FlinkCost.Tiny.plus(RelOptCostImpl.FACTORY.makeTinyCost()))
+      .isInstanceOf(classOf[ClassCastException])
   }
 
   @Test
@@ -159,9 +163,10 @@ class FlinkCostTest {
     assertTrue(expectedCost3.equals(cost2.minus(cost1)))
   }
 
-  @Test(expected = classOf[ClassCastException])
+  @Test
   def testMinus_WithDiffCost(): Unit = {
-    FlinkCost.Tiny.minus(RelOptCostImpl.FACTORY.makeTinyCost())
+    assertThatThrownBy(() => FlinkCost.Tiny.minus(RelOptCostImpl.FACTORY.makeTinyCost()))
+      .isInstanceOf(classOf[ClassCastException])
   }
 
   @Test
