@@ -17,44 +17,53 @@
  */
 package org.apache.flink.table.planner.runtime.harness
 
-import org.apache.flink.api.scala._
 import org.apache.flink.streaming.util.KeyedOneInputStreamOperatorTestHarness
 import org.apache.flink.table.api._
 import org.apache.flink.table.api.bridge.scala._
 import org.apache.flink.table.api.bridge.scala.internal.StreamTableEnvironmentImpl
+import org.apache.flink.table.api.config.ExecutionConfigOptions
 import org.apache.flink.table.data.RowData
 import org.apache.flink.table.planner.JInt
-import org.apache.flink.table.planner.runtime.utils.JavaUserDefinedTableFunctions
-import org.apache.flink.table.planner.runtime.utils.StreamingWithStateTestBase.StateBackendMode
+import org.apache.flink.table.planner.runtime.utils.{JavaUserDefinedTableFunctions, StreamingEnvUtil}
+import org.apache.flink.table.planner.runtime.utils.StreamingWithStateTestBase.{HEAP_BACKEND, ROCKSDB_BACKEND, StateBackendMode}
 import org.apache.flink.table.runtime.util.RowDataHarnessAssertor
 import org.apache.flink.table.runtime.util.StreamRecordUtils.binaryRecord
-import org.apache.flink.testutils.junit.extensions.parameterized.ParameterizedTestExtension
+import org.apache.flink.table.types.logical.LogicalType
+import org.apache.flink.testutils.junit.extensions.parameterized.{ParameterizedTestExtension, Parameters}
 import org.apache.flink.types.Row
 import org.apache.flink.types.RowKind._
 
+import org.assertj.core.api.Assertions.assertThat
 import org.junit.jupiter.api.{BeforeEach, TestTemplate}
 import org.junit.jupiter.api.extension.ExtendWith
 
 import java.lang.{Long => JLong}
 import java.time.Duration
+import java.util
 import java.util.concurrent.ConcurrentLinkedQueue
 
+import scala.collection.JavaConversions._
 import scala.collection.mutable
 
 @ExtendWith(Array(classOf[ParameterizedTestExtension]))
-class RankHarnessTest(mode: StateBackendMode) extends HarnessTestBase(mode) {
+class RankHarnessTest(mode: StateBackendMode, enableAsyncState: Boolean)
+  extends HarnessTestBase(mode) {
 
   @BeforeEach
   override def before(): Unit = {
     super.before()
     val setting = EnvironmentSettings.newInstance().inStreamingMode().build()
     this.tEnv = StreamTableEnvironmentImpl.create(env, setting)
+
+    tEnv.getConfig.set(
+      ExecutionConfigOptions.TABLE_EXEC_ASYNC_STATE_ENABLED,
+      Boolean.box(enableAsyncState))
   }
 
   @TestTemplate
   def testRetractRankWithRowNumber(): Unit = {
     val data = new mutable.MutableList[(String, String, Long)]
-    val t = env.fromCollection(data).toTable(tEnv, 'a, 'b, 'c)
+    val t = StreamingEnvUtil.fromCollection(env, data).toTable(tEnv, 'a, 'b, 'c)
     tEnv.createTemporaryView("T", t)
     tEnv.createTemporarySystemFunction(
       "STRING_SPLIT",
@@ -93,6 +102,8 @@ class RankHarnessTest(mode: StateBackendMode) extends HarnessTestBase(mode) {
         DataTypes.BIGINT().getLogicalType
       ))
 
+    assertThat(isAsyncStateOperator(testHarness)).isFalse
+
     testHarness.open()
 
     // set TtlTimeProvider with 1
@@ -150,7 +161,7 @@ class RankHarnessTest(mode: StateBackendMode) extends HarnessTestBase(mode) {
   @TestTemplate
   def testRetractRankWithoutRowNumber(): Unit = {
     val data = new mutable.MutableList[(String, String, Long)]
-    val t = env.fromCollection(data).toTable(tEnv, 'a, 'b, 'c)
+    val t = StreamingEnvUtil.fromCollection(env, data).toTable(tEnv, 'a, 'b, 'c)
     tEnv.createTemporaryView("T", t)
     tEnv.createTemporarySystemFunction(
       "STRING_SPLIT",
@@ -187,6 +198,8 @@ class RankHarnessTest(mode: StateBackendMode) extends HarnessTestBase(mode) {
         DataTypes.BIGINT().getLogicalType,
         DataTypes.STRING().getLogicalType))
 
+    assertThat(isAsyncStateOperator(testHarness)).isFalse
+
     testHarness.open()
 
     // set TtlTimeProvider with 1
@@ -228,7 +241,7 @@ class RankHarnessTest(mode: StateBackendMode) extends HarnessTestBase(mode) {
   def prepareUpdateRankWithRowNumberTester()
       : (KeyedOneInputStreamOperatorTestHarness[RowData, RowData, RowData], RowDataHarnessAssertor) = {
     val data = new mutable.MutableList[(String, Int, Int)]
-    val t = env.fromCollection(data).toTable(tEnv, 'word, 'cnt, 'type)
+    val t = StreamingEnvUtil.fromCollection(env, data).toTable(tEnv, 'word, 'cnt, 'type)
     tEnv.createTemporaryView("T", t)
 
     val sql =
@@ -254,6 +267,9 @@ class RankHarnessTest(mode: StateBackendMode) extends HarnessTestBase(mode) {
         DataTypes.INT().getLogicalType,
         DataTypes.INT().getLogicalType,
         DataTypes.BIGINT().getLogicalType))
+
+    assertThat(isAsyncStateOperator(testHarness)).isFalse
+
     (testHarness, assertor)
   }
 
@@ -452,4 +468,272 @@ class RankHarnessTest(mode: StateBackendMode) extends HarnessTestBase(mode) {
     assertor.assertOutputEqualsSorted("result mismatch", expectedOutput, result)
     testHarness.close()
   }
+
+  def prepareRankTester(
+      query: String,
+      operatorNameIdentifier: String,
+      operatorOutputLogicalTypes: Array[LogicalType])
+      : (KeyedOneInputStreamOperatorTestHarness[RowData, RowData, RowData], RowDataHarnessAssertor) = {
+    val sourceDDL =
+      s"""
+         |CREATE TEMPORARY TABLE T(
+         |  a STRING PRIMARY KEY NOT ENFORCED,
+         |  b BIGINT
+         |) WITH (
+         |  'connector' = 'values',
+         |  'changelog-mode' = 'I'
+         |)
+         |""".stripMargin
+    tEnv.executeSql(sourceDDL)
+
+    val t1 = tEnv.sqlQuery(query)
+
+    val testHarness =
+      createHarnessTester(t1.toRetractStream[Row], operatorNameIdentifier)
+    val assertor = new RowDataHarnessAssertor(operatorOutputLogicalTypes)
+
+    (testHarness, assertor)
+  }
+
+  @TestTemplate
+  def testAppendFastTop1(): Unit = {
+    tEnv.getConfig.setIdleStateRetention(Duration.ofSeconds(1))
+    val query =
+      """
+        |SELECT a, b
+        |FROM
+        |(
+        |    SELECT a, b,
+        |        ROW_NUMBER() OVER (PARTITION BY a ORDER BY b DESC) AS rn
+        |    FROM T
+        |) t1
+        |WHERE rn <= 1
+      """.stripMargin
+    val (testHarness, assertor) =
+      prepareRankTester(
+        query,
+        "Rank(strategy=[AppendFastStrategy",
+        Array(DataTypes.STRING().getLogicalType, DataTypes.BIGINT().getLogicalType)
+      )
+
+    if (enableAsyncState) {
+      assertThat(isAsyncStateOperator(testHarness)).isTrue
+    } else {
+      assertThat(isAsyncStateOperator(testHarness)).isFalse
+    }
+
+    testHarness.open()
+
+    testHarness.processElement(binaryRecord(INSERT, "a", 2L: JLong))
+    testHarness.processElement(binaryRecord(INSERT, "a", 1L: JLong))
+    testHarness.processElement(binaryRecord(INSERT, "a", 3L: JLong))
+
+    val result = dropWatermarks(testHarness.getOutput.toArray)
+
+    val expectedOutput = new ConcurrentLinkedQueue[Object]()
+    expectedOutput.add(binaryRecord(INSERT, "a", 2L: JLong))
+    expectedOutput.add(binaryRecord(UPDATE_BEFORE, "a", 2L: JLong))
+    expectedOutput.add(binaryRecord(UPDATE_AFTER, "a", 3L: JLong))
+
+    assertor.assertOutputEqualsSorted("result mismatch", expectedOutput, result)
+
+    testHarness.close()
+  }
+
+  @TestTemplate
+  def testUpdateFastTop1(): Unit = {
+    tEnv.getConfig.setIdleStateRetention(Duration.ofSeconds(1))
+    val query =
+      """
+        |SELECT a, b
+        |FROM
+        |(
+        |    SELECT a, b,
+        |        ROW_NUMBER() OVER (PARTITION BY a ORDER BY b DESC) AS rn
+        |    FROM (
+        |       select a, count(*) as b from T group by a
+        |    ) t1
+        |) t2
+        |WHERE rn <= 1
+      """.stripMargin
+    val (testHarness, assertor) =
+      prepareRankTester(
+        query,
+        "Rank(strategy=[UpdateFastStrategy",
+        Array(DataTypes.STRING().getLogicalType, DataTypes.BIGINT().getLogicalType)
+      )
+
+    if (enableAsyncState) {
+      assertThat(isAsyncStateOperator(testHarness)).isTrue
+    } else {
+      assertThat(isAsyncStateOperator(testHarness)).isFalse
+    }
+
+    testHarness.open()
+
+    testHarness.processElement(binaryRecord(INSERT, "a", 2L: JLong))
+    testHarness.processElement(binaryRecord(UPDATE_AFTER, "a", 3L: JLong))
+    testHarness.processElement(binaryRecord(UPDATE_AFTER, "a", 4L: JLong))
+
+    val result = dropWatermarks(testHarness.getOutput.toArray)
+
+    val expectedOutput = new ConcurrentLinkedQueue[Object]()
+    expectedOutput.add(binaryRecord(INSERT, "a", 2L: JLong))
+    expectedOutput.add(binaryRecord(UPDATE_BEFORE, "a", 2L: JLong))
+    expectedOutput.add(binaryRecord(UPDATE_AFTER, "a", 3L: JLong))
+    expectedOutput.add(binaryRecord(UPDATE_BEFORE, "a", 3L: JLong))
+    expectedOutput.add(binaryRecord(UPDATE_AFTER, "a", 4L: JLong))
+
+    assertor.assertOutputEqualsSorted("result mismatch", expectedOutput, result)
+
+    testHarness.close()
+  }
+
+  @TestTemplate
+  def testAppendOnlyTopNWithRowNumber(): Unit = {
+    tEnv.getConfig.setIdleStateRetention(Duration.ofSeconds(1))
+    val query =
+      """
+        |SELECT a, b, rn
+        |FROM
+        |(
+        |    SELECT a, b,
+        |        ROW_NUMBER() OVER (PARTITION BY a ORDER BY b DESC) AS rn
+        |    FROM T
+        |) t1
+        |WHERE rn <= 3
+      """.stripMargin
+    val (testHarness, assertor) =
+      prepareRankTester(
+        query,
+        "Rank(strategy=[AppendFastStrategy",
+        Array(
+          DataTypes.STRING().getLogicalType,
+          DataTypes.BIGINT().getLogicalType,
+          DataTypes.BIGINT().getLogicalType)
+      )
+
+    if (enableAsyncState) {
+      assertThat(isAsyncStateOperator(testHarness)).isTrue
+    } else {
+      assertThat(isAsyncStateOperator(testHarness)).isFalse
+    }
+
+    testHarness.open()
+
+    val expectedOutput = new ConcurrentLinkedQueue[Object]()
+
+    // a,2 - top1
+    testHarness.processElement(binaryRecord(INSERT, "a", 2L: JLong))
+    expectedOutput.add(binaryRecord(INSERT, "a", 2L: JLong, 1L: JLong))
+
+    // a,2 - top1
+    // a,1 - top2
+    testHarness.processElement(binaryRecord(INSERT, "a", 1L: JLong))
+    expectedOutput.add(binaryRecord(INSERT, "a", 1L: JLong, 2L: JLong))
+
+    // a,3 - top1
+    // a,2 - top2
+    // a,1 - top3
+    testHarness.processElement(binaryRecord(INSERT, "a", 3L: JLong))
+    expectedOutput.add(binaryRecord(UPDATE_BEFORE, "a", 2L: JLong, 1L: JLong))
+    expectedOutput.add(binaryRecord(UPDATE_AFTER, "a", 3L: JLong, 1L: JLong))
+    expectedOutput.add(binaryRecord(UPDATE_BEFORE, "a", 1L: JLong, 2L: JLong))
+    expectedOutput.add(binaryRecord(UPDATE_AFTER, "a", 2L: JLong, 2L: JLong))
+    expectedOutput.add(binaryRecord(INSERT, "a", 1L: JLong, 3L: JLong))
+
+    // a,3 - top1
+    // a,2 - top2
+    // a,1 - top3
+    testHarness.processElement(binaryRecord(INSERT, "a", 0L: JLong))
+
+    // a,3 - top1
+    // a,3 - top2
+    // a,2 - top3
+    testHarness.processElement(binaryRecord(INSERT, "a", 3L: JLong))
+    expectedOutput.add(binaryRecord(UPDATE_BEFORE, "a", 2L: JLong, 2L: JLong))
+    expectedOutput.add(binaryRecord(UPDATE_AFTER, "a", 3L: JLong, 2L: JLong))
+    expectedOutput.add(binaryRecord(UPDATE_BEFORE, "a", 1L: JLong, 3L: JLong))
+    expectedOutput.add(binaryRecord(UPDATE_AFTER, "a", 2L: JLong, 3L: JLong))
+
+    val result = dropWatermarks(testHarness.getOutput.toArray)
+    assertor.assertOutputEqualsSorted("result mismatch", expectedOutput, result)
+
+    testHarness.close()
+  }
+
+  @TestTemplate
+  def testAppendOnlyTopNWithoutRowNumber(): Unit = {
+    tEnv.getConfig.setIdleStateRetention(Duration.ofSeconds(1))
+    val query =
+      """
+        |SELECT a, b
+        |FROM
+        |(
+        |    SELECT a, b,
+        |        ROW_NUMBER() OVER (PARTITION BY a ORDER BY b DESC) AS rn
+        |    FROM T
+        |) t1
+        |WHERE rn <= 3
+      """.stripMargin
+    val (testHarness, assertor) =
+      prepareRankTester(
+        query,
+        "Rank(strategy=[AppendFastStrategy",
+        Array(DataTypes.STRING().getLogicalType, DataTypes.BIGINT().getLogicalType)
+      )
+
+    if (enableAsyncState) {
+      assertThat(isAsyncStateOperator(testHarness)).isTrue
+    } else {
+      assertThat(isAsyncStateOperator(testHarness)).isFalse
+    }
+
+    testHarness.open()
+
+    val expectedOutput = new ConcurrentLinkedQueue[Object]()
+
+    // a,2 - top1
+    testHarness.processElement(binaryRecord(INSERT, "a", 2L: JLong))
+    expectedOutput.add(binaryRecord(INSERT, "a", 2L: JLong))
+
+    // a,2 - top1
+    // a,1 - top2
+    testHarness.processElement(binaryRecord(INSERT, "a", 1L: JLong))
+    expectedOutput.add(binaryRecord(INSERT, "a", 1L: JLong))
+
+    // a,3 - top1
+    // a,2 - top2
+    // a,1 - top3
+    testHarness.processElement(binaryRecord(INSERT, "a", 3L: JLong))
+    expectedOutput.add(binaryRecord(INSERT, "a", 3L: JLong))
+
+    // a,3 - top1
+    // a,2 - top2
+    // a,1 - top3
+    testHarness.processElement(binaryRecord(INSERT, "a", 0L: JLong))
+
+    // a,3 - top1
+    // a,3 - top2
+    // a,2 - top3
+    testHarness.processElement(binaryRecord(INSERT, "a", 3L: JLong))
+    expectedOutput.add(binaryRecord(DELETE, "a", 1L: JLong))
+    expectedOutput.add(binaryRecord(INSERT, "a", 3L: JLong))
+
+    val result = dropWatermarks(testHarness.getOutput.toArray)
+    assertor.assertOutputEqualsSorted("result mismatch", expectedOutput, result)
+
+    testHarness.close()
+  }
+}
+
+object RankHarnessTest {
+
+  @Parameters(name = "StateBackend={0}, EnableAsyncState = {1}")
+  def parameters(): util.Collection[Array[java.lang.Object]] = {
+    Seq[Array[AnyRef]](
+      Array(HEAP_BACKEND, Boolean.box(false)),
+      Array(HEAP_BACKEND, Boolean.box(true)),
+      Array(ROCKSDB_BACKEND, Boolean.box(false)))
+  }
 }
