@@ -20,12 +20,14 @@ package org.apache.flink.table.runtime.operators.over;
 
 import org.apache.flink.configuration.Configuration;
 import org.apache.flink.core.memory.ManagedMemoryUseCase;
+import org.apache.flink.runtime.event.WatermarkEvent;
 import org.apache.flink.runtime.jobgraph.OperatorID;
 import org.apache.flink.runtime.operators.testutils.MockEnvironment;
 import org.apache.flink.runtime.operators.testutils.MockEnvironmentBuilder;
 import org.apache.flink.streaming.api.graph.StreamConfig;
 import org.apache.flink.streaming.api.operators.Output;
 import org.apache.flink.streaming.api.operators.StreamOperator;
+import org.apache.flink.streaming.api.operators.StreamOperatorParameters;
 import org.apache.flink.streaming.api.operators.StreamingRuntimeContext;
 import org.apache.flink.streaming.api.watermark.Watermark;
 import org.apache.flink.streaming.runtime.streamrecord.LatencyMarker;
@@ -47,8 +49,8 @@ import org.apache.flink.table.types.logical.IntType;
 import org.apache.flink.table.types.logical.RowType;
 import org.apache.flink.util.OutputTag;
 
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 import java.util.ArrayList;
 import java.util.List;
@@ -61,7 +63,7 @@ import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.when;
 
 /** Test for {@link NonBufferOverWindowOperator}. */
-public class NonBufferOverWindowOperatorTest {
+class NonBufferOverWindowOperatorTest {
 
     static GeneratedAggsHandleFunction function =
             new GeneratedAggsHandleFunction("Function1", "", new Object[0]) {
@@ -96,13 +98,13 @@ public class NonBufferOverWindowOperatorTest {
     private NonBufferOverWindowOperator operator;
     private List<GenericRowData> collect;
 
-    @Before
-    public void before() throws Exception {
+    @BeforeEach
+    void before() throws Exception {
         collect = new ArrayList<>();
     }
 
     @Test
-    public void testNormal() throws Exception {
+    void testNormal() throws Exception {
         test(
                 new boolean[] {false, false},
                 new GenericRowData[] {
@@ -115,7 +117,7 @@ public class NonBufferOverWindowOperatorTest {
     }
 
     @Test
-    public void testResetAccumulators() throws Exception {
+    void testResetAccumulators() throws Exception {
         test(
                 new boolean[] {true, false},
                 new GenericRowData[] {
@@ -146,24 +148,29 @@ public class NonBufferOverWindowOperatorTest {
                 .thenReturn(0.99);
         when(streamConfig.getOperatorID()).thenReturn(new OperatorID());
         operator =
-                new NonBufferOverWindowOperator(functions, comparator, resetAccumulators) {
+                new NonBufferOverWindowOperator(
+                        new StreamOperatorParameters<>(
+                                task,
+                                streamConfig,
+                                new ConsumerOutput(
+                                        r ->
+                                                collect.add(
+                                                        GenericRowData.of(
+                                                                r.getInt(0),
+                                                                r.getLong(1),
+                                                                r.getLong(2),
+                                                                r.getLong(3),
+                                                                r.getLong(4)))),
+                                TestProcessingTimeService::new,
+                                null,
+                                null),
+                        functions,
+                        comparator,
+                        resetAccumulators) {
                     public StreamingRuntimeContext getRuntimeContext() {
                         return mock(StreamingRuntimeContext.class);
                     }
                 };
-        operator.setProcessingTimeService(new TestProcessingTimeService());
-        operator.setup(
-                task,
-                streamConfig,
-                new ConsumerOutput(
-                        r ->
-                                collect.add(
-                                        GenericRowData.of(
-                                                r.getInt(0),
-                                                r.getLong(1),
-                                                r.getLong(2),
-                                                r.getLong(3),
-                                                r.getLong(4)))));
         operator.open();
         addRow(0, 1L, 4L);
         addRow(0, 1L, 1L);
@@ -212,6 +219,11 @@ public class NonBufferOverWindowOperatorTest {
             throw new RuntimeException();
         }
 
+        @Override
+        public void emitWatermark(WatermarkEvent watermark) {
+            throw new RuntimeException();
+        }
+
         @Override
         public void collect(StreamRecord<RowData> record) {
             consumer.accept(record.getValue());
