@@ -71,7 +71,8 @@ public class TestFileSystemCatalogTest extends TestFileSystemCatalogTestBase {
     private static final List<String> PARTITION_KEYS = Collections.singletonList("partition");
 
     private static final ResolvedSchema CREATE_RESOLVED_SCHEMA =
-            new ResolvedSchema(CREATE_COLUMNS, Collections.emptyList(), CONSTRAINTS);
+            new ResolvedSchema(
+                    CREATE_COLUMNS, Collections.emptyList(), CONSTRAINTS, Collections.emptyList());
 
     private static final Schema CREATE_SCHEMA =
             Schema.newBuilder().fromResolvedSchema(CREATE_RESOLVED_SCHEMA).build();
