@@ -19,8 +19,10 @@
 package org.apache.flink.runtime.jobmaster;
 
 import org.apache.flink.api.common.JobStatus;
-import org.apache.flink.api.common.time.Time;
+import org.apache.flink.client.program.ClusterClient;
 import org.apache.flink.client.program.MiniClusterClient;
+import org.apache.flink.configuration.Configuration;
+import org.apache.flink.configuration.JobManagerOptions;
 import org.apache.flink.core.execution.SavepointFormatType;
 import org.apache.flink.runtime.checkpoint.CheckpointException;
 import org.apache.flink.runtime.checkpoint.CheckpointMetaData;
@@ -37,22 +39,37 @@ import org.apache.flink.runtime.jobgraph.OperatorID;
 import org.apache.flink.runtime.jobgraph.tasks.AbstractInvokable;
 import org.apache.flink.runtime.jobgraph.tasks.CheckpointCoordinatorConfiguration;
 import org.apache.flink.runtime.jobgraph.tasks.JobCheckpointingSettings;
-import org.apache.flink.test.util.AbstractTestBaseJUnit4;
-import org.apache.flink.testutils.junit.FailsInGHAContainerWithRootUser;
+import org.apache.flink.runtime.resourcemanager.StandaloneResourceManager;
+import org.apache.flink.runtime.resourcemanager.slotmanager.DefaultResourceTracker;
+import org.apache.flink.runtime.resourcemanager.slotmanager.DefaultSlotStatusSyncer;
+import org.apache.flink.runtime.resourcemanager.slotmanager.FineGrainedSlotManager;
+import org.apache.flink.runtime.resourcemanager.slotmanager.FineGrainedTaskManagerTracker;
+import org.apache.flink.runtime.scheduler.adaptive.AdaptiveScheduler;
+import org.apache.flink.runtime.scheduler.adaptive.DefaultStateTransitionManager;
+import org.apache.flink.runtime.testutils.CommonTestUtils;
+import org.apache.flink.runtime.testutils.MiniClusterResourceConfiguration;
+import org.apache.flink.test.junit5.InjectClusterClient;
+import org.apache.flink.test.junit5.MiniClusterExtension;
+import org.apache.flink.testutils.logging.LoggerAuditingExtension;
 import org.apache.flink.util.ExceptionUtils;
+import org.apache.flink.util.MdcUtils;
 
-import org.junit.Assume;
-import org.junit.Rule;
-import org.junit.Test;
-import org.junit.experimental.categories.Category;
-import org.junit.rules.TemporaryFolder;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Assumptions;
+import org.junit.jupiter.api.Tag;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.extension.RegisterExtension;
+import org.junit.jupiter.api.io.TempDir;
 
+import java.io.File;
 import java.io.IOException;
 import java.nio.file.Files;
 import java.nio.file.Path;
 import java.nio.file.Paths;
+import java.time.Duration;
 import java.util.Collections;
 import java.util.List;
+import java.util.Set;
 import java.util.concurrent.CompletableFuture;
 import java.util.concurrent.CountDownLatch;
 import java.util.concurrent.ExecutionException;
@@ -61,40 +78,83 @@ import java.util.concurrent.TimeUnit;
 import java.util.stream.Collectors;
 import java.util.stream.Stream;
 
+import static org.apache.flink.configuration.JobManagerOptions.SCHEDULER;
+import static org.apache.flink.util.JobIDLoggingUtil.assertKeyPresent;
 import static org.hamcrest.MatcherAssert.assertThat;
 import static org.hamcrest.Matchers.equalTo;
 import static org.hamcrest.Matchers.hasItem;
 import static org.hamcrest.Matchers.isOneOf;
-import static org.junit.Assert.assertTrue;
+import static org.slf4j.event.Level.TRACE;
 
 /**
  * Tests for {@link org.apache.flink.runtime.jobmaster.JobMaster#triggerSavepoint(String, boolean,
- * Time)}.
+ * Duration)}.
  *
  * @see org.apache.flink.runtime.jobmaster.JobMaster
  */
-public class JobMasterTriggerSavepointITCase extends AbstractTestBaseJUnit4 {
+public class JobMasterTriggerSavepointITCase {
 
     private static CountDownLatch invokeLatch;
 
     private static volatile CountDownLatch triggerCheckpointLatch;
 
-    @Rule public TemporaryFolder temporaryFolder = new TemporaryFolder();
+    @TempDir protected File temporaryFolder;
+
+    @RegisterExtension
+    public final LoggerAuditingExtension standaloneResourceManagerLogging =
+            new LoggerAuditingExtension(StandaloneResourceManager.class, TRACE);
+
+    @RegisterExtension
+    public final LoggerAuditingExtension adaptiveSchedulerLogging =
+            new LoggerAuditingExtension(AdaptiveScheduler.class, TRACE);
+
+    @RegisterExtension
+    public final LoggerAuditingExtension defaultStateTransitionManagerLogging =
+            new LoggerAuditingExtension(DefaultStateTransitionManager.class, TRACE);
+
+    @RegisterExtension
+    public final LoggerAuditingExtension defaultResourceTrackerLogging =
+            new LoggerAuditingExtension(DefaultResourceTracker.class, TRACE);
+
+    @RegisterExtension
+    public final LoggerAuditingExtension defaultSlotStatusSyncerLogging =
+            new LoggerAuditingExtension(DefaultSlotStatusSyncer.class, TRACE);
+
+    @RegisterExtension
+    public final LoggerAuditingExtension fineGrainedTaskManagerTrackerLogging =
+            new LoggerAuditingExtension(FineGrainedTaskManagerTracker.class, TRACE);
+
+    @RegisterExtension
+    public final LoggerAuditingExtension fineGrainedSlotManagerLogging =
+            new LoggerAuditingExtension(FineGrainedSlotManager.class, TRACE);
+
+    @RegisterExtension
+    public static MiniClusterExtension miniClusterResource =
+            new MiniClusterExtension(
+                    new MiniClusterResourceConfiguration.Builder()
+                            .setConfiguration(getConfiguration())
+                            .setNumberTaskManagers(1)
+                            .setNumberSlotsPerTaskManager(4)
+                            .build());
+
+    private static Configuration getConfiguration() {
+        Configuration configuration = new Configuration();
+        configuration.set(SCHEDULER, JobManagerOptions.SchedulerType.Adaptive);
+        return configuration;
+    }
 
     private Path savepointDirectory;
-    private MiniClusterClient clusterClient;
     private JobGraph jobGraph;
 
-    private void setUpWithCheckpointInterval(long checkpointInterval) throws Exception {
+    private void setUpWithCheckpointInterval(
+            long checkpointInterval, ClusterClient<?> clusterClient) throws Exception {
         invokeLatch = new CountDownLatch(1);
         triggerCheckpointLatch = new CountDownLatch(1);
-        savepointDirectory = temporaryFolder.newFolder().toPath();
+        savepointDirectory = temporaryFolder.toPath();
 
-        Assume.assumeTrue(
-                "ClusterClient is not an instance of MiniClusterClient",
-                MINI_CLUSTER_RESOURCE.getClusterClient() instanceof MiniClusterClient);
-
-        clusterClient = (MiniClusterClient) MINI_CLUSTER_RESOURCE.getClusterClient();
+        Assumptions.assumeTrue(
+                clusterClient instanceof MiniClusterClient,
+                "ClusterClient is not an instance of MiniClusterClient");
 
         final JobVertex vertex = new JobVertex("testVertex");
         vertex.setInvokableClass(NoOpBlockingInvokable.class);
@@ -121,15 +181,16 @@ public class JobMasterTriggerSavepointITCase extends AbstractTestBaseJUnit4 {
                         .build();
 
         clusterClient.submitJob(jobGraph).get();
-        assertTrue(invokeLatch.await(60, TimeUnit.SECONDS));
-        waitForJob();
+        Assertions.assertTrue(invokeLatch.await(60, TimeUnit.SECONDS));
+        waitForJob(clusterClient);
     }
 
     @Test
-    public void testStopJobAfterSavepoint() throws Exception {
-        setUpWithCheckpointInterval(10L);
+    public void testStopJobAfterSavepoint(@InjectClusterClient ClusterClient<?> clusterClient)
+            throws Exception {
+        setUpWithCheckpointInterval(10L, clusterClient);
 
-        final String savepointLocation = cancelWithSavepoint();
+        final String savepointLocation = cancelWithSavepoint(clusterClient);
         final JobStatus jobStatus = clusterClient.getJobStatus(jobGraph.getJobID()).get();
 
         assertThat(jobStatus, isOneOf(JobStatus.CANCELED, JobStatus.CANCELLING));
@@ -142,11 +203,12 @@ public class JobMasterTriggerSavepointITCase extends AbstractTestBaseJUnit4 {
     }
 
     @Test
-    public void testStopJobAfterSavepointWithDeactivatedPeriodicCheckpointing() throws Exception {
+    public void testStopJobAfterSavepointWithDeactivatedPeriodicCheckpointing(
+            @InjectClusterClient ClusterClient<?> clusterClient) throws Exception {
         // set checkpointInterval to Long.MAX_VALUE, which means deactivated checkpointing
-        setUpWithCheckpointInterval(Long.MAX_VALUE);
+        setUpWithCheckpointInterval(Long.MAX_VALUE, clusterClient);
 
-        final String savepointLocation = cancelWithSavepoint();
+        final String savepointLocation = cancelWithSavepoint(clusterClient);
         final JobStatus jobStatus =
                 clusterClient.getJobStatus(jobGraph.getJobID()).get(60, TimeUnit.SECONDS);
 
@@ -160,18 +222,19 @@ public class JobMasterTriggerSavepointITCase extends AbstractTestBaseJUnit4 {
     }
 
     @Test
-    @Category(FailsInGHAContainerWithRootUser.class)
-    public void testDoNotCancelJobIfSavepointFails() throws Exception {
-        setUpWithCheckpointInterval(10L);
+    @Tag("org.apache.flink.testutils.junit.FailsInGHAContainerWithRootUser")
+    public void testDoNotCancelJobIfSavepointFails(
+            @InjectClusterClient ClusterClient<?> clusterClient) throws Exception {
+        setUpWithCheckpointInterval(10L, clusterClient);
 
         try {
             Files.setPosixFilePermissions(savepointDirectory, Collections.emptySet());
         } catch (IOException e) {
-            Assume.assumeNoException(e);
+            Assumptions.assumeTrue(e == null);
         }
 
         try {
-            cancelWithSavepoint();
+            cancelWithSavepoint(clusterClient);
         } catch (Exception e) {
             assertThat(
                     ExceptionUtils.findThrowable(e, CheckpointException.class).isPresent(),
@@ -185,6 +248,81 @@ public class JobMasterTriggerSavepointITCase extends AbstractTestBaseJUnit4 {
         // assert that checkpoints are continued to be triggered
         triggerCheckpointLatch = new CountDownLatch(1);
         assertThat(triggerCheckpointLatch.await(60L, TimeUnit.SECONDS), equalTo(true));
+
+        // assert that JobId is present in the logs
+        waitForDisconnect(clusterClient);
+        verifyJobIdIsLogged(clusterClient);
+    }
+
+    private void verifyJobIdIsLogged(ClusterClient<?> clusterClient) throws Exception {
+        final Set<String> jobIDs =
+                clusterClient.listJobs().get().stream()
+                        .map(r -> r.getJobId().toHexString())
+                        .collect(Collectors.toSet());
+
+        // NOTE: most of the assertions are empirical, such as
+        // - which classes are important
+        // - how many messages to expect
+        // - which log patterns to ignore
+        assertKeyPresent(
+                MdcUtils.JOB_ID,
+                jobIDs,
+                adaptiveSchedulerLogging,
+                List.of(
+                        "Closing the AdaptiveScheduler. Trying to suspend the current job execution.",
+                        "Transition from state .*",
+                        "Stopping the checkpoint services with state .*"));
+        assertKeyPresent(
+                MdcUtils.JOB_ID,
+                jobIDs,
+                defaultStateTransitionManagerLogging,
+                List.of(
+                        "OnChange event received in phase Idling for job .*",
+                        "OnTrigger event received in phase Idling for job .*",
+                        "Transitioning from .*",
+                        "Desired resources are .*"));
+        assertKeyPresent(
+                MdcUtils.JOB_ID,
+                jobIDs,
+                standaloneResourceManagerLogging,
+                List.of(
+                        "Registering job manager .*",
+                        "Registered job manager .*",
+                        "Disconnect job manager .*"),
+                "Registering TaskManager with ResourceID .*");
+        assertKeyPresent(
+                MdcUtils.JOB_ID,
+                jobIDs,
+                defaultResourceTrackerLogging,
+                List.of(
+                        "Received notification for job .*",
+                        "Initiating tracking of resources for job .*",
+                        "Stopping tracking of resources for job .*"));
+        assertKeyPresent(
+                MdcUtils.JOB_ID,
+                jobIDs,
+                defaultSlotStatusSyncerLogging,
+                List.of(
+                        "Freeing slot .*",
+                        "Starting allocation of slot .*",
+                        "Completed allocation of allocation .*"));
+        assertKeyPresent(
+                MdcUtils.JOB_ID,
+                jobIDs,
+                fineGrainedTaskManagerTrackerLogging,
+                List.of(
+                        "Add pending slot with allocationId .*",
+                        "Complete slot allocation with allocationId .*",
+                        "Free allocated slot with allocationId .*"),
+                "Add task manager .*");
+        assertKeyPresent(
+                MdcUtils.JOB_ID,
+                jobGraph.getJobID().toHexString(),
+                fineGrainedSlotManagerLogging,
+                List.of("Received resource requirements from job .*"),
+                "(?s)Matching resource requirements against available resources..*",
+                "Freeing slot .*",
+                "Registering task executor .*");
     }
 
     /**
@@ -192,8 +330,9 @@ public class JobMasterTriggerSavepointITCase extends AbstractTestBaseJUnit4 {
      * with a meaningful exception message.
      */
     @Test
-    public void testCancelWithSavepointWithoutConfiguredSavepointDirectory() throws Exception {
-        setUpWithCheckpointInterval(10L);
+    public void testCancelWithSavepointWithoutConfiguredSavepointDirectory(
+            @InjectClusterClient ClusterClient<?> clusterClient) throws Exception {
+        setUpWithCheckpointInterval(10L, clusterClient);
 
         try {
             clusterClient
@@ -206,7 +345,7 @@ public class JobMasterTriggerSavepointITCase extends AbstractTestBaseJUnit4 {
         }
     }
 
-    private void waitForJob() throws Exception {
+    private void waitForJob(ClusterClient<?> clusterClient) throws Exception {
         for (int i = 0; i < 60; i++) {
             try {
                 final JobStatus jobStatus =
@@ -223,6 +362,13 @@ public class JobMasterTriggerSavepointITCase extends AbstractTestBaseJUnit4 {
         throw new AssertionError("Job did not become running within timeout.");
     }
 
+    private void waitForDisconnect(ClusterClient<?> clusterClient) throws Exception {
+        clusterClient.cancel(jobGraph.getJobID()).get();
+        CommonTestUtils.waitUntilCondition(
+                () -> clusterClient.getJobStatus(jobGraph.getJobID()).get() == JobStatus.CANCELED,
+                600);
+    }
+
     /**
      * Invokable which calls {@link CountDownLatch#countDown()} on {@link
      * JobMasterTriggerSavepointITCase#invokeLatch}, and then blocks afterwards.
@@ -275,7 +421,7 @@ public class JobMasterTriggerSavepointITCase extends AbstractTestBaseJUnit4 {
         }
     }
 
-    private String cancelWithSavepoint() throws Exception {
+    private String cancelWithSavepoint(ClusterClient<?> clusterClient) throws Exception {
         return clusterClient
                 .cancelWithSavepoint(
                         jobGraph.getJobID(),
