@@ -21,7 +21,6 @@ package org.apache.flink.test.runtime;
 import org.apache.flink.api.common.BatchShuffleMode;
 import org.apache.flink.configuration.Configuration;
 import org.apache.flink.configuration.ExecutionOptions;
-import org.apache.flink.configuration.NettyShuffleEnvironmentOptions;
 import org.apache.flink.configuration.TaskManagerOptions;
 import org.apache.flink.runtime.jobgraph.JobGraph;
 import org.apache.flink.testutils.junit.extensions.parameterized.Parameter;
@@ -31,24 +30,18 @@ import org.apache.flink.testutils.junit.extensions.parameterized.Parameters;
 import org.junit.jupiter.api.TestTemplate;
 import org.junit.jupiter.api.extension.ExtendWith;
 
+import java.time.Duration;
 import java.util.Arrays;
 import java.util.Collection;
 
 /** Tests for hybrid shuffle mode. */
 @ExtendWith(ParameterizedTestExtension.class)
 class HybridShuffleITCase extends BatchShuffleITCaseBase {
+    @Parameter public boolean enableAdaptiveAutoParallelism;
 
-    @Parameter public boolean enableNewHybridMode;
-
-    @Parameter(value = 1)
-    public boolean enableAdaptiveAutoParallelism;
-
-    @Parameters(name = "enableNewHybridMode={0} enableAdaptiveAutoParallelism={1}")
+    @Parameters(name = "enableAdaptiveAutoParallelism={0}")
     public static Collection<Boolean[]> parameters() {
-        return Arrays.asList(
-                new Boolean[] {false, false},
-                new Boolean[] {true, false},
-                new Boolean[] {true, true});
+        return Arrays.asList(new Boolean[] {false}, new Boolean[] {false}, new Boolean[] {true});
     }
 
     @TestTemplate
@@ -91,18 +84,28 @@ class HybridShuffleITCase extends BatchShuffleITCaseBase {
         executeJob(jobGraph, configuration, numRecordsToSend);
     }
 
+    @TestTemplate
+    public void testAutoDisableBufferDebloat() throws Exception {
+        final int numRecordsToSend = 1_000_000;
+        Configuration configuration = configureHybridOptions(getConfiguration(), false);
+        configuration.set(TaskManagerOptions.BUFFER_DEBLOAT_ENABLED, true);
+        configuration.set(TaskManagerOptions.BUFFER_DEBLOAT_PERIOD, Duration.ofMillis(1));
+
+        JobGraph jobGraph =
+                createJobGraph(
+                        numRecordsToSend, false, configuration, enableAdaptiveAutoParallelism);
+        executeJob(jobGraph, configuration, numRecordsToSend);
+    }
+
     private Configuration configureHybridOptions(Configuration configuration, boolean isSelective) {
         BatchShuffleMode shuffleMode =
                 isSelective
                         ? BatchShuffleMode.ALL_EXCHANGES_HYBRID_SELECTIVE
                         : BatchShuffleMode.ALL_EXCHANGES_HYBRID_FULL;
         configuration.set(ExecutionOptions.BATCH_SHUFFLE_MODE, shuffleMode);
-        configuration.set(
-                NettyShuffleEnvironmentOptions.NETWORK_HYBRID_SHUFFLE_ENABLE_NEW_MODE,
-                enableNewHybridMode);
 
-        if (enableNewHybridMode && isSelective) {
-            // Note that the memory tier of the new mode need more buffers for the selective mode
+        if (isSelective) {
+            // Note that the memory tier need more buffers for the selective mode
             configuration.setString(TaskManagerOptions.NETWORK_MEMORY_MAX.key(), "128m");
         }
         return configuration;
