@@ -22,7 +22,7 @@ import org.apache.flink.streaming.api.datastream.DataStream;
 import org.apache.flink.streaming.api.environment.StreamExecutionEnvironment;
 import org.apache.flink.streaming.api.functions.co.CoMapFunction;
 import org.apache.flink.test.streaming.runtime.util.TestListResultSink;
-import org.apache.flink.test.util.AbstractTestBase;
+import org.apache.flink.test.util.AbstractTestBaseJUnit4;
 import org.apache.flink.util.Collector;
 
 import org.junit.Test;
@@ -35,7 +35,7 @@ import static org.junit.Assert.assertEquals;
 
 /** Integration tests for connected streams. */
 @SuppressWarnings("serial")
-public class SelfConnectionITCase extends AbstractTestBase {
+public class SelfConnectionITCase extends AbstractTestBaseJUnit4 {
 
     /** We connect two different data streams in a chain to a CoMap. */
     @Test
