@@ -23,8 +23,7 @@ import org.apache.flink.api.common.functions.RuntimeContext;
 import org.apache.flink.api.common.typeinfo.BasicTypeInfo;
 import org.apache.flink.streaming.api.datastream.DataStream;
 import org.apache.flink.streaming.api.environment.StreamExecutionEnvironment;
-import org.apache.flink.streaming.api.functions.source.RichParallelSourceFunction;
-import org.apache.flink.streaming.api.operators.ChainingStrategy;
+import org.apache.flink.streaming.api.functions.source.legacy.RichParallelSourceFunction;
 import org.apache.flink.streaming.util.TestSequentialReadingStreamOperator;
 import org.apache.flink.test.streaming.runtime.util.TestListResultSink;
 
@@ -58,7 +57,6 @@ public class StreamTaskSelectiveReadingITCase {
 
         TestSequentialReadingStreamOperator twoInputStreamOperator =
                 new TestSequentialReadingStreamOperator("Operator0");
-        twoInputStreamOperator.setChainingStrategy(ChainingStrategy.NEVER);
 
         source0.connect(source1)
                 .transform(
