@@ -20,6 +20,14 @@ package org.apache.flink.test.streaming.runtime;
 
 import org.apache.flink.api.common.JobID;
 import org.apache.flink.api.common.JobStatus;
+import org.apache.flink.api.common.eventtime.AscendingTimestampsWatermarks;
+import org.apache.flink.api.common.eventtime.NoWatermarksGenerator;
+import org.apache.flink.api.common.eventtime.TimestampAssigner;
+import org.apache.flink.api.common.eventtime.TimestampAssignerSupplier;
+import org.apache.flink.api.common.eventtime.WatermarkGenerator;
+import org.apache.flink.api.common.eventtime.WatermarkGeneratorSupplier;
+import org.apache.flink.api.common.eventtime.WatermarkOutput;
+import org.apache.flink.api.common.eventtime.WatermarkStrategy;
 import org.apache.flink.api.common.functions.MapFunction;
 import org.apache.flink.api.common.functions.ReduceFunction;
 import org.apache.flink.api.common.typeinfo.BasicTypeInfo;
@@ -34,31 +42,29 @@ import org.apache.flink.runtime.checkpoint.CheckpointException;
 import org.apache.flink.runtime.checkpoint.CheckpointFailureReason;
 import org.apache.flink.runtime.client.JobStatusMessage;
 import org.apache.flink.runtime.testutils.MiniClusterResourceConfiguration;
-import org.apache.flink.streaming.api.TimeCharacteristic;
 import org.apache.flink.streaming.api.datastream.DataStream;
 import org.apache.flink.streaming.api.environment.StreamExecutionEnvironment;
-import org.apache.flink.streaming.api.functions.AssignerWithPeriodicWatermarks;
-import org.apache.flink.streaming.api.functions.AssignerWithPunctuatedWatermarks;
 import org.apache.flink.streaming.api.functions.co.CoMapFunction;
 import org.apache.flink.streaming.api.functions.sink.v2.DiscardingSink;
-import org.apache.flink.streaming.api.functions.source.SourceFunction;
-import org.apache.flink.streaming.api.functions.timestamps.AscendingTimestampExtractor;
+import org.apache.flink.streaming.api.functions.source.legacy.SourceFunction;
 import org.apache.flink.streaming.api.operators.AbstractStreamOperator;
-import org.apache.flink.streaming.api.operators.ChainingStrategy;
 import org.apache.flink.streaming.api.operators.OneInputStreamOperator;
 import org.apache.flink.streaming.api.watermark.Watermark;
 import org.apache.flink.streaming.api.windowing.assigners.TumblingEventTimeWindows;
-import org.apache.flink.streaming.api.windowing.time.Time;
 import org.apache.flink.streaming.runtime.streamrecord.StreamRecord;
 import org.apache.flink.test.util.MiniClusterWithClientResource;
 import org.apache.flink.util.ExceptionUtils;
 import org.apache.flink.util.TestLogger;
+import org.apache.flink.util.function.SerializableFunction;
 
 import org.junit.Assert;
 import org.junit.Before;
 import org.junit.ClassRule;
+import org.junit.Rule;
 import org.junit.Test;
+import org.junit.rules.TemporaryFolder;
 
+import java.time.Duration;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.List;
@@ -74,6 +80,8 @@ import static org.junit.Assert.fail;
 @SuppressWarnings("serial")
 public class TimestampITCase extends TestLogger {
 
+    @Rule public TemporaryFolder tmpFolder = new TemporaryFolder();
+
     private static final int NUM_TASK_MANAGERS = 2;
     private static final int NUM_TASK_SLOTS = 3;
     private static final int PARALLELISM = NUM_TASK_MANAGERS * NUM_TASK_SLOTS;
@@ -223,14 +231,16 @@ public class TimestampITCase extends TestLogger {
                             JobID id = running.get(0);
 
                             waitUntilAllTasksAreRunning(CLUSTER.getRestClusterClient(), id);
+
                             // send stop until the job is stopped
+                            final String savepointDirName = tmpFolder.newFolder().getAbsolutePath();
                             do {
                                 try {
                                     clusterClient
                                             .stopWithSavepoint(
                                                     id,
                                                     false,
-                                                    "test",
+                                                    savepointDirName,
                                                     SavepointFormatType.CANONICAL)
                                             .get();
                                 } catch (Exception e) {
@@ -372,12 +382,7 @@ public class TimestampITCase extends TestLogger {
 
         DataStream<Integer> extractOp =
                 source1.assignTimestampsAndWatermarks(
-                        new AscendingTimestampExtractor<Integer>() {
-                            @Override
-                            public long extractAscendingTimestamp(Integer element) {
-                                return element;
-                            }
-                        });
+                        AscendingRecordTimestampsWatermarkStrategy.create(Long::valueOf));
 
         extractOp
                 .transform("Watermark Check", BasicTypeInfo.INT_TYPE_INFO, new CustomOperator(true))
@@ -445,17 +450,30 @@ public class TimestampITCase extends TestLogger {
                         });
 
         source1.assignTimestampsAndWatermarks(
-                        new AssignerWithPunctuatedWatermarks<Integer>() {
-
+                        new WatermarkStrategy<Integer>() {
                             @Override
-                            public long extractTimestamp(Integer element, long currentTimestamp) {
-                                return element;
+                            public TimestampAssigner<Integer> createTimestampAssigner(
+                                    TimestampAssignerSupplier.Context context) {
+                                return (element, recordTimestamp) -> element;
                             }
 
                             @Override
-                            public Watermark checkAndGetNextWatermark(
-                                    Integer element, long extractedTimestamp) {
-                                return new Watermark(extractedTimestamp - 1);
+                            public WatermarkGenerator<Integer> createWatermarkGenerator(
+                                    WatermarkGeneratorSupplier.Context context) {
+                                return new WatermarkGenerator<Integer>() {
+                                    @Override
+                                    public void onEvent(
+                                            Integer event,
+                                            long eventTimestamp,
+                                            WatermarkOutput output) {
+                                        output.emitWatermark(
+                                                new org.apache.flink.api.common.eventtime.Watermark(
+                                                        eventTimestamp - 1));
+                                    }
+
+                                    @Override
+                                    public void onPeriodicEmit(WatermarkOutput output) {}
+                                };
                             }
                         })
                 .transform("Watermark Check", BasicTypeInfo.INT_TYPE_INFO, new CustomOperator(true))
@@ -510,17 +528,30 @@ public class TimestampITCase extends TestLogger {
                         });
 
         source1.assignTimestampsAndWatermarks(
-                        new AssignerWithPunctuatedWatermarks<Integer>() {
-
+                        new WatermarkStrategy<Integer>() {
                             @Override
-                            public long extractTimestamp(Integer element, long previousTimestamp) {
-                                return element;
+                            public TimestampAssigner<Integer> createTimestampAssigner(
+                                    TimestampAssignerSupplier.Context context) {
+                                return (element, recordTimestamp) -> element;
                             }
 
                             @Override
-                            public Watermark checkAndGetNextWatermark(
-                                    Integer element, long extractedTimestamp) {
-                                return new Watermark(extractedTimestamp - 1);
+                            public WatermarkGenerator<Integer> createWatermarkGenerator(
+                                    WatermarkGeneratorSupplier.Context context) {
+                                return new WatermarkGenerator<Integer>() {
+                                    @Override
+                                    public void onEvent(
+                                            Integer event,
+                                            long eventTimestamp,
+                                            WatermarkOutput output) {
+                                        output.emitWatermark(
+                                                new org.apache.flink.api.common.eventtime.Watermark(
+                                                        eventTimestamp - 1));
+                                    }
+
+                                    @Override
+                                    public void onPeriodicEmit(WatermarkOutput output) {}
+                                };
                             }
                         })
                 .transform("Watermark Check", BasicTypeInfo.INT_TYPE_INFO, new CustomOperator(true))
@@ -579,19 +610,7 @@ public class TimestampITCase extends TestLogger {
                         });
 
         source1.assignTimestampsAndWatermarks(
-                        new AssignerWithPunctuatedWatermarks<Integer>() {
-
-                            @Override
-                            public long extractTimestamp(Integer element, long currentTimestamp) {
-                                return element;
-                            }
-
-                            @Override
-                            public Watermark checkAndGetNextWatermark(
-                                    Integer element, long extractedTimestamp) {
-                                return null;
-                            }
-                        })
+                        (WatermarkStrategy<Integer>) context -> new NoWatermarksGenerator<>())
                 .transform(
                         "Watermark Check", BasicTypeInfo.INT_TYPE_INFO, new CustomOperator(true));
 
@@ -641,18 +660,7 @@ public class TimestampITCase extends TestLogger {
                         });
 
         source1.assignTimestampsAndWatermarks(
-                        new AssignerWithPeriodicWatermarks<Integer>() {
-
-                            @Override
-                            public long extractTimestamp(Integer element, long currentTimestamp) {
-                                return element;
-                            }
-
-                            @Override
-                            public Watermark getCurrentWatermark() {
-                                return null;
-                            }
-                        })
+                        (WatermarkStrategy<Integer>) context -> new NoWatermarksGenerator<>())
                 .transform(
                         "Watermark Check", BasicTypeInfo.INT_TYPE_INFO, new CustomOperator(true));
 
@@ -663,44 +671,17 @@ public class TimestampITCase extends TestLogger {
                 CustomOperator.finalWatermarks[0].get(0).getTimestamp() == Long.MAX_VALUE);
     }
 
-    /**
-     * This verifies that an event time source works when setting stream time characteristic to
-     * processing time. In this case, the watermarks should just be swallowed apart from the last
-     * final watermark marking the end of time.
-     */
-    @Test
-    public void testEventTimeSourceWithProcessingTime() throws Exception {
-        StreamExecutionEnvironment env = StreamExecutionEnvironment.getExecutionEnvironment();
-
-        env.setParallelism(2);
-        env.setStreamTimeCharacteristic(TimeCharacteristic.ProcessingTime);
-
-        DataStream<Integer> source1 = env.addSource(new MyTimestampSource(0, 10));
-
-        source1.map(new IdentityMap())
-                .transform(
-                        "Watermark Check", BasicTypeInfo.INT_TYPE_INFO, new CustomOperator(false));
-
-        env.execute();
-
-        // verify that we don't get any watermarks, the source is used as watermark source in
-        // other tests, so it normally emits watermarks
-        Assert.assertTrue(CustomOperator.finalWatermarks[0].size() == 1);
-        Assert.assertEquals(Watermark.MAX_WATERMARK, CustomOperator.finalWatermarks[0].get(0));
-    }
-
     @Test
     public void testErrorOnEventTimeOverProcessingTime() {
         StreamExecutionEnvironment env = StreamExecutionEnvironment.getExecutionEnvironment();
 
         env.setParallelism(2);
-        env.setStreamTimeCharacteristic(TimeCharacteristic.ProcessingTime);
 
         DataStream<Tuple2<String, Integer>> source1 =
                 env.fromData(new Tuple2<>("a", 1), new Tuple2<>("b", 2));
 
-        source1.keyBy(0)
-                .window(TumblingEventTimeWindows.of(Time.seconds(5)))
+        source1.keyBy(x -> x.f0)
+                .window(TumblingEventTimeWindows.of(Duration.ofSeconds(5)))
                 .reduce(
                         new ReduceFunction<Tuple2<String, Integer>>() {
                             @Override
@@ -729,8 +710,8 @@ public class TimestampITCase extends TestLogger {
         DataStream<Tuple2<String, Integer>> source1 =
                 env.fromData(new Tuple2<>("a", 1), new Tuple2<>("b", 2));
 
-        source1.keyBy(0)
-                .window(TumblingEventTimeWindows.of(Time.seconds(5)))
+        source1.keyBy(x -> x.f0)
+                .window(TumblingEventTimeWindows.of(Duration.ofSeconds(5)))
                 .reduce(
                         new ReduceFunction<Tuple2<String, Integer>>() {
                             @Override
@@ -763,7 +744,6 @@ public class TimestampITCase extends TestLogger {
         private final boolean timestampsEnabled;
 
         public CustomOperator(boolean timestampsEnabled) {
-            setChainingStrategy(ChainingStrategy.ALWAYS);
             this.timestampsEnabled = timestampsEnabled;
         }
 
@@ -805,9 +785,7 @@ public class TimestampITCase extends TestLogger {
     private static class TimestampCheckingOperator extends AbstractStreamOperator<Integer>
             implements OneInputStreamOperator<Integer, Integer> {
 
-        public TimestampCheckingOperator() {
-            setChainingStrategy(ChainingStrategy.ALWAYS);
-        }
+        public TimestampCheckingOperator() {}
 
         @Override
         public void processElement(StreamRecord<Integer> element) throws Exception {
@@ -927,4 +905,31 @@ public class TimestampITCase extends TestLogger {
                 .map(JobStatusMessage::getJobId)
                 .collect(Collectors.toList());
     }
+
+    public static class AscendingRecordTimestampsWatermarkStrategy<T>
+            implements WatermarkStrategy<T> {
+        private final SerializableFunction<T, Long> timestampExtractor;
+
+        public AscendingRecordTimestampsWatermarkStrategy(
+                SerializableFunction<T, Long> timestampExtractor) {
+            this.timestampExtractor = timestampExtractor;
+        }
+
+        public static <T> AscendingRecordTimestampsWatermarkStrategy<T> create(
+                SerializableFunction<T, Long> timestampExtractor) {
+            return new AscendingRecordTimestampsWatermarkStrategy<>(timestampExtractor);
+        }
+
+        @Override
+        public WatermarkGenerator<T> createWatermarkGenerator(
+                WatermarkGeneratorSupplier.Context context) {
+            return new AscendingTimestampsWatermarks<>();
+        }
+
+        @Override
+        public TimestampAssigner<T> createTimestampAssigner(
+                TimestampAssignerSupplier.Context context) {
+            return (event, ignore) -> timestampExtractor.apply(event);
+        }
+    }
 }
