@@ -207,6 +207,7 @@ public abstract class YarnTestBase {
 
     protected static File yarnSiteXML = null;
     protected static File hdfsSiteXML = null;
+    protected static Map<String, String> env;
 
     private YarnClient yarnClient = null;
 
@@ -244,7 +245,7 @@ public abstract class YarnTestBase {
      *
      * @return a classpath suitable for running all YARN-launched JVMs
      */
-    private static String getYarnClasspath() {
+    protected static String getYarnClasspath() {
         final String start = "../flink-yarn-tests";
         try {
             File classPathFile =
@@ -431,7 +432,9 @@ public abstract class YarnTestBase {
         private String[] names;
         private String excludeInPath = null;
 
-        /** @param names which have to be included in the filename. */
+        /**
+         * @param names which have to be included in the filename.
+         */
         public ContainsName(String[] names) {
             this.names = names;
         }
@@ -817,7 +820,7 @@ public abstract class YarnTestBase {
                 yarnCluster.start();
             }
 
-            Map<String, String> map = new HashMap<String, String>(System.getenv());
+            env = new HashMap<>(System.getenv());
 
             File flinkConfDirPath =
                     TestUtils.findFile(
@@ -829,7 +832,8 @@ public abstract class YarnTestBase {
             final String confDirPath = flinkConfDirPath.getParentFile().getAbsolutePath();
             globalConfiguration = GlobalConfiguration.loadConfiguration(confDirPath);
             globalConfiguration.set(
-                    JobManagerOptions.RESOURCE_WAIT_TIMEOUT, Duration.ofSeconds(30));
+                    JobManagerOptions.SCHEDULER_SUBMISSION_RESOURCE_WAIT_TIMEOUT,
+                    Duration.ofSeconds(30));
 
             // copy conf dir to test temporary workspace location
             tempConfPathForSecureRun = tmp.toPath().resolve("conf").toFile();
@@ -849,7 +853,7 @@ public abstract class YarnTestBase {
 
             assertThat(configDir).isNotNull();
 
-            map.put(ConfigConstants.ENV_FLINK_CONF_DIR, configDir);
+            env.put(ConfigConstants.ENV_FLINK_CONF_DIR, configDir);
 
             File targetTestClassesFolder = new File("target/test-classes");
             writeYarnSiteConfigXML(conf, targetTestClassesFolder);
@@ -859,12 +863,12 @@ public abstract class YarnTestBase {
                 setMiniDFSCluster(targetTestClassesFolder);
             }
 
-            map.put(
+            env.put(
                     "IN_TESTS",
                     "yes we are in tests"); // see YarnClusterDescriptor() for more infos
-            map.put("YARN_CONF_DIR", targetTestClassesFolder.getAbsolutePath());
-            map.put("MAX_LOG_FILE_NUMBER", "10");
-            CommonTestUtils.setEnv(map);
+            env.put("YARN_CONF_DIR", targetTestClassesFolder.getAbsolutePath());
+            env.put("MAX_LOG_FILE_NUMBER", "10");
+            CommonTestUtils.setEnv(env);
 
             assertThat(yarnCluster.getServiceState()).isEqualTo(Service.STATE.STARTED);
 
